#pragma once

#include <array>
#include <string>

enum class ScriptType : uint8_t { Tamil, Brahmi, Roman, Others };

struct ScriptData {
  ScriptType type {};
  std::array<std::string_view, 19> vowels;
  std::array<std::string_view, 19> vowelDiacritics;
  std::array<std::string_view, 50> consonants;
  std::array<std::string_view, 5> consonantDiacritic;
  std::array<std::string_view, 19> symbols;
};

// clang-format off
constexpr std::array<std::pair<std::string_view, ScriptData>, 118> ScriptDataMap {{
  { "bengali", {
    ScriptType::Brahmi,
    { "অ", "আ", "ই", "ঈ", "উ", "ঊ", "ঋ", "ৠ", "ঌ", "ৡ", "এ˘", "এ", "ঐ", "ও˘", "ও", "ঔ", "এʼ", "এˇ", "আʼ" },
    { "্", "া", "ি", "ী", "ু", "ূ", "ৃ", "ৄ", "ৢ", "ৣ", "ে˘", "ে", "ৈ", "ো˘", "ো", "ৌ", "েʼ", "েˇ", "াʼ" },
    { "ক", "খ", "গ", "ঘ", "ঙ", "চ", "ছ", "জ", "ঝ", "ঞ", "ট", "ঠ", "ড", "ঢ", "ণ", "ত", "থ", "দ", "ধ", "ন", "প", "ফ", "ব", "ভ", "ম", "য", "র", "ল", "ৱ", "শ", "ষ", "স", "হ", "ল়", "ষ়", "র়", "ন়", "ক়", "খ়", "গ়", "জ়", "ড়", "ঢ়", "ফ়", "য়", "ঁˆগ", "ঁˆজ", "ঁˆড", "ঁˆদ", "ঁˆব" },
    { "ঁ", "ং", "ঃ", "ঃʼ", "়" },
    { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯", "ওঁ", "ঽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "devanagari", {
    ScriptType::Brahmi,
    { "अ", "आ", "इ", "ई", "उ", "ऊ", "ऋ", "ॠ", "ऌ", "ॡ", "ऎ", "ए", "ऐ", "ऒ", "ओ", "औ", "ऍ", "एॕ", "ऑ" },
    { "्", "ा", "ि", "ी", "ु", "ू", "ृ", "ॄ", "ॢ", "ॣ", "ॆ", "े", "ै", "ॊ", "ो", "ौ", "ॅ", "ॕ", "ॉ" },
    { "क", "ख", "ग", "घ", "ङ", "च", "छ", "ज", "झ", "ञ", "ट", "ठ", "ड", "ढ", "ण", "त", "थ", "द", "ध", "न", "प", "फ", "ब", "भ", "म", "य", "र", "ल", "व", "श", "ष", "स", "ह", "ळ", "ऴ", "ऱ", "ऩ", "क़", "ख़", "ग़", "ज़", "ड़", "ढ़", "फ़", "य़", "ँˆग", "ँˆज", "ँˆड", "ँˆद", "ँˆब" },
    { "ँ", "ं", "ः", "ःʼ", "़" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "ॐ", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "gujarati", {
    ScriptType::Brahmi,
    { "અ", "આ", "ઇ", "ઈ", "ઉ", "ઊ", "ઋ", "ૠ", "ઌ", "ૡ", "એ˘", "એ", "ઐ", "ઓ˘", "ઓ", "ઔ", "ઍ", "ઍˇ", "ઑ" },
    { "્", "ા", "િ", "ી", "ુ", "ૂ", "ૃ", "ૄ", "ૢ", "ૣ", "ે˘", "ે", "ૈ", "ો˘", "ો", "ૌ", "ૅ", "ૅˇ", "ૉ" },
    { "ક", "ખ", "ગ", "ઘ", "ઙ", "ચ", "છ", "જ", "ઝ", "ઞ", "ટ", "ઠ", "ડ", "ઢ", "ણ", "ત", "થ", "દ", "ધ", "ન", "પ", "ફ", "બ", "ભ", "મ", "ય", "ર", "લ", "વ", "શ", "ષ", "સ", "હ", "ળ", "ળ઼", "ર઼", "ન઼", "ક઼", "ખ઼", "ગ઼", "જ઼", "ડ઼", "ઢ઼", "ફ઼", "ય઼", "ઁˆગ", "ઁˆજ", "ઁˆડ", "ઁˆદ", "ઁˆબ" },
    { "ઁ", "ં", "ઃ", "ઃʼ", "઼" },
    { "૦", "૧", "૨", "૩", "૪", "૫", "૬", "૭", "૮", "૯", "ૐ", "ઽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "gurmukhi", {
    ScriptType::Brahmi,
    { "ਅ", "ਆ", "ਇ", "ਈ", "ਉ", "ਊ", "ਰੁʼ", "ਰੂʼ", "ਲੁʼ", "ਲੂʼ", "ਏ˘", "ਏ", "ਐ", "ਓ˘", "ਓ", "ਔ", "ਏʼ", "ਏˇ", "ਆʼ" },
    { "੍", "ਾ", "ਿ", "ੀ", "ੁ", "ੂ", "੍ਰੁʼ", "੍ਰੂʼ", "੍ਲੁʼ", "੍ਲੂʼ", "ੇ˘", "ੇ", "ੈ", "ੋ˘", "ੋ", "ੌ", "ੇʼ", "ੇˇ", "ਾʼ" },
    { "ਕ", "ਖ", "ਗ", "ਘ", "ਙ", "ਚ", "ਛ", "ਜ", "ਝ", "ਞ", "ਟ", "ਠ", "ਡ", "ਢ", "ਣ", "ਤ", "ਥ", "ਦ", "ਧ", "ਨ", "ਪ", "ਫ", "ਬ", "ਭ", "ਮ", "ਯ", "ਰ", "ਲ", "ਵ", "ਸ਼", "ਸ਼਼", "ਸ", "ਹ", "ਲ਼", "ਲ਼਼", "ਰ਼", "ਨ਼", "ਕ਼", "ਖ਼", "ਗ਼", "ਜ਼", "ੜ", "ਢ਼", "ਫ਼", "ਯ਼", "ਁˆਗ", "ਁˆਜ", "ਁˆਡ", "ਁˆਦ", "ਁˆਬ" },
    { "ਁ", "ਂ", "ਃ", "ਃʼ", "਼" },
    { "੦", "੧", "੨", "੩", "੪", "੫", "੬", "੭", "੮", "੯", "ੴ", "(ਅ)", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "iast", {
    ScriptType::Roman,
    { "a", "ā", "i", "ī", "u", "ū", "ṛ", "ṝ", "ḷ", "ḹ", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "×", "ā", "i", "ī", "u", "ū", "ṛ", "ṝ", "ḷ", "ḹ", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "k", "kh", "g", "gh", "ṅ", "c", "ch", "j", "jh", "ñ", "ṭ", "ṭh", "ḍ", "ḍh", "ṇ", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "ś", "ṣ", "s", "h", "l̤", "ḻ", "ṟ", "ṉ", "q", "k͟h", "ġ", "z", "r̤", "r̤h", "f", "ẏ", "n̆g", "n̆j", "n̆ḍ", "n̆d", "m̆b" },
    { "m̐", "ṃ", "ḥ", "ḵ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oṃ", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "ipa", {
    ScriptType::Roman,
    { "ə", "ɑː", "ɪ", "iː", "u", "uː", "ɾɨ", "ɾɨː", "lɨ", "lɨː", "e", "eː", "əɪ", "o", "oː", "əu", "æ", "æː", "ɔ" },
    { "×", "ɑː", "ɪ", "iː", "u", "uː", "ɾɨ", "ɾɨː", "lɨ", "lɨː", "e", "eː", "əɪ", "o", "oː", "əu", "æ", "æː", "ɔ" },
    { "k", "kʰ", "g", "gʰ", "ŋ", "t͡ʃ", "t͡ʃʰ", "d͡ʒ", "d͡ʒʰ", "ɲ", "ʈ", "ʈʰ", "ɖ", "ɖʰ", "ɳ", "t̪", "t̪ʰ", "d̪", "d̪ʰ", "n̪", "p", "pʰ", "b", "bʰ", "m", "j", "ɾ", "l", "ʋ", "ʃ", "ʂ", "s̪", "ɦ", "ɭ", "ɻ", "r", "n", "q", "x", "ɣ", "z", "ɽ", "ɽʰ", "f", "ẏ", "ᵑɡ", "ᶮd͡ʒ", "ᶯɖ", "ⁿd", "ᵐb" },
    { "̃ʽ", "̃", "h", "xʽ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oːm", "ə̸", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "iso", {
    ScriptType::Roman,
    { "a", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "e", "ē", "ai", "o", "ō", "au", "æ", "ǣ", "ô" },
    { "×", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "e", "ē", "ai", "o", "ō", "au", "æ", "ǣ", "ô" },
    { "k", "kh", "g", "gh", "ṅ", "c", "ch", "j", "jh", "ñ", "ṭ", "ṭh", "ḍ", "ḍh", "ṇ", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "ś", "ṣ", "s", "h", "ḷ", "ḻ", "ṟ", "ṉ", "q", "k͟h", "ġ", "z", "ṛ", "ṛh", "f", "ẏ", "n̆g", "n̆j", "n̆ḍ", "n̆d", "m̆b" },
    { "m̐", "ṁ", "ḥ", "ḵ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ōṁ", "’", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "itrans", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "R^i", "R^I", "L^i", "L^I", "^e", "e", "ai", "^o", "o", "au", "e.c", "a.C", "A.c" },
    { "×", "A", "i", "I", "u", "U", "R^i", "R^I", "L^i", "L^I", "^e", "e", "ai", "^o", "o", "au", "e.c", "a.C", "A.c" },
    { "k", "kh", "g", "gh", "~N", "ch", "Ch", "j", "jh", "~n", "T", "Th", "D", "Dh", "N", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "sh", "Sh", "s", "h", "L", "zh", "R", "^n", "q", "K", "G", "z", ".D", ".Dh", "f", "Y", "n*g", "n*j", "n*D", "n*d", "m*b" },
    { ".N", "M", "H", "K^", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oM", ".a", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "kannada", {
    ScriptType::Brahmi,
    { "ಅ", "ಆ", "ಇ", "ಈ", "ಉ", "ಊ", "ಋ", "ೠ", "ಌ", "ೡ", "ಎ", "ಏ", "ಐ", "ಒ", "ಓ", "ಔ", "ಎʼ", "ಏˇ", "ಆʼ" },
    { "್", "ಾ", "ಿ", "ೀ", "ು", "ೂ", "ೃ", "ೄ", "ೢ", "ೣ", "ೆ", "ೇ", "ೈ", "ೊ", "ೋ", "ೌ", "ೆʼ", "ೇˇ", "ಾʼ" },
    { "ಕ", "ಖ", "ಗ", "ಘ", "ಙ", "ಚ", "ಛ", "ಜ", "ಝ", "ಞ", "ಟ", "ಠ", "ಡ", "ಢ", "ಣ", "ತ", "ಥ", "ದ", "ಧ", "ನ", "ಪ", "ಫ", "ಬ", "ಭ", "ಮ", "ಯ", "ರ", "ಲ", "ವ", "ಶ", "ಷ", "ಸ", "ಹ", "ಳ", "ೞ", "ಱ", "ನ಼", "ಕ಼", "ಖ಼", "ಗ಼", "ಜ಼", "ಡ಼", "ಢ಼", "ಫ಼", "ಯ಼", "ಂˆಗ", "ಂˆಜ", "ಂˆಡ", "ಂˆದ", "ಂˆಬ" },
    { "ಁ", "ಂ", "ಃ", "ಃʼ", "಼" },
    { "೦", "೧", "೨", "೩", "೪", "೫", "೬", "೭", "೮", "೯", "ಓಂ", "ಽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "malayalam", {
    ScriptType::Brahmi,
    { "അ", "ആ", "ഇ", "ഈ", "ഉ", "ഊ", "ഋ", "ൠ", "ഌ", "ൡ", "എ", "ഏ", "ഐ", "ഒ", "ഓ", "ഔ", "എʼ", "ഏˇ", "ആʼ" },
    { "്", "ാ", "ി", "ീ", "ു", "ൂ", "ൃ", "ൄ", "ൢ", "ൣ", "െ", "േ", "ൈ", "ൊ", "ോ", "ൗ", "െʼ", "േˇ", "ാʼ" },
    { "ക", "ഖ", "ഗ", "ഘ", "ങ", "ച", "ഛ", "ജ", "ഝ", "ഞ", "ട", "ഠ", "ഡ", "ഢ", "ണ", "ത", "ഥ", "ദ", "ധ", "ന", "പ", "ഫ", "ബ", "ഭ", "മ", "യ", "ര", "ല", "വ", "ശ", "ഷ", "സ", "ഹ", "ള", "ഴ", "റ", "ഩ", "ക·", "ഖ·", "ഗ·", "ജ·", "ഡ·", "ഢ·", "ഫ·", "യ·", "ംˆഗ", "ംˆജ", "ംˆഡ", "ംˆദ", "ംˆബ" },
    { "ഁ", "ം", "ഃ", "ഃʼ", "·" },
    { "൦", "൧", "൨", "൩", "൪", "൫", "൬", "൭", "൮", "൯", "ഓം", "ഽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "oriya", {
    ScriptType::Brahmi,
    { "ଅ", "ଆ", "ଇ", "ଈ", "ଉ", "ଊ", "ଋ", "ୠ", "ଌ", "ୡ", "ଏ˘", "ଏ", "ଐ", "ଓ˘", "ଓ", "ଔ", "ଏʼ", "ଏˇ", "ଆʼ" },
    { "୍", "ା", "ି", "ୀ", "ୁ", "ୂ", "ୃ", "ୄ", "ୢ", "ୣ", "େ˘", "େ", "ୈ", "ୋ˘", "ୋ", "ୌ", "େʼ", "େˇ", "ାʼ" },
    { "କ", "ଖ", "ଗ", "ଘ", "ଙ", "ଚ", "ଛ", "ଜ", "ଝ", "ଞ", "ଟ", "ଠ", "ଡ", "ଢ", "ଣ", "ତ", "ଥ", "ଦ", "ଧ", "ନ", "ପ", "ଫ", "ବ", "ଭ", "ମ", "ଯ", "ର", "ଲ", "ୱ", "ଶ", "ଷ", "ସ", "ହ", "ଳ", "ଳ଼", "ର଼", "ନ଼", "କ଼", "ଖ଼", "ଗ଼", "ଜ଼", "ଡ଼", "ଢ଼", "ଫ଼", "ୟ", "ଁˆଗ", "ଁˆଜ", "ଁˆଡ", "ଁˆଦ", "ଁˆବ" },
    { "ଁ", "ଂ", "ଃ", "ଃʼ", "଼" },
    { "୦", "୧", "୨", "୩", "୪", "୫", "୬", "୭", "୮", "୯", "ଓଁ", "ଽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "romansimple", {
    ScriptType::Roman,
    { "a", "aa", "i", "ee", "u", "oo", "ri", "ree", "li", "lee", "e", "E", "ai", "o", "O", "au", "a", "e", "o" },
    { "×", "aa", "i", "ee", "u", "oo", "ri", "ree", "li", "lee", "e", "E", "ai", "o", "O", "au", "a", "e", "o" },
    { "k", "kh", "g", "gh", "n", "ch", "chh", "j", "jh", "n", "T", "Th", "D", "Dh", "N", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "sh", "sh", "s", "h", "L", "zh", "R", "n", "q", "kh", "g", "z", "r", "rh", "f", "y", "ng", "nj", "nD", "nd", "mb" },
    { "m", "m", "h", "g", "" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "om", "~", ".", "..", "gum", "ggum", "​", "‌", "‍" }
  }},
  { "tamil", {
    ScriptType::Tamil,
    { "அ", "ஆ", "இ", "ஈ", "உ", "ஊ", "ருʼ", "ரூʼ", "லுʼ", "லூʼ", "எ", "ஏ", "ஐ", "ஒ", "ஓ", "ஔ", "எʼ", "ஏˇ", "ஆʼ" },
    { "்", "ா", "ி", "ீ", "ு", "ூ", "்ருʼ", "்ரூʼ", "்லுʼ", "்லூʼ", "ெ", "ே", "ை", "ொ", "ோ", "ௌ", "ெʼ", "ேˇ", "ாʼ" },
    { "க", "க²", "க³", "க⁴", "ங", "ச", "ச²", "ஜ", "ஜ²", "ஞ", "ட", "ட²", "ட³", "ட⁴", "ண", "த", "த²", "த³", "த⁴", "ந", "ப", "ப²", "ப³", "ப⁴", "ம", "ய", "ர", "ல", "வ", "ஶ", "ஷ", "ஸ", "ஹ", "ள", "ழ", "ற", "ன", "ஃக", "ஃக²", "ஃக³", "ஃஜ", "ஃட²", "ஃட³", "ஃப", "ஃய", "ங்ˆக³", "ஞ்ˆஜ³", "ண்ˆட³", "ந்ˆத³", "ம்ˆப³" },
    { "மஂʼ", "மஂ", "꞉", "ஃ", "·" },
    { "௦", "௧", "௨", "௩", "௪", "௫", "௬", "௭", "௮", "௯", "ௐ", "(அ)", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "telugu", {
    ScriptType::Brahmi,
    { "అ", "ఆ", "ఇ", "ఈ", "ఉ", "ఊ", "ఋ", "ౠ", "ఌ", "ౡ", "ఎ", "ఏ", "ఐ", "ఒ", "ఓ", "ఔ", "ఎ॒​", "ఏ॒​", "ఒ॒​" },
    { "్", "ా", "ి", "ీ", "ు", "ూ", "ృ", "ౄ", "ౢ", "ౣ", "ె", "ే", "ై", "ొ", "ో", "ౌ", "ె॒​", "ే॒​", "ొ॒​" },
    { "క", "ఖ", "గ", "ఘ", "ఙ", "చ", "ఛ", "జ", "ఝ", "ఞ", "ట", "ఠ", "డ", "ఢ", "ణ", "త", "థ", "ద", "ధ", "న", "ప", "ఫ", "బ", "భ", "మ", "య", "ర", "ల", "వ", "శ", "ష", "స", "హ", "ళ", "ఴ", "ఱ", "న·", "క·", "ఖ·", "గ·", "జ·", "డ·", "ఢ·", "ఫ·", "య·", "ఁˆగ", "ఁˆజ", "ఁˆడ", "ఁˆద", "ఁˆబ" },
    { "ఀ", "ం", "ః", "ఃʼ", "·" },
    { "౦", "౧", "౨", "౩", "౪", "౫", "౬", "౭", "౮", "౯", "ఓం", "ఽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
#ifndef __EMSCRIPTEN__
  { "ahom", {
    ScriptType::Brahmi,
    { "𑜒", "𑜒𑜡", "𑜒𑜢", "𑜒𑜣", "𑜒𑜤", "𑜒𑜥", "𑜍𑜤ʽ", "𑜍𑜥ʽ", "𑜎𑜤ʽ", "𑜎𑜥ʽ", "𑜒𑜦𑜧ʽ", "𑜒𑜦𑜧", "𑜒𑜩", "𑜒𑜦𑜡ʽ", "𑜒𑜦𑜡", "𑜒𑜧𑜨", "𑜒𑜠", "𑜒𑜦ʽ", "𑜒𑜡ʽ" },
    { "𑜫", "𑜡", "𑜢", "𑜣", "𑜤", "𑜥", "𑜞𑜤ʽ", "𑜞𑜥ʽ", "𑜝𑜤ʽ", "𑜝𑜥ʽ", "𑜦𑜧ʽ", "𑜦𑜧", "𑜩", "𑜦𑜡ʽ", "𑜦𑜡", "𑜧𑜨", "𑜠", "𑜦ʽ", "𑜡ʽ" },
    { "𑜀", "𑜁", "𑜕", "𑜗", "𑜂", "𑜋ʽ", "𑜋", "𑜊", "𑜙", "𑜐", "𑜄ʽ", "𑜌ʽ", "𑜓ʽ", "𑜔ʽ", "𑜃ʽ", "𑜄", "𑜌", "𑜓", "𑜔", "𑜃", "𑜆", "𑜇", "𑜈", "𑜘", "𑜉", "𑜊ʽ", "𑜍", "𑜎", "𑜈ʽ", "𑜏ʽ", "𑜏ʽ", "𑜏", "𑜑", "𑜎ʽ", "𑜎ʽ", "𑜍ʽ", "𑜃ʽ", "𑜀ʽ", "𑜁ʽ", "𑜕ʽ", "𑜊ʽ", "𑜓ʽ", "𑜔ʽ", "𑜇ʽ", "𑜊ʽ", "𑜪𑜕ʽ", "𑜪𑜊ʽ", "𑜪𑜓ʽ", "𑜪𑜓ʽ", "𑜪𑜈ʽ" },
    { "𑜪ʽ", "𑜪", "𑜑𑜫ʽ", "𑜑𑜫ʽʽ", "ʽʽ" },
    { "𑜰", "𑜱", "𑜲", "𑜳", "𑜴", "𑜵", "𑜶", "𑜷", "𑜸", "𑜹", "𑜒𑜪𑜨", "'", "𑜼", "𑜽", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "aksharaa", {
    ScriptType::Roman,
    { "a", "aa", "i", "ii", "u", "uu", "ru'", "ruu'", "lu'", "luu'", "e", "ee", "ai", "o", "oo", "au", "e'", "ee'", "o'" },
    { "×", "aa", "i", "ii", "u", "uu", "ru'", "ruu'", "lu'", "luu'", "e", "ee", "ai", "o", "oo", "au", "e'", "ee'", "o'" },
    { "k", "kh", "g", "gh", "ng'", "ch", "chh", "j", "jh", "nj'", "t'", "t'h", "d'", "d'h", "n'", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "sh", "shh", "s", "h", "l'", "zh", "r'", "n;", "q", "qh", "g;", "z", "d;", "d;h", "f", "y;", "ng;", "nj;", "nd';", "nd;", "mb;" },
    { "m;", "m'", "h'", "_k", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oom'", "a;", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "ariyaka", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "ruʽ", "rUʽ", "luʽ", "lUʽ", "eʽ", "e", "ai", "oʽ", "o", "au", "eʽ", "eʽ", "A" },
    { "×", "A", "i", "I", "u", "U", "ruʽ", "rUʽ", "luʽ", "lUʽ", "eʽ", "e", "ai", "oʽ", "o", "au", "eʽ", "eʽ", "A" },
    { "k", "K", "g", "G", "~", "c", "C", "j", "J", "Y", "T", "F", "D", "V", "N", "t", "f", "d", "@", "n", "p", "P", "b", "B", "m", "y", "r", "l", "v", "sʽ", "sʽ", "s", "h", "L", "Lʽ", "rʽ", "nʽ", "kʽ", "Kʽ", "gʽ", "jʽ", "Dʽ", "Vʽ", "Pʽ", "yʽ", "Mgʽ", "Mjʽ", "MDʽ", "Mdʽ", "Mbʽ" },
    { "Mʽ", "M", "h", "hʽ", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oM", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "assamese", {
    ScriptType::Brahmi,
    { "অ", "আ", "ই", "ঈ", "উ", "ঊ", "ঋ", "ৠ", "ঌ", "ৡ", "এ˘", "এ", "ঐ", "ও˘", "ও", "ঔ", "এʼ", "এˇ", "আʼ" },
    { "্", "া", "ি", "ী", "ু", "ূ", "ৃ", "ৄ", "ৢ", "ৣ", "ে˘", "ে", "ৈ", "ো˘", "ো", "ৌ", "েʼ", "েˇ", "াʼ" },
    { "ক", "খ", "গ", "ঘ", "ঙ", "চ", "ছ", "জ", "ঝ", "ঞ", "ট", "ঠ", "ড", "ঢ", "ণ", "ত", "থ", "দ", "ধ", "ন", "প", "ফ", "ব", "ভ", "ম", "য", "র", "ল", "ৱ", "শ", "ষ", "স", "হ", "ল়", "ষ়", "র়", "ন়", "ক়", "খ়", "গ়", "জ়", "ড়", "ঢ়", "ফ়", "য়", "ঁˆগ", "ঁˆজ", "ঁˆড", "ঁˆদ", "ঁˆব" },
    { "ঁ", "ং", "ঃ", "ঃʼ", "়" },
    { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯", "ওঁ", "ঽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "avestan", {
    ScriptType::Brahmi,
    { "𐬀", "𐬁", "𐬌", "𐬍", "𐬎", "𐬏", "𐬆𐬭𐬆", "𐬇𐬭𐬇", "𐬆𐬮𐬆", "𐬇𐬮𐬇", "𐬈", "𐬉", "𐬀𐬌", "𐬊", "𐬋", "𐬀𐬎", "𐬆", "𐬇", "𐬂" },
    { "×", "𐬁", "𐬌", "𐬍", "𐬎", "𐬏", "𐬆𐬭𐬆", "𐬇𐬭𐬇", "𐬆𐬮𐬆", "𐬇𐬮𐬇", "𐬈", "𐬉", "𐬀𐬌", "𐬊", "𐬋", "𐬀𐬎", "𐬆", "𐬇", "𐬂" },
    { "𐬐", "𐬑", "𐬔", "𐬖", "𐬢", "𐬗", "𐬗ʽ", "𐬘", "𐬘ʽ", "𐬦", "𐬙ʽ", "𐬚ʽ", "𐬛ʽ", "𐬛ʽ", "𐬧", "𐬙", "𐬚", "𐬛", "𐬜", "𐬥", "𐬞", "𐬞ʽ", "𐬠", "𐬠ʽ", "𐬨", "𐬫", "𐬭", "𐬮", "𐬬", "𐬱", "𐬴", "𐬯", "𐬵", "𐬮ʽ", "𐬮ʽ", "𐬭ʽ", "𐬥ʽ", "𐬐ʽ", "𐬓", "𐬕", "𐬰", "𐬛ʽ", "𐬜ʽ", "𐬟", "𐬪", "𐬢𐬔ʽ", "𐬣𐬘ʽ", "𐬥𐬛ʽ", "𐬥𐬛ʽ", "𐬨𐬠ʽ" },
    { "𐬩ʽ", "𐬩", "𐬵", "𐬑ʽ", "ʿ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𐬋𐬨", "ʽ", "𐬼‏", "𐬽‏", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "balinese", {
    ScriptType::Brahmi,
    { "ᬅ", "ᬆ", "ᬇ", "ᬈ", "ᬉ", "ᬊ", "ᬋ", "ᬌ", "ᬍ", "ᬎ", "ᬏʽ", "ᬏ", "ᬐ", "ᬑʽ", "ᬑ", "ᬒ", "ᬳᭂʽ", "ᬳᭃʽ", "ᬆʽ" },
    { "᭄", "ᬵ", "ᬶ", "ᬷ", "ᬸ", "ᬹ", "ᬺ", "ᬻ", "ᬼ", "ᬽ", "ᬾʽ", "ᬾ", "ᬿ", "ᭀʽ", "ᭀ", "ᭁ", "ᭂ", "ᭃ", "ᬵʽ" },
    { "ᬓ", "ᬔ", "ᬕ", "ᬖ", "ᬗ", "ᬘ", "ᬙ", "ᬚ", "ᬛ", "ᬜ", "ᬝ", "ᬞ", "ᬟ", "ᬠ", "ᬡ", "ᬢ", "ᬣ", "ᬤ", "ᬥ", "ᬦ", "ᬧ", "ᬨ", "ᬩ", "ᬪ", "ᬫ", "ᬬ", "ᬭ", "ᬮ", "ᬯ", "ᬰ", "ᬱ", "ᬲ", "ᬳ", "ᬮ᬴", "ᬱ᬴", "ᬭ᬴", "ᬦ᬴", "ᬓ᬴", "ᬔ᬴", "ᬕ᬴", "ᬚ᬴", "ᬟ᬴", "ᬠ᬴", "ᬧ᬴", "ᬬ᬴", "ᬁᬕʽ", "ᬁᬚʽ", "ᬁᬟʽ", "ᬁᬤʽ", "ᬁᬩʽ" },
    { "ᬁ", "ᬂ", "ᬄ", "ᬄʽ", "᬴" },
    { "᭐", "᭑", "᭒", "᭓", "᭔", "᭕", "᭖", "᭗", "᭘", "᭙", "ᬒᬁ", "'", "᭞", "᭟", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "barahanorth", {
    ScriptType::Roman,
    { "a", "aa", "i", "ee", "u", "oo", "Ru", "RU", "~lu", "~lU", "E", "e", "ai", "O", "o", "au", "~e", "~~e", "~o" },
    { "×", "aa", "i", "ee", "u", "oo", "Ru", "RU", "~lu", "~lU", "E", "e", "ai", "O", "o", "au", "~e", "~~e", "~o" },
    { "k", "kh", "g", "gh", "~g", "c", "C", "j", "jh", "~j", "T", "Th", "D", "Dh", "N", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "S", "Sh", "s", "h", "L", "Lx", "rx", "nx", "kx", "Kx", "gx", "z", "Dx", "Dhx", "f", "yx", "~ng", "~nj", "~nD", "~nd", "~mb" },
    { "~M", "M", "H", "~H", "x" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oum", "&", "|", "||", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "barahasouth", {
    ScriptType::Roman,
    { "a", "aa", "i", "ee", "u", "oo", "Ru", "RU", "~lu", "~lU", "e", "E", "ai", "o", "O", "au", "~e", "~~e", "~o" },
    { "×", "aa", "i", "ee", "u", "oo", "Ru", "RU", "~lu", "~lU", "e", "E", "ai", "o", "O", "au", "~e", "~~e", "~o" },
    { "k", "kh", "g", "gh", "~g", "c", "C", "j", "jh", "~j", "T", "Th", "D", "Dh", "N", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "S", "Sh", "s", "h", "L", "Lx", "rx", "nx", "kx", "Kx", "gx", "z", "Dx", "Dhx", "f", "yx", "~ng", "~nj", "~nD", "~nd", "~mb" },
    { "~M", "M", "H", "~H", "x" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oum", "&", "|", "||", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "batakkaro", {
    ScriptType::Brahmi,
    { "ᯀ", "ᯀʽ", "ᯤ", "ᯤʽ", "ᯥ", "ᯥʽ", "ᯒᯬʽ", "ᯒᯬʽ", "ᯞᯬʽ", "ᯞᯬʽ", "ᯤʽ", "ᯤʽ", "ᯀᯤʽ", "ᯥʽ", "ᯥʽ", "ᯀᯥʽ", "ᯤʽ", "ᯤʽ", "ᯀʽ" },
    { "᯳", "ʽ", "ᯫ", "ᯫʽ", "ᯬ", "ᯬʽ", "ᯒᯬʽ", "ᯒᯬʽ", "ᯞᯬʽ", "ᯞᯬʽ", "ᯩ", "ᯩʽ", "ᯤʽ", "ᯭ", "ᯭʽ", "ᯥʽ", "ᯧ", "ᯩʽ", "ʽ" },
    { "ᯂ", "ᯂʽ", "ᯎ", "ᯎʽ", "ᯝ", "ᯡ", "ᯡʽ", "ᯐ", "ᯐʽ", "ᯉʽ", "ᯗʽ", "ᯗʽ", "ᯑʽ", "ᯑʽ", "ᯉʽ", "ᯗ", "ᯗʽ", "ᯑ", "ᯑʽ", "ᯉ", "ᯇ", "ᯇʽ", "ᯆ", "ᯆʽ", "ᯔ", "ᯛ", "ᯒ", "ᯞ", "ᯋ", "ᯘʽ", "ᯘʽ", "ᯘ", "ᯀʽ", "ᯞʽ", "ᯞʽ", "ᯒʽ", "ᯉʽ", "ᯂʽ", "ᯂʽ", "ᯎʽ", "ᯐʽ", "ᯑʽ", "ᯑʽ", "ᯇʽ", "ᯛʽ", "ᯰᯎʽ", "ᯰᯐʽ", "ᯢʽ", "ᯢ", "ᯣ" },
    { "ᯰʽ", "ᯰ", "ᯱ", "ᯱʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᯥᯔ᯳ʽ", "'", ".", ".", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "batakmanda", {
    ScriptType::Brahmi,
    { "ᯀ", "ᯀʽ", "ᯤ", "ᯤʽ", "ᯥ", "ᯥʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯤʽ", "ᯤʽ", "ᯀᯤʽ", "ᯥʽ", "ᯥʽ", "ᯀᯥʽ", "ᯤʽ", "ᯤʽ", "ᯀʽ" },
    { "᯲", "ʽ", "ᯪ", "ᯪʽ", "ᯮ", "ᯮʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯩ", "ᯩʽ", "ᯤʽ", "ᯬ", "ᯬʽ", "ᯥʽ", "ᯩʽ", "ᯩʽ", "ʽ" },
    { "ᯄ᯦", "ᯄ᯦ʽ", "ᯎ", "ᯎʽ", "ᯝ", "ᯚ᯦", "ᯚ᯦ʽ", "ᯐ", "ᯐʽ", "ᯠ", "ᯖʽ", "ᯖʽ", "ᯑʽ", "ᯑʽ", "ᯊʽ", "ᯖ", "ᯖʽ", "ᯑ", "ᯑʽ", "ᯊ", "ᯇ", "ᯇʽ", "ᯅ", "ᯅʽ", "ᯔ", "ᯛ", "ᯒ", "ᯞ", "ᯍ", "ᯚʽ", "ᯚʽ", "ᯚ", "ᯄ", "ᯞʽ", "ᯞʽ", "ᯒʽ", "ᯊʽ", "ᯄ᯦ʽ", "ᯄ᯦ʽ", "ᯎʽ", "ᯐʽ", "ᯑʽ", "ᯑʽ", "ᯇʽ", "ᯛʽ", "ᯰᯎʽ", "ᯰᯐʽ", "ᯰᯑʽ", "ᯰᯑʽ", "ᯰᯅʽ" },
    { "ᯰʽ", "ᯰ", "ᯄ᯲ʽ", "ᯄ᯲ʽʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᯥᯔ᯲ʽ", "'", ".", ".", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "batakpakpak", {
    ScriptType::Brahmi,
    { "ᯀ", "ᯀʽ", "ᯤ", "ᯤʽ", "ᯥ", "ᯥʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯤʽ", "ᯤʽ", "ᯀᯤʽ", "ᯥʽ", "ᯥʽ", "ᯀᯥʽ", "ᯤʽ", "ᯤʽ", "ᯀʽ" },
    { "᯲", "ʽ", "ᯪ", "ᯪʽ", "ᯮ", "ᯮʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯨ", "ᯨʽ", "ᯤʽ", "ᯬ", "ᯬʽ", "ᯥʽ", "ᯧ", "ᯩʽ", "ʽ" },
    { "ᯂ", "ᯂʽ", "ᯎ", "ᯎʽ", "ᯝ", "ᯘʽ", "ᯘʽ", "ᯐ", "ᯐʽ", "ᯉʽ", "ᯗʽ", "ᯗʽ", "ᯑʽ", "ᯑʽ", "ᯉʽ", "ᯗ", "ᯗʽ", "ᯑ", "ᯑʽ", "ᯉ", "ᯇ", "ᯇʽ", "ᯅ", "ᯅʽ", "ᯔ", "ᯛ", "ᯒ", "ᯞ", "ᯍ", "ᯘʽ", "ᯘʽ", "ᯘ", "ᯀʽ", "ᯞʽ", "ᯞʽ", "ᯒʽ", "ᯉʽ", "ᯂʽ", "ᯂʽ", "ᯎʽ", "ᯐʽ", "ᯑʽ", "ᯑʽ", "ᯇʽ", "ᯛʽ", "ᯰᯎʽ", "ᯰᯐʽ", "ᯰᯑʽ", "ᯰᯑʽ", "ᯰᯅʽ" },
    { "ᯰʽ", "ᯰ", "ᯱ", "ᯱʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᯥᯔ᯲ʽ", "'", ".", ".", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "bataksima", {
    ScriptType::Brahmi,
    { "ᯁ", "ᯁʽ", "ᯤ", "ᯤʽ", "ᯥ", "ᯥʽ", "ᯓᯮʽ", "ᯓᯮʽ", "ᯟᯮʽ", "ᯟᯮʽ", "ᯤʽ", "ᯤʽ", "ᯀᯤʽ", "ᯥʽ", "ᯥʽ", "ᯀᯥʽ", "ᯤʽ", "ᯤʽ", "ᯀʽ" },
    { "᯳", "ʽ", "ᯫ", "ᯫʽ", "ᯮ", "ᯮʽ", "ᯓᯮʽ", "ᯓᯮʽ", "ᯟᯮʽ", "ᯟᯮʽ", "ᯩ", "ᯩʽ", "ᯤʽ", "ᯬ", "ᯬʽ", "ᯭ", "ᯩʽ", "ᯩʽ", "ʽ" },
    { "ᯃ", "ᯃʽ", "ᯏ", "ᯏʽ", "ᯝ", "ᯙʽ", "ᯙʽ", "ᯐ", "ᯐʽ", "ᯠ", "ᯖʽ", "ᯖʽ", "ᯑʽ", "ᯑʽ", "ᯉʽ", "ᯖ", "ᯖʽ", "ᯑ", "ᯑʽ", "ᯉ", "ᯈ", "ᯈʽ", "ᯅ", "ᯅʽ", "ᯕ", "ᯜ", "ᯓ", "ᯟ", "ᯌ", "ᯙʽ", "ᯙʽ", "ᯙ", "ᯃʽ", "ᯟʽ", "ᯟʽ", "ᯓʽ", "ᯉʽ", "ᯃʽ", "ᯃʽ", "ᯏʽ", "ᯐʽ", "ᯑʽ", "ᯑʽ", "ᯈʽ", "ᯜʽ", "ᯰᯏʽ", "ᯰᯐʽ", "ᯰᯑʽ", "ᯰᯑʽ", "ᯰᯅʽ" },
    { "ᯰʽ", "ᯰ", "ᯱ", "ᯱʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᯥᯕ᯳ʽ", "'", ".", ".", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "bataktoba", {
    ScriptType::Brahmi,
    { "ᯀ", "ᯀʽ", "ᯤ", "ᯤʽ", "ᯥ", "ᯥʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯤʽ", "ᯤʽ", "ᯀᯤʽ", "ᯥʽ", "ᯥʽ", "ᯀᯥʽ", "ᯤʽ", "ᯤʽ", "ᯀʽ" },
    { "᯲", "ʽ", "ᯪ", "ᯪʽ", "ᯮ", "ᯮʽ", "ᯒᯮʽ", "ᯒᯮʽ", "ᯞᯮʽ", "ᯞᯮʽ", "ᯩ", "ᯩʽ", "ᯤʽ", "ᯬ", "ᯬʽ", "ᯥʽ", "ᯩʽ", "ᯩʽ", "ʽ" },
    { "ᯂ", "ᯂʽ", "ᯎ", "ᯎʽ", "ᯝ", "ᯘʽ", "ᯘʽ", "ᯐ", "ᯐʽ", "ᯠ", "ᯗʽ", "ᯗʽ", "ᯑʽ", "ᯑʽ", "ᯉʽ", "ᯗ", "ᯗʽ", "ᯑ", "ᯑʽ", "ᯉ", "ᯇ", "ᯇʽ", "ᯅ", "ᯅʽ", "ᯔ", "ᯛ", "ᯒ", "ᯞ", "ᯍ", "ᯘʽ", "ᯘʽ", "ᯘ", "ᯂʽ", "ᯞʽ", "ᯞʽ", "ᯒʽ", "ᯉʽ", "ᯂʽ", "ᯂʽ", "ᯎʽ", "ᯐʽ", "ᯑʽ", "ᯑʽ", "ᯇʽ", "ᯛʽ", "ᯰᯎʽ", "ᯰᯐʽ", "ᯰᯑʽ", "ᯰᯑʽ", "ᯰᯅʽ" },
    { "ᯰʽ", "ᯰ", "ᯂ᯲ʽ", "ᯂ᯲ʽʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᯥᯔ᯲ʽ", "'", ".", ".", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "bhaiksuki", {
    ScriptType::Brahmi,
    { "𑰀", "𑰁", "𑰂", "𑰃", "𑰄", "𑰅", "𑰆", "𑰇", "𑰈", "𑰈ʽ", "𑰊ʽ", "𑰊", "𑰋", "𑰌ʽ", "𑰌", "𑰍", "𑰊ʽ", "𑰊ʽ", "𑰁ʽ" },
    { "𑰿", "𑰯", "𑰰", "𑰱", "𑰲", "𑰳", "𑰴", "𑰵", "𑰶", "𑰶ʽ", "𑰸ʽ", "𑰸", "𑰹", "𑰺ʽ", "𑰺", "𑰻", "𑰸ʽ", "𑰸ʽ", "𑰯ʽ" },
    { "𑰎", "𑰏", "𑰐", "𑰑", "𑰒", "𑰓", "𑰔", "𑰕", "𑰖", "𑰗", "𑰘", "𑰙", "𑰚", "𑰛", "𑰜", "𑰝", "𑰞", "𑰟", "𑰠", "𑰡", "𑰢", "𑰣", "𑰤", "𑰥", "𑰦", "𑰧", "𑰨", "𑰩", "𑰪", "𑰫", "𑰬", "𑰭", "𑰮", "𑰩ʽ", "𑰩ʽ", "𑰨ʽ", "𑰡ʽ", "𑰎ʽ", "𑰏ʽ", "𑰐ʽ", "𑰕ʽ", "𑰚ʽ", "𑰛ʽ", "𑰣ʽ", "𑰧ʽ", "𑰼ʽ𑰐", "𑰼ʽ𑰕", "𑰼ʽ𑰚", "𑰼ʽ𑰟", "𑰼ʽ𑰤" },
    { "𑰼", "𑰽", "𑰾", "𑰾ʽ", "ʽ" },
    { "𑱐", "𑱑", "𑱒", "𑱓", "𑱔", "𑱕", "𑱖", "𑱗", "𑱘", "𑱙", "𑰌𑰼", "𑱀", "𑱁", "𑱂", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "brahmi", {
    ScriptType::Brahmi,
    { "𑀅", "𑀆", "𑀇", "𑀈", "𑀉", "𑀊", "𑀋", "𑀌", "𑀍", "𑀎", "𑀏ʽ", "𑀏", "𑀐", "𑀑ʽ", "𑀑", "𑀒", "𑀏ʽ", "𑀏ʽ", "𑀆ʽ" },
    { "𑁆", "𑀸", "𑀺", "𑀻", "𑀼", "𑀽", "𑀾", "𑀿", "𑁀", "𑁁", "𑁂ʽ", "𑁂", "𑁃", "𑁄ʽ", "𑁄", "𑁅", "𑁂ʽ", "𑁂ʽ", "𑀸ʽ" },
    { "𑀓", "𑀔", "𑀕", "𑀖", "𑀗", "𑀘", "𑀙", "𑀚", "𑀛", "𑀜", "𑀝", "𑀞", "𑀟", "𑀠", "𑀡", "𑀢", "𑀣", "𑀤", "𑀥", "𑀦", "𑀧", "𑀨", "𑀩", "𑀪", "𑀫", "𑀬", "𑀭", "𑀮", "𑀯", "𑀰", "𑀱", "𑀲", "𑀳", "𑀴", "𑀴ʽ", "𑀭ʽ", "𑀦ʽ", "𑀓ʽ", "𑀔ʽ", "𑀕ʽ", "𑀚ʽ", "𑀟ʽ", "𑀠ʽ", "𑀨ʽ", "𑀬ʽ", "𑀀𑀕ʽ", "𑀀𑀚ʽ", "𑀀𑀟ʽ", "𑀀𑀤ʽ", "𑀀𑀩ʽ" },
    { "𑀀", "𑀁", "𑀂", "𑀂ʽ", "ʽ" },
    { "𑁦", "𑁧", "𑁨", "𑁩", "𑁪", "𑁫", "𑁬", "𑁭", "𑁮", "𑁯", "𑀑𑀁", "ʽ", "𑁇", "𑁈", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "buginese", {
    ScriptType::Brahmi,
    { "ᨕ", "ᨕʽ", "ᨕᨗ", "ᨕᨗʽ", "ᨕᨘ", "ᨕᨘʽ", "ᨑᨘʽ", "ᨑᨘʽ", "ᨒᨘʽ", "ᨒᨘʽ", "ᨕᨙ", "ᨕᨙʽ", "ᨕᨕᨗʽ", "ᨕᨚ", "ᨕᨚʽ", "ᨕᨕᨘʽ", "ᨕᨛ", "ᨕᨛʽ", "ᨕʽ" },
    { "ʾ", "ʽ", "ᨗ", "ᨗʽ", "ᨘ", "ᨘʽ", "ᨑᨘʽ", "ᨑᨘʽ", "ᨒᨘʽ", "ᨒᨘʽ", "ᨙ", "ᨙʽ", "ᨕᨗʽ", "ᨚ", "ᨚʽ", "ᨕᨘʽ", "ᨛ", "ᨛʽ", "ʽʽʽ" },
    { "ᨀ", "ᨀʽ", "ᨁ", "ᨁʽ", "ᨂ", "ᨌ", "ᨌʽ", "ᨍ", "ᨍʽ", "ᨎ", "ᨈʽ", "ᨈʽ", "ᨉʽ", "ᨉʽ", "ᨊʽ", "ᨈ", "ᨈʽ", "ᨉ", "ᨉʽ", "ᨊ", "ᨄ", "ᨄʽ", "ᨅ", "ᨅʽ", "ᨆ", "ᨐ", "ᨑ", "ᨒ", "ᨓ", "ᨔʽ", "ᨔʽ", "ᨔ", "ᨖ", "ᨒʽ", "ᨒʽ", "ᨑʽ", "ᨊʽ", "ᨀʽ", "ᨀʽ", "ᨁʽ", "ᨍʽ", "ᨉʽ", "ᨉʽ", "ᨄʽ", "ᨐʽ", "ᨂᨁʽ", "ᨎᨍʽ", "ᨊᨉʽ", "ᨊᨉʽ", "ᨆᨅʽ" },
    { "ᨆʽ", "ᨆʽ", "ᨖʽ", "ᨖʽʼ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᨕᨚᨆʽ", "ʽʽ", "᨞", "᨞᨞", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "buhid", {
    ScriptType::Brahmi,
    { "ᝀ", "ᝀʽ", "ᝁ", "ᝁʽ", "ᝂ", "ᝂʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝁʽ", "ᝁʽ", "ᝀᝁʽ", "ᝂʽ", "ᝂʽ", "ᝀᝂʽ", "ᝁʽ", "ᝁʽ", "ᝀʽ" },
    { "ʽ", "ʽ", "ᝒ", "ᝒʽ", "ᝓ", "ᝓʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝎᝓʽ", "ᝒʽ", "ᝒʽ", "ᝁʽ", "ᝓʽ", "ᝓʽ", "ᝂʽ", "ᝒʽ", "ᝒʽ", "ʽ" },
    { "ᝃ", "ᝃʽ", "ᝄ", "ᝄʽ", "ᝅ", "ᝐʽ", "ᝐʽ", "ᝇʽ", "ᝇʽ", "ᝈʽ", "ᝆʽ", "ᝆʽ", "ᝇʽ", "ᝇʽ", "ᝈʽ", "ᝆ", "ᝆʽ", "ᝇ", "ᝇʽ", "ᝈ", "ᝉ", "ᝉʽ", "ᝊ", "ᝊʽ", "ᝋ", "ᝌ", "ᝍ", "ᝎ", "ᝏ", "ᝐʽ", "ᝐʽ", "ᝐ", "ᝃʽ", "ᝎʽ", "ᝎʽ", "ᝎʽ", "ᝈʽ", "ᝃʽ", "ᝃʽ", "ᝄʽ", "ᝇʽ", "ᝇʽ", "ᝇʽ", "ᝉʽ", "ᝌʽ", "ᝅᝄʽ", "ᝈᝇʽ", "ᝈᝇʽ", "ᝈᝇʽ", "ᝋᝊʽ" },
    { "ᝋʽ", "ᝋʽ", "ᝃʽ", "ᝃʽʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᝂᝋʽ", "ʽʽ", "᜵", "᜶", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "burmese", {
    ScriptType::Brahmi,
    { "အ", "အာ", "ဣ", "ဤ", "ဥ", "ဦ", "ၒ", "ၓ", "ၔ", "ၕ", "ဧʽ", "ဧ", "အဲ", "ဩʽ", "ဩ", "ဪ", "ဧʽ", "ဧʽ", "အာʽ" },
    { "်", "ာ", "ိ", "ီ", "ု", "ူ", "ၖ", "ၗ", "ၘ", "ၙ", "ေʽ", "ေ", "ဲ", "ောʽ", "ော", "ော်", "ေʽ", "ေʽ", "ာʽ" },
    { "က", "ခ", "ဂ", "ဃ", "င", "စ", "ဆ", "ဇ", "ဈ", "ဉ", "ဋ", "ဌ", "ဍ", "ဎ", "ဏ", "တ", "ထ", "ဒ", "ဓ", "န", "ပ", "ဖ", "ဗ", "ဘ", "မ", "ယ", "ရ", "လ", "ဝ", "ၐ", "ၑ", "သ", "ဟ", "ဠ", "ဠʽ", "ရʽ", "နʽ", "ကʽ", "ခʽ", "ဂʽ", "ဇʽ", "ဍʽ", "ဎʽ", "ဖʽ", "ယʽ", "ံဂʽ", "ံဇʽ", "ံဍʽ", "ံဒʽ", "ံဗʽ" },
    { "ံʽ", "ံ", "း", "းʽ", "ʽ" },
    { "၀", "၁", "၂", "၃", "၄", "၅", "၆", "၇", "၈", "၉", "ဥုံ", "'", "၊", "။", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "chakma", {
    ScriptType::Brahmi,
    { "𑄃", "𑄃𑄧", "𑄃𑄨", "𑄃𑄩", "𑄃𑄪", "𑄃𑄫", "𑄢𑄨ʽ", "𑄢𑄩ʽ", "𑅄𑄨ʽ", "𑅄𑄩ʽ", "𑄃𑄬ʽ", "𑄃𑄬", "𑄃𑄰", "𑄃𑄮ʽ", "𑄃𑄮", "𑄃𑄯", "𑄃𑄬𑄬ʽ", "𑄃𑄬ʽ", "𑄃𑅅" },
    { "𑄴", "𑄧", "𑄨", "𑄩", "𑄪", "𑄫", "𑄳𑄢𑄨ʽ", "𑄳𑄢𑄩ʽ", "𑄳𑅄𑄨ʽ", "𑄳𑅄𑄩ʽ", "𑄬ʽ", "𑄬", "𑄰", "𑄮ʽ", "𑄮", "𑄯", "𑄬𑄬", "𑄬ʽ", "𑅅" },
    { "𑄇", "𑄈", "𑄉", "𑄊", "𑄋", "𑄌", "𑄍", "𑄎", "𑄏", "𑄐", "𑄑", "𑄒", "𑄓", "𑄔", "𑄕", "𑄖", "𑄗", "𑄘", "𑄙", "𑄚", "𑄛", "𑄜", "𑄝", "𑄞", "𑄟", "𑄡", "𑄢", "𑄣", "𑄤", "𑄥ʽ", "𑄥ʽ", "𑄥", "𑄦", "𑄣ʽ", "𑄣ʽ", "𑄢ʽ", "𑄚ʽ", "𑄇ʽ", "𑄈ʽ", "𑄉ʽ", "𑄎ʽ", "𑄓ʽ", "𑄔ʽ", "𑄜ʽ", "𑄠", "𑄀𑄉ʽ", "𑄀𑄎ʽ", "𑄀𑄓ʽ", "𑄀𑄘ʽ", "𑄀𑄝ʽ" },
    { "𑄀", "𑄁", "𑄂", "𑄂ʼ", "ʽ" },
    { "𑄶", "𑄷", "𑄸", "𑄹", "𑄺", "𑄻", "𑄼", "𑄽", "𑄾", "𑄿", "𑄃𑄮𑄀", "'", "𑅁", "𑅂", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "cham", {
    ScriptType::Brahmi,
    { "ꨀ", "ꨀꨩ", "ꨁ", "ꨁꨩ", "ꨂ", "ꨂꨩ", "ꨣꨮ", "ꨣꨮꨩ", "ꨤꨮ", "ꨤꨮꨩ", "ꨃʽ", "ꨃ", "ꨄ", "ꨅʽ", "ꨅ", "ꨀꨯꨱ", "ꨃʽ", "ꨃʽ", "ꨀꨩʽ" },
    { "ʾ", "ꨩ", "ꨪ", "ꨫ", "ꨭ", "ꨭꨩ", "ʾꨣꨮ", "ʾꨣꨮꨩ", "ʾꨤꨮ", "ʾꨤꨮꨩ", "ꨯꨮʽ", "ꨯꨮ", "ꨰ", "ꨮʽ", "ꨯ", "ꨯꨱ", "ꨯꨮʽ", "ꨯꨮʽ", "ꨩʽ" },
    { "ꨆ", "ꨇ", "ꨈ", "ꨉ", "ꨋ", "ꨌ", "ꨍ", "ꨎ", "ꨏ", "ꨑ", "ꨓʽ", "ꨔʽ", "ꨕʽ", "ꨖʽ", "ꨘʽ", "ꨓ", "ꨔ", "ꨕ", "ꨖ", "ꨘ", "ꨚ", "ꨜ", "ꨝ", "ꨞ", "ꨠ", "ꨢ", "ꨣ", "ꨤ", "ꨥ", "ꨦʽ", "ꨦ", "ꨧ", "ꨨ", "ꨤʽ", "ꨤʽ", "ꨣʽ", "ꨘʽ", "ꨆʽ", "ꨇʽ", "ꨈʽ", "ꨎʽ", "ꨕʽ", "ꨖʽ", "ꨜʽ", "ꨥʽ", "ꩌꨈʽ", "ꨒ", "ꨙʽ", "ꨙ", "ꨡ" },
    { "ꩃ", "ꩌ", "ꩍ", "ꩍʽ", "ʽ" },
    { "꩐", "꩑", "꩒", "꩓", "꩔", "꩕", "꩖", "꩗", "꩘", "꩙", "ꨅꩌ", "'", "꩝", "꩞", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "dogra", {
    ScriptType::Brahmi,
    { "𑠀", "𑠁", "𑠂", "𑠃", "𑠄", "𑠅", "𑠤𑠭ʽ", "𑠤𑠮ʽ", "𑠥𑠭ʽ", "𑠥𑠮ʽ", "𑠆ʽ", "𑠆", "𑠇", "𑠈ʽ", "𑠈", "𑠉", "𑠆ʽ", "𑠆ʽ", "𑠁ʽ" },
    { "𑠹", "𑠬", "𑠭", "𑠮", "𑠯", "𑠰", "𑠱", "𑠲", "𑠹𑠥𑠭ʽ", "𑠹𑠥𑠮ʽ", "𑠳ʽ", "𑠳", "𑠴", "𑠵ʽ", "𑠵", "𑠶", "𑠳ʽ", "𑠳ʽ", "𑠬ʽ" },
    { "𑠊", "𑠋", "𑠌", "𑠍", "𑠎", "𑠏", "𑠐", "𑠑", "𑠒", "𑠓", "𑠔", "𑠕", "𑠖", "𑠗", "𑠘", "𑠙", "𑠚", "𑠛", "𑠜", "𑠝", "𑠞", "𑠟", "𑠠", "𑠡", "𑠢", "𑠣", "𑠤", "𑠥", "𑠦", "𑠧", "𑠨", "𑠩", "𑠪", "𑠥𑠺", "𑠨𑠺", "𑠤𑠺", "𑠝𑠺", "𑠊𑠺", "𑠋𑠺", "𑠌𑠺", "𑠑𑠺", "𑠫", "𑠗𑠺", "𑠟𑠺", "𑠣𑠺", "𑠷𑠌ʽ", "𑠷𑠑ʽ", "𑠷𑠖ʽ", "𑠷𑠛ʽ", "𑠷𑠠ʽ" },
    { "𑠷ʽ", "𑠷", "𑠸", "𑠸ʽ", "𑠺" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "𑠈𑠷", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "grantha", {
    ScriptType::Brahmi,
    { "𑌅", "𑌆", "𑌇", "𑌈", "𑌉", "𑌊", "𑌋", "𑍠", "𑌌", "𑍡", "𑌏𑌀", "𑌏", "𑌐", "𑌓𑌀", "𑌓", "𑌔", "𑌏ʽ", "𑌏ʽ", "𑌆ʽ" },
    { "𑍍", "𑌾", "𑌿", "𑍀", "𑍁", "𑍂", "𑍃", "𑍄", "𑍢", "𑍣", "𑍇𑌀", "𑍇", "𑍈", "𑍋𑌀", "𑍋", "𑍗", "𑍇ʽ", "𑍇ʽ", "𑌾ʽ" },
    { "𑌕", "𑌖", "𑌗", "𑌘", "𑌙", "𑌚", "𑌛", "𑌜", "𑌝", "𑌞", "𑌟", "𑌠", "𑌡", "𑌢", "𑌣", "𑌤", "𑌥", "𑌦", "𑌧", "𑌨", "𑌪", "𑌫", "𑌬", "𑌭", "𑌮", "𑌯", "𑌰", "𑌲", "𑌵", "𑌶", "𑌷", "𑌸", "𑌹", "𑌳", "𑌳𑌼", "𑌰𑌼", "𑌨𑌼", "𑌕𑌼", "𑌖𑌼", "𑌗𑌼", "𑌜𑌼", "𑌡𑌼", "𑌢𑌼", "𑌫𑌼", "𑌯𑌼", "𑌁ʽ𑌗", "𑌁ʽ𑌜", "𑌁ʽ𑌡", "𑌁ʽ𑌦", "𑌁ʽ𑌬" },
    { "𑌁", "𑌂", "𑌃", "𑌃ʽ", "𑌼" },
    { "௦", "௧", "௨", "௩", "௪", "௫", "௬", "௭", "௮", "௯", "𑍐", "𑌽", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "granthagrantamil", {
    ScriptType::Brahmi,
    { "অ", "আ", "ই", "ঈ", "উ", "ঊ", "ঋ", "ৠ", "ঌ", "ৡ", "এ", "এ", "ঐ", "ও", "ও", "ঔ", "এʼ", "এˇ", "আʼ" },
    { "্", "া", "ি", "ী", "ু", "ূ", "ৃ", "ৄ", "ৢ", "ৣ", "ে", "ে", "ৈ", "ো", "ো", "ৌ", "েʼ", "েˇ", "াʼ" },
    { "ক", "খ", "গ", "ঘ", "ঙ", "চ", "ছ", "জ", "ঝ", "ঞ", "ট", "ঠ", "ড", "ঢ", "ণ", "ত", "থ", "দ", "ধ", "ন", "প", "ফ", "ব", "ভ", "ম", "য", "র", "ল", "ৱ", "শ", "ষ", "স", "হ", "ৰ", "ৰ়", "র়", "ন়", "ক়", "খ়", "গ়", "জ়", "ড়", "ঢ়", "ফ়", "য়", "ঁˆগ", "ঁˆজ", "ঁˆড", "ঁˆদ", "ঁˆব" },
    { "ঁ", "ং", "ঃ", "ঃʼ", "়" },
    { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯", "ওং", "ঽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "granthapandya", {
    ScriptType::Brahmi,
    { "അ", "ആ", "ഇ", "ഈ", "ഉ", "ഊ", "ഋ", "ൠ", "ഌ", "ൡ", "ഏʽ", "ഏ", "ഐ", "ഓʽ", "ഓ", "ഔ", "ഏʽ", "ഏʽ", "ആʽ" },
    { "്", "ാ", "ി", "ീ", "ു", "ൂ", "ൃ", "ൄ", "ൢ", "ൣ", "േʽ", "േ", "ൈ", "ോʽ", "ോ", "ൗ", "േʽ", "േʽ", "ാʽ" },
    { "ക", "ഖ", "ഗ", "ഘ", "ങ", "ച", "ഛ", "ജ", "ഝ", "ഞ", "ട", "ഠ", "ഡ", "ഢ", "ണ", "ത", "ഥ", "ദ", "ധ", "ന", "പ", "ഫ", "ബ", "ഭ", "മ", "യ", "ര", "ല", "വ", "ശ", "ഷ", "സ", "ഹ", "ള", "ളʽ", "രʽ", "നʽ", "കʽ", "ഖʽ", "ഗʽ", "ജʽ", "ഡʽ", "ഢʽ", "ഫʽ", "യʽ", "ംʽഗ", "ംʽജ", "ംʽഡ", "ംʽദ", "ംʽബ" },
    { "ംʽ", "ം", "ഃ", "ഃʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ഓം", "ഽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "gunjalagondi", {
    ScriptType::Brahmi,
    { "𑵠", "𑵡", "𑵢", "𑵣", "𑵤", "𑵥", "𑶈𑶍ʽ", "𑶈𑶎ʽ", "𑵵𑶍ʽ", "𑵵𑶎ʽ", "𑵧ʽ", "𑵧", "𑵨", "𑵪ʽ", "𑵪", "𑵫", "𑵧ʽ", "𑵧ʽ", "𑵡ʽ" },
    { "𑶗", "𑶊", "𑶋", "𑶌", "𑶍", "𑶎", "𑶗𑶈𑶍ʽ", "𑶗𑶈𑶎ʽ", "𑶗𑵵𑶍ʽ", "𑶗𑵵𑶎ʽ", "𑶐ʽ", "𑶐", "𑶑", "𑶓ʽ", "𑶓", "𑶔", "𑶐ʽ", "𑶐ʽ", "𑶊ʽ" },
    { "𑵱", "𑵲", "𑵶", "𑵷", "𑶄", "𑵻", "𑵼", "𑶀", "𑶁", "𑵺ʾ", "𑵽", "𑵾", "𑶂", "𑶃", "𑵺ʿ", "𑵳", "𑵴", "𑵸", "𑵹", "𑵺", "𑶅", "𑶆", "𑵮", "𑵯", "𑵰", "𑵬", "𑶈", "𑵵", "𑵭", "𑶉ʽ", "𑶉ʽ", "𑶉", "𑶇", "𑵿", "𑵿ʽ", "𑶈ʽ", "𑵺ʽ", "𑵱ʽ", "𑵲ʽ", "𑵶ʽ", "𑶀ʽ", "𑶂ʽ", "𑶃ʽ", "𑶆ʽ", "𑵬ʽ", "𑶕𑵶ʽ", "𑶕𑶀ʽ", "𑶕𑶂ʽ", "𑶕𑵸ʽ", "𑶕𑵮ʽ" },
    { "𑶕ʽ", "𑶕", "𑶖", "𑶖ʽ", "ʽʽ" },
    { "𑶠", "𑶡", "𑶢", "𑶣", "𑶤", "𑶥", "𑶦", "𑶧", "𑶨", "𑶩", "𑶘", "ʽʽʽ", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "hanifirohingya", {
    ScriptType::Brahmi,
    { "𐴝", "𐴝𐴤", "𐴞", "𐴞𐴤", "𐴟", "𐴟𐴤", "𐴌𐴟ʽ", "𐴌𐴟𐴤ʽ", "𐴓𐴟ʽ", "𐴓𐴟𐴤ʽ", "𐴠", "𐴠𐴤", "𐴝𐴙", "𐴡", "𐴡𐴤", "𐴝𐴗", "𐴠ʽ", "𐴠𐴤ʽ", "𐴝𐴤ʽ" },
    { "×", "𐴝𐴤", "𐴞", "𐴞𐴤", "𐴟", "𐴟𐴤", "𐴌𐴟ʽ", "𐴌𐴟𐴤ʽ", "𐴓𐴟ʽ", "𐴓𐴟𐴤ʽ", "𐴠", "𐴠𐴤", "𐴝𐴙", "𐴡", "𐴡𐴤", "𐴝𐴗", "𐴠ʽ", "𐴠𐴤ʽ", "𐴝𐴤ʽ" },
    { "𐴑", "𐴑ʽ", "𐴒", "𐴒ʽ", "𐴚", "𐴆", "𐴆ʽ", "𐴅", "𐴅ʽ", "𐴛", "𐴄", "𐴄ʽ", "𐴋", "𐴋ʽ", "𐴕ʽ", "𐴃", "𐴃ʽ", "𐴊", "𐴊ʽ", "𐴕", "𐴂", "𐴂ʽ", "𐴁", "𐴁ʽ", "𐴔", "𐴘", "𐴌", "𐴓", "𐴖", "𐴐", "𐴐ʽ", "𐴏", "𐴇", "𐴓ʽ", "𐴓ʽ", "𐴌ʽ", "𐴕ʽ", "𐴑ʽ", "𐴈", "𐴒ʽ", "𐴎", "𐴍", "𐴍ʽ", "𐴉", "𐴘ʽ", "𐴣𐴒ʽ", "𐴣𐴅ʽ", "𐴣𐴋ʽ", "𐴣𐴊ʽ", "𐴣𐴁ʽ" },
    { "𐴣ʽ", "𐴣", "𐴇ʽ", "𐴈ʽ", "ʾ" },
    { "𐴰", "𐴱", "𐴲", "𐴳", "𐴴", "𐴵", "𐴶", "𐴷", "𐴸", "𐴹", "𐴀𐴡𐴴𐴔", "ʽʽ", "۔", "۔۔", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "hanunoo", {
    ScriptType::Brahmi,
    { "ᜠ", "ᜠʽ", "ᜡ", "ᜡʽ", "ᜢ", "ᜢʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜡʽ", "ᜡʽ", "ᜠᜡʽ", "ᜢʽ", "ᜢʽ", "ᜠᜢʽ", "ᜡʽ", "ᜡʽ", "ᜠʽ" },
    { "᜴", "ʽ", "ᜲ", "ᜲʽ", "ᜳ", "ᜳʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜮᜳʽ", "ᜲʽ", "ᜲʽ", "ᜡʽ", "ᜳʽ", "ᜳʽ", "ᜢʽ", "ᜲʽ", "ᜲʽ", "ʽ" },
    { "ᜣ", "ᜣʽ", "ᜤ", "ᜤʽ", "ᜥ", "ᜰʽ", "ᜰʽ", "ᜧʽ", "ᜧʽ", "ᜨʽ", "ᜦʽ", "ᜦʽ", "ᜧʽ", "ᜧʽ", "ᜨʽ", "ᜦ", "ᜦʽ", "ᜧ", "ᜧʽ", "ᜨ", "ᜩ", "ᜩʽ", "ᜪ", "ᜪʽ", "ᜫ", "ᜬ", "ᜭ", "ᜮ", "ᜯ", "ᜰʽ", "ᜰʽ", "ᜰ", "ᜣʽ", "ᜮʽ", "ᜮʽ", "ᜮʽ", "ᜨʽ", "ᜣʽ", "ᜣʽ", "ᜤʽ", "ᜧʽ", "ᜧʽ", "ᜧʽ", "ᜩʽ", "ᜬʽ", "ᜥᜤʽ", "ᜨᜧʽ", "ᜨᜧʽ", "ᜨᜧʽ", "ᜫᜪʽ" },
    { "ᜫ᜴ʽ", "ᜫ᜴ʽ", "ᜣ᜴ʽ", "ᜣ᜴ʽʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᜢᜫ᜴ʽ", "ʽʽ", "᜵", "᜶", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "hebrew", {
    ScriptType::Brahmi,
    { "אַ", "אָ", "אִ", "אִי", "אֻ", "אוּ", "רֻʽ", "רוּʽ", "לֻʽ", "לוּʽ", "אֶ", "אֵ", "אַײְʽ", "אֹ", "אוֹ", "אַוְʽ", "אָʽ", "אֵʽ", "אֹʽ" },
    { "ְ", "ָ", "ִ", "ִי", "ֻ", "וּ", "ְרֻʽ", "ְרוּʽ", "ְלֻʽ", "ְלוּʽ", "ֶ", "ֵ", "ַײְʽ", "ֹ", "וֹ", "ַוְʽ", "ָʽ", "ֵʽ", "ֹʽ" },
    { "כּ", "כʽ", "ג", "גʽ", "נʽ", "צ׳", "צ׳ʽ", "ג׳", "ג׳ʽ", "נʽ", "טʽ", "טʽ", "דʽ", "דʽ", "נʽ", "ט", "טʽ", "ד", "דʽ", "נ", "פּ", "פּʽ", "בּ", "בּʽ", "מ", "ײ", "ר", "ל", "װ", "שׁʽ", "שׁ", "ס", "ה", "לʽ", "לʽ", "רʽ", "נʽ", "ק", "כ", "גּ", "ז", "דʽ", "דʽ", "פ", "ײʽ", "נְגַʽ", "נְגַ׳ʽ", "נְדַʽ", "נְדַʽ", "מְבַּʽ" },
    { "מְʼ", "מְʼ", "הְʽ", "הְʽ", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "אוֹמְʽ", "'", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "hk", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "R", "RR", "lR", "lRR", "E", "e", "ai", "O", "o", "au", "aE", "AE", "aO" },
    { "×", "A", "i", "I", "u", "U", "R", "RR", "lR", "lRR", "E", "e", "ai", "O", "o", "au", "aE", "AE", "aO" },
    { "k", "kh", "g", "gh", "G", "c", "ch", "j", "jh", "J", "T", "Th", "D", "Dh", "N", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "z", "S", "s", "h", "L", "Z", "r2", "n2", "q", "qh", "g2", "z2", "r3", "r3h", "f", "Y", "n*g", "n*j", "n*D", "n*d", "m*b" },
    { "~", "M", "H", "K", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oM", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "iastpali", {
    ScriptType::Roman,
    { "a", "ā", "i", "ī", "u", "ū", "ṛ", "ṝ", "l̤", "l̤̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "×", "ā", "i", "ī", "u", "ū", "ṛ", "ṝ", "l̤", "l̤̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "k", "kh", "g", "gh", "ṅ", "c", "ch", "j", "jh", "ñ", "ṭ", "ṭh", "ḍ", "ḍh", "ṇ", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "ś", "ṣ", "s", "h", "ḷ", "ḻ", "ṟ", "ṉ", "q", "k͟h", "ġ", "z", "r̤", "r̤h", "f", "ẏ", "n̆g", "n̆j", "n̆ḍ", "n̆d", "m̆b" },
    { "m̐", "ṃ", "ḥ", "ḵ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oṃ", "'ʽ", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "isopali", {
    ScriptType::Roman,
    { "a", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "×", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "k", "kh", "g", "gh", "ṅ", "c", "ch", "j", "jh", "ñ", "ṭ", "ṭh", "ḍ", "ḍh", "ṇ", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "ś", "ṣ", "s", "h", "ḷ", "ḻ", "ṟ", "ṉ", "q", "k͟h", "ġ", "z", "ṛ", "ṛh", "f", "ẏ", "n̆g", "n̆j", "n̆ḍ", "n̆d", "m̆b" },
    { "m̐", "ṁ", "ḥ", "ḵ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ōṁ", "’ʽ", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "javanese", {
    ScriptType::Brahmi,
    { "ꦄ", "ꦄꦴ", "ꦆ", "ꦇ", "ꦈ", "ꦈꦴ", "ꦉ", "ꦉꦴ", "ꦊ", "ꦋ", "ꦌʽ", "ꦌ", "ꦍ", "ꦎʽ", "ꦎ", "ꦎꦴ", "ꦄꦼ", "ꦄꦼꦴ", "ꦄꦴʽ" },
    { "꧀", "ꦴ", "ꦶ", "ꦷ", "ꦸ", "ꦹ", "ꦽ", "꧀ꦉꦴ", "꧀ꦊ", "꧀ꦋ", "ꦺʽ", "ꦺ", "ꦻ", "ꦺꦴʽ", "ꦺꦴ", "ꦻꦴ", "ꦼ", "ꦼꦴ", "ꦴʽ" },
    { "ꦏ", "ꦑ", "ꦒ", "ꦓ", "ꦔ", "ꦕ", "ꦖ", "ꦗ", "ꦙ", "ꦚ", "ꦛ", "ꦜ", "ꦝ", "ꦞ", "ꦟ", "ꦠ", "ꦡ", "ꦢ", "ꦣ", "ꦤ", "ꦥ", "ꦦ", "ꦧ", "ꦨ", "ꦩ", "ꦪ", "ꦫ", "ꦭ", "ꦮ", "ꦯ", "ꦰ", "ꦱ", "ꦲ", "ꦭ꦳", "ꦰ꦳", "ꦫ꦳", "ꦤ꦳", "ꦏ꦳", "ꦑ꦳", "ꦒ꦳", "ꦗ꦳", "ꦝ꦳", "ꦞ꦳", "ꦦ꦳", "ꦪ꦳", "ꦀꦒʽ", "ꦀꦗʽ", "ꦀꦝʽ", "ꦀꦢʽ", "ꦀꦧʽ" },
    { "ꦀ", "ꦁ", "ꦃ", "ꦃʽ", "꦳" },
    { "꧐", "꧑", "꧒", "꧓", "꧔", "꧕", "꧖", "꧗", "꧘", "꧙", "ꦎꦀ", "'", "꧈", "꧉", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "kaithi", {
    ScriptType::Brahmi,
    { "𑂃", "𑂄", "𑂅", "𑂆", "𑂇", "𑂈", "𑂩𑂱ʽ", "𑂩𑂲ʽ", "𑂪𑂱ʽ", "𑂪𑂲ʽ", "𑂉ʽ", "𑂉", "𑂊", "𑂋ʽ", "𑂋", "𑂌", "𑂉ʽ", "𑂉ʽ", "𑂄ʽ" },
    { "𑂹", "𑂰", "𑂱", "𑂲", "𑂳", "𑂴", "𑂹𑂩𑂱ʽ", "𑂹𑂩𑂲ʽ", "𑂹𑂪𑂱ʽ", "𑂹𑂪𑂲ʽ", "𑂵ʽ", "𑂵", "𑂶", "𑂷ʽ", "𑂷", "𑂸", "𑂵ʽ", "𑂵ʽ", "𑂰ʽ" },
    { "𑂍", "𑂎", "𑂏", "𑂐", "𑂑", "𑂒", "𑂓", "𑂔", "𑂕", "𑂖", "𑂗", "𑂘", "𑂙", "𑂛", "𑂝", "𑂞", "𑂟", "𑂠", "𑂡", "𑂢", "𑂣", "𑂤", "𑂥", "𑂦", "𑂧", "𑂨", "𑂩", "𑂪", "𑂫", "𑂬", "𑂭", "𑂮", "𑂯", "𑂪𑂺", "𑂭𑂺", "𑂩𑂺", "𑂢𑂺", "𑂍𑂺", "𑂎𑂺", "𑂏𑂺", "𑂔𑂺", "𑂚", "𑂜", "𑂤𑂺", "𑂨𑂺", "𑂀𑂏ʽ", "𑂀𑂔ʽ", "𑂀𑂙ʽ", "𑂀𑂠ʽ", "𑂀𑂥ʽ" },
    { "𑂀", "𑂁", "𑂂", "𑂂ʽ", "𑂺" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "𑂋𑂁", "ऽ", "𑃀", "𑃁", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "kawi", {
    ScriptType::Brahmi,
    { "ꦄ", "ꦄꦴ", "ꦆ", "ꦇ", "ꦈ", "ꦈꦴ", "ꦉ", "ꦉꦴ", "ꦊ", "ꦋ", "ꦌʽ", "ꦌ", "ꦍ", "ꦎʽ", "ꦎ", "ꦎꦴ", "ꦄꦼ", "ꦄꦼʽ", "ꦄꦴʽ" },
    { "꧀", "ꦴ", "ꦶ", "ꦷ", "ꦸ", "ꦹ", "ꦽ", "꧀ꦉꦴ", "꧀ꦊ", "꧀ꦋ", "ꦺʽ", "ꦺ", "ꦻ", "ꦺꦴʽ", "ꦺꦴ", "ꦻꦴ", "ꦼ", "ꦼʽ", "ꦴʽ" },
    { "ꦏ", "ꦑ", "ꦒ", "ꦓ", "ꦔ", "ꦕ", "ꦖ", "ꦗ", "ꦙ", "ꦚ", "ꦛ", "ꦜ", "ꦝ", "ꦞ", "ꦟ", "ꦠ", "ꦡ", "ꦢ", "ꦣ", "ꦤ", "ꦥ", "ꦦ", "ꦧ", "ꦨ", "ꦩ", "ꦪ", "ꦫ", "ꦭ", "ꦮ", "ꦯ", "ꦰ", "ꦱ", "ꦲ", "ꦭ꦳", "ꦰ꦳", "ꦫ꦳", "ꦤ꦳", "ꦏ꦳", "ꦑ꦳", "ꦒ꦳", "ꦗ꦳", "ꦝ꦳", "ꦞ꦳", "ꦦ꦳", "ꦪ꦳", "ꦀꦒʽ", "ꦀꦗʽ", "ꦀꦝʽ", "ꦀꦢʽ", "ꦀꦧʽ" },
    { "ꦀ", "ꦁ", "ꦃ", "ꦃʽ", "꦳" },
    { "꧐", "꧑", "꧒", "꧓", "꧔", "꧕", "꧖", "꧗", "꧘", "꧙", "ꦎꦀ", "'", "꧈", "꧉", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khamtishan", {
    ScriptType::Brahmi,
    { "ဢ", "ဢႃ", "ဢိ", "ဢီ", "ဢု", "ဢူ", "ရိʽ", "ရီʽ", "လိʽ", "လီʽ", "ဢေʽ", "ဢေ", "ဢႆ", "ဢူဝ်ʽ", "ဢေႃ", "ဢဝ်ʽ", "ဢႄ", "ဢႄʽ", "ဢႃʽ" },
    { "်", "ႃ", "ိ", "ီ", "ု", "ူ", "်ရိʽ", "်ရီʽ", "်လိʽ", "်လီʽ", "ေʽ", "ေ", "ႆ", "ူဝ်ʽ", "ေႃ", "ဝ်ʽ", "ႄ", "ႄʽ", "ႃʽ" },
    { "က", "ၵ", "ꩠ", "ၷ", "င", "ꩡ", "ꩢ", "ꩣ", "ꩤ", "ꩥ", "ꩦ", "ꩧ", "ꩨ", "ꩩ", "ꧣ", "တ", "ထ", "ၻ", "ꩪ", "ꩫ", "ပ", "ၸ", "ၿ", "ၹ", "မ", "ယ", "ရ", "လ", "ဝ", "ꩬʽ", "ꩬʽ", "ꩬ", "ꩭ", "ꩮ", "ꩮʽ", "ရʽ", "ၼʽ", "ကʽ", "ꩱ", "ꩠʽ", "ꩲ", "ꩨʽ", "ꩩʽ", "ꩯ", "ယʽ", "ံၷʽ", "ံꩡʽ", "ံꩨʽ", "ံၻʽ", "ံၿʽ" },
    { "ံʽ", "ံ", "း", "းʽ", "ʽʽ" },
    { "႐", "႑", "႒", "႓", "႔", "႕", "႖", "႗", "႘", "႙", "ဢေႃံ", "'", "၊", "။", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "kharoshthi", {
    ScriptType::Brahmi,
    { "𐨀", "𐨀𐨌", "𐨀𐨁", "𐨀𐨁𐨌", "𐨀𐨂", "𐨀𐨂𐨌", "𐨀𐨃", "𐨀𐨃𐨌", "𐨫𐨂ʽ", "𐨫𐨂𐨌ʽ", "𐨀𐨅ʽ", "𐨀𐨅", "𐨀𐨅𐨌", "𐨀𐨆ʽ", "𐨀𐨆", "𐨀𐨆𐨌", "𐨀𐨅ʽ", "𐨀𐨅ʽ", "𐨀𐨌ʽ" },
    { "𐨿", "𐨌", "𐨁", "𐨁𐨌", "𐨂", "𐨂𐨌", "𐨃", "𐨃𐨌", "𐨿𐨫𐨂ʽ", "𐨿𐨫𐨂𐨌ʽ", "𐨅ʽ", "𐨅", "𐨅𐨌", "𐨆ʽ", "𐨆", "𐨆𐨌", "𐨅ʽ", "𐨅ʽ", "𐨌ʽ" },
    { "𐨐", "𐨑", "𐨒", "𐨓", "𐨣ʽ", "𐨕", "𐨖", "𐨗", "𐨗ʽ", "𐨙", "𐨚", "𐨛", "𐨜", "𐨝", "𐨞", "𐨟", "𐨠", "𐨡", "𐨢", "𐨣", "𐨤", "𐨥", "𐨦", "𐨧", "𐨨", "𐨩", "𐨪", "𐨫", "𐨬", "𐨭", "𐨮", "𐨯", "𐨱", "𐨫ʽ", "𐨫ʽ", "𐨪ʽ", "𐨣ʽ", "𐨲", "𐨑ʽ", "𐨒ʽ", "𐨰", "𐨜ʽ", "𐨝ʽ", "𐨥ʽ", "𐨩ʽ", "𐨎𐨒ʽ", "𐨎𐨗ʽ", "𐨎𐨜ʽ", "𐨎𐨡ʽ", "𐨎𐨦ʽ" },
    { "𐨎ʽ", "𐨎", "𐨏", "𐨏ʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𐨀𐨅𐨎", "ʽ", "𐩖", "𐩗", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khmer", {
    ScriptType::Brahmi,
    { "អ", "អា", "ឥ", "ឦ", "ឧ", "ឩ", "ឫ", "ឬ", "ឭ", "ឮ", "ឯʽ", "ឯ", "ឰ", "ឱʽ", "ឱ", "ឳ", "ឯʽ", "ឯʽ", "អាʽ" },
    { "៑", "ា", "ិ", "ី", "ុ", "ូ", "្ឫ", "្ឬ", "្ឭ", "្ឮ", "េʽ", "េ", "ៃ", "ោʽ", "ោ", "ៅ", "េʽ", "េʽ", "ាʽ" },
    { "ក", "ខ", "គ", "ឃ", "ង", "ច", "ឆ", "ជ", "ឈ", "ញ", "ដ", "ឋ", "ឌ", "ឍ", "ណ", "ត", "ថ", "ទ", "ធ", "ន", "ប", "ផ", "ព", "ភ", "ម", "យ", "រ", "ល", "វ", "ឝ", "ឞ", "ស", "ហ", "ឡ", "ឡʽ", "រʽ", "នʽ", "កʽ", "ខʽ", "គʽ", "ជʽ", "ឌʽ", "ឍʽ", "ផʽ", "យʽ", "ំគʽ", "ំជʽ", "ំឌʽ", "ំទʽ", "ំពʽ" },
    { "ំʽ", "ំ", "ះ", "ះʽ", "ʽ" },
    { "០", "១", "២", "៣", "៤", "៥", "៦", "៧", "៨", "៩", "ឱំ", "ៜ", "។", "៕", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khojki", {
    ScriptType::Brahmi,
    { "𑈀", "𑈁", "𑈂", "𑈂ʽ", "𑈃", "𑈃ʽ", "𑈦𑈭ʽ", "𑈦𑈮ʽ", "𑈧𑈭ʽ", "𑈧𑈮ʽ", "𑈄ʽ", "𑈄", "𑈅", "𑈆ʽ", "𑈆", "𑈇", "𑈄ʽ", "𑈄ʽ", "𑈁ʽ" },
    { "𑈵", "𑈬", "𑈭", "𑈮", "𑈯", "𑈯ʽ", "𑈵𑈦𑈭ʽ", "𑈵𑈦𑈮ʽ", "𑈵𑈧𑈭ʽ", "𑈵𑈧𑈮ʽ", "𑈰ʽ", "𑈰", "𑈱", "𑈲ʽ", "𑈲", "𑈳", "𑈰ʽ", "𑈰ʽ", "𑈬ʽ" },
    { "𑈈", "𑈉", "𑈊", "𑈌", "𑈍", "𑈎", "𑈏", "𑈐", "𑈐ʽ", "𑈓", "𑈔", "𑈕", "𑈖", "𑈗", "𑈘", "𑈙", "𑈚", "𑈛", "𑈝", "𑈞", "𑈟", "𑈠", "𑈡", "𑈣", "𑈤", "𑈥", "𑈦", "𑈧", "𑈨", "𑈩𑈶", "𑈩𑈶ʽ", "𑈩", "𑈪", "𑈫", "𑈫𑈶", "𑈦𑈶", "𑈞𑈶", "𑈈𑈶", "𑈉𑈶", "𑈊𑈶", "𑈐𑈶", "𑈖𑈶", "𑈗𑈶", "𑈠𑈶", "𑈥𑈶", "𑈴𑈊ʽ", "𑈴𑈐ʽ", "𑈴𑈖ʽ", "𑈴𑈛ʽ", "𑈴𑈡ʽ" },
    { "𑈴ʽ", "𑈴", "𑈪𑈵ʽ", "𑈪𑈵ʽʽ", "𑈶" },
    { "૦", "૧", "૨", "૩", "૪", "૫", "૬", "૭", "૮", "૯", "𑈆𑈴", "ʽʽ", "𑈸", "𑈹", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khomthai", {
    ScriptType::Brahmi,
    { "อ", "อา", "อิ", "อี", "อุ", "อู", "รุʽ", "รูʽ", "ลุʽ", "ลูʽ", "อเʽ", "อเ", "อยฺʽ", "อโʽ", "อโ", "อวฺʽ", "อแʽ", "อแ", "อาʽ" },
    { "ฺ", "า", "ิ", "ี", "ุ", "ู", "ฺฤ", "ฺฤๅ", "ฺลุʽ", "ฺลูʽ", "เʽ", "เ", "ใ", "โʽ", "โ", "วฺʽ", "แʽ", "แ", "าʽ" },
    { "ก", "ข", "ค", "ฆ", "ง", "จ", "ฉ", "ช", "ฌ", "ญ", "ฏ", "ฐ", "ฑ", "ฒ", "ณ", "ต", "ถ", "ท", "ธ", "น", "ป", "ผ", "พ", "ภ", "ม", "ย", "ร", "ล", "ว", "สʽ", "สʽ", "ส", "ห", "ฬ", "ฬʽ", "รʽ", "นʽ", "กʽ", "ขʽ", "คʽ", "ชʽ", "รʽ", "รฺหʽ", "ผʽ", "ยʽ", "ํคʽ", "ํชʽ", "ํฑʽ", "ํทʽ", "ํพʽ" },
    { "ํʽ", "ํ", "หฺʽ", "หฺʽʽ", "ʽ" },
    { "๐", "๑", "๒", "๓", "๔", "๕", "๖", "๗", "๘", "๙", "อโํ", "ʽʽ", "ฯ", "๚", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khudawadi", {
    ScriptType::Brahmi,
    { "𑊰", "𑊱", "𑊲", "𑊳", "𑊴", "𑊵", "𑋙𑋡ʽ", "𑋙𑋢ʽ", "𑋚𑋡ʽ", "𑋚𑋢ʽ", "𑊶ʽ", "𑊶", "𑊷", "𑊸ʽ", "𑊸", "𑊹", "𑊶ʽ", "𑊶ʽ", "𑊱ʽ" },
    { "𑋪", "𑋠", "𑋡", "𑋢", "𑋣", "𑋤", "𑋪𑋙𑋡ʽ", "𑋪𑋙𑋢ʽ", "𑋪𑋚𑋡ʽ", "𑋪𑋚𑋢ʽ", "𑋥ʽ", "𑋥", "𑋦", "𑋧ʽ", "𑋧", "𑋨", "𑋥ʽ", "𑋥ʽ", "𑋠ʽ" },
    { "𑊺", "𑊻", "𑊼", "𑊾", "𑊿", "𑋀", "𑋁", "𑋂", "𑋄", "𑋅", "𑋆", "𑋇", "𑋈", "𑋋", "𑋌", "𑋍", "𑋎", "𑋏", "𑋐", "𑋑", "𑋒", "𑋓", "𑋔", "𑋖", "𑋗", "𑋘", "𑋙", "𑋚", "𑋛", "𑋜", "𑋜𑋩", "𑋝", "𑋞", "𑋚𑋩", "𑋚𑋩ʽ", "𑋙𑋩", "𑋑𑋩", "𑊺𑋩", "𑊻𑋩", "𑊾𑋩", "𑋂𑋩", "𑋊", "𑋋𑋩", "𑋓𑋩", "𑋘𑋩", "𑋟𑊼ʽ", "𑋟𑋂ʽ", "𑋟𑋈ʽ", "𑋟𑋏ʽ", "𑋟𑋔ʽ" },
    { "𑋟ʽ", "𑋟", "𑋞𑋪ʽ", "𑋞𑋪ʽʽ", "𑋩" },
    { "𑋰", "𑋱", "𑋲", "𑋳", "𑋴", "𑋵", "𑋶", "𑋷", "𑋸", "𑋹", "𑊸𑋟", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "khuentham", {
    ScriptType::Brahmi,
    { "ᩋ", "ᩋᩣ", "ᩍ", "ᩎ", "ᩏ", "ᩐ", "ᩂ", "ᩂᩣ", "ᩄ", "ᩄᩣ", "ᩑʽ", "ᩑ", "ᩋᩱ", "ᩒʽ", "ᩒ", "ᩏᩫᩣ", "ᩑʽ", "ᩑʽ", "ᩋᩣʽ" },
    { "᩺", "ᩣ", "ᩥ", "ᩦ", "ᩩ", "ᩪ", "᩺ᩂ", "᩺ᩂᩣ", "᩺ᩄ", "᩺ᩄᩣ", "ᩮʽ", "ᩮ", "ᩱ", "ᩮᩣʽ", "ᩮᩣ", "ᩮᩫᩣ", "ᩮʽ", "ᩮʽ", "ᩣʽ" },
    { "ᨠ", "ᨡ", "ᨣ", "ᨥ", "ᨦ", "ᨧ", "ᨨ", "ᨩ", "ᨫ", "ᨬ", "ᨭ", "ᨮ", "ᨯ", "ᨰ", "ᨱ", "ᨲ", "ᨳ", "ᨴ", "ᨵ", "ᨶ", "ᨸ", "ᨹ", "ᨻ", "ᨽ", "ᨾ", "ᨿ", "ᩁ", "ᩃ", "ᩅ", "ᩆ", "ᩇ", "ᩈ", "ᩉ", "ᩊ", "ᩊʽ", "ᩁʽ", "ᨶʽ", "ᨠʽ", "ᨡʽ", "ᨣʽ", "ᨩʽ", "ᨯʽ", "ᨰʽ", "ᨹʽ", "ᨿʽ", "ᩴᨣʽ", "ᩴᨩʽ", "ᩴᨯʽ", "ᩴᨴʽ", "ᩴᨽʽ" },
    { "ᩴʽ", "ᩴ", "ᩡ", "ᩡʽ", "ʽ" },
    { "᪐", "᪑", "᪒", "᪓", "᪔", "᪕", "᪖", "᪗", "᪘", "᪙", "ᩒᩴ", "'", "᪨", "᪩", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "lao", {
    ScriptType::Brahmi,
    { "ອ", "ອາ", "ອິ", "ອີ", "ອຸ", "ອູ", "ຣຸʽ", "ຣູʽ", "ລຸʽ", "ລູʽ", "ອເະ", "ອເ", "ອໄ", "ອໂະ", "ອໂ", "ອເົາ", "ອແະ", "ອແ", "ອເາະ" },
    { "຺", "າ", "ິ", "ີ", "ຸ", "ູ", "຺ຣຸʽ", "຺ຣູʽ", "຺ລຸʽ", "຺ລູʽ", "ເະ", "ເ", "ໄ", "ໂະ", "ໂ", "ເົາ", "ແະ", "ແ", "ເາະ" },
    { "ກ", "ຂ", "ຄ", "ຄʽ", "ງ", "ຈ", "ຈʽ", "ຊ", "ຊʽ", "ຍ", "ຕʽ", "ຖʽ", "ທʽ", "ທʽ", "ນʽ", "ຕ", "ຖ", "ທ", "ທʽ", "ນ", "ປ", "ຜ", "ພ", "ພʽ", "ມ", "ຢ", "ຣ", "ລ", "ວ", "ສʽ", "ສʽ", "ສ", "ຫ", "ລʽ", "ລʽ", "ຮ", "ນʽ", "ກʽ", "ຂʽ", "ຄʽ", "ຊʽ", "ທʽ", "ທʽ", "ຝ", "ຢʽ", "ໍຄʽ", "ໍຊʽ", "ໍທʽ", "ໍທʽ", "ໍພʽ" },
    { "ໍʽ", "ໍ", "ຫ຺ʽ", "ຫ຺ʽʽ", "" },
    { "໐", "໑", "໒", "໓", "໔", "໕", "໖", "໗", "໘", "໙", "ໂອງ຺", "'", "ຯ", "ຯຯ", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "lao2", {
    ScriptType::Brahmi,
    { "ອ", "ອາ", "ອິ", "ອີ", "ອຸ", "ອູ", "ຣຸʽ", "ຣູʽ", "ລຸʽ", "ລູʽ", "ເອະ", "ເອ", "ໄອ", "ໂອະ", "ໂອ", "ເອົາ", "ແອະ", "ແອ", "ເອາະ" },
    { "຺", "າ", "ິ", "ີ", "ຸ", "ູ", "຺ຣຸʽ", "຺ຣູʽ", "຺ລຸʽ", "຺ລູʽ", "ເະ", "ເ", "ໄ", "ໂະ", "ໂ", "ເົາ", "ແະ", "ແ", "ເາະ" },
    { "ກ", "ຂ", "ຄ", "ຄʽ", "ງ", "ຈ", "ສ", "ຊ", "ຊʽ", "ຍ", "ຕʽ", "ຖʽ", "ທʽ", "ທʽ", "ນʽ", "ຕ", "ຖ", "ທ", "ທʽ", "ນ", "ປ", "ຜ", "ພ", "ພʽ", "ມ", "ຍ", "ຣ", "ລ", "ວ", "ສʽ", "ສʽ", "ສ", "ຫ", "ລʽ", "ລʽ", "ຮ", "ນʽ", "ກʽ", "ຂʽ", "ຄʽ", "ຊʽ", "ດʽ", "ທʽ", "ຝ", "ຢʽ", "ໍຄʽ", "ໍຊʽ", "ໍທʽ", "ໍທʽ", "ໍພʽ" },
    { "ໍʽ", "ໍ", "ຫ຺ʽ", "ຫ຺ʽʽ", "" },
    { "໐", "໑", "໒", "໓", "໔", "໕", "໖", "໗", "໘", "໙", "ໂອງ຺", "'", "ຯ", "ຯຯ", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "laopali", {
    ScriptType::Brahmi,
    { "ອ", "ອາ", "ອິ", "ອີ", "ອຸ", "ອູ", "ຣຸʽ", "ຣູʽ", "ລຸʽ", "ລູʽ", "ອເະ", "ອເ", "ອໄ", "ອໂະ", "ອໂ", "ອເົາ", "ອແະ", "ອແ", "ອເາະ" },
    { "຺", "າ", "ິ", "ີ", "ຸ", "ູ", "຺ຣຸʽ", "຺ຣູʽ", "຺ລຸʽ", "຺ລູʽ", "ເະ", "ເ", "ໄ", "ໂະ", "ໂ", "ເົາ", "ແະ", "ແ", "ເາະ" },
    { "ກ", "ຂ", "ຄ", "ຆ", "ງ", "ຈ", "ຉ", "ຊ", "ຌ", "ຎ", "ຏ", "ຐ", "ຑ", "ຒ", "ຓ", "ຕ", "ຖ", "ທ", "ຘ", "ນ", "ປ", "ຜ", "ພ", "ຠ", "ມ", "ຍ", "ຣ", "ລ", "ວ", "ຨ", "ຩ", "ສ", "ຫ", "ຬ", "ຬʽ", "ຮ", "ນʽ", "ກʽ", "ຂʽ", "ຄʽ", "ຊʽ", "ຐʽ", "ຑʽ", "ຝ", "ຢ", "ໍຄʽ", "ໍຊʽ", "ໍຐʽ", "ໍທʽ", "ໍພʽ" },
    { "ໍʽ", "ໍ", "ຫ໌", "ຫ໌ʽ", "ʽ" },
    { "໐", "໑", "໒", "໓", "໔", "໕", "໖", "໗", "໘", "໙", "ໂອໍʽ", "'", "ຯ", "ຯຯ", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "laotham", {
    ScriptType::Brahmi,
    { "ᩋ", "ᩋᩣ", "ᩍ", "ᩎ", "ᩏ", "ᩐ", "ᩂ", "ᩂᩣ", "ᩄ", "ᩄᩣ", "ᩑʽ", "ᩑ", "ᩋᩱ", "ᩒʽ", "ᩒ", "ᩏᩫᩣ", "ᩑʽ", "ᩑʽ", "ᩋᩣʽ" },
    { "᩺", "ᩣ", "ᩥ", "ᩦ", "ᩩ", "ᩪ", "᩺ᩂ", "᩺ᩂᩣ", "᩺ᩄ", "᩺ᩄᩣ", "ᩮʽ", "ᩮ", "ᩱ", "ᩮᩣʽ", "ᩮᩣ", "ᩮᩫᩣ", "ᩮʽ", "ᩮʽ", "ᩣʽ" },
    { "ᨠ", "ᨡ", "ᨣ", "ᨥ", "ᨦ", "ᨧ", "ᨨ", "ᨩ", "ᨫ", "ᨬ", "ᨭ", "ᨮ", "ᨯ", "ᨰ", "ᨱ", "ᨲ", "ᨳ", "ᨴ", "ᨵ", "ᨶ", "ᨸ", "ᨹ", "ᨻ", "ᨽ", "ᨾ", "ᨿ", "ᩁ", "ᩃ", "ᩅ", "ᩆ", "ᩇ", "ᩈ", "ᩉ", "ᩊ", "ᩊʽ", "ᩁʽ", "ᨶʽ", "ᨠʽ", "ᨡʽ", "ᨣʽ", "ᨩʽ", "ᨯʽ", "ᨰʽ", "ᨹʽ", "ᨿʽ", "ᩴᨣʽ", "ᩴᨩʽ", "ᩴᨯʽ", "ᩴᨴʽ", "ᩴᨽʽ" },
    { "ᩴʽ", "ᩴ", "ᩡ", "ᩡʽ", "ʽ" },
    { "᪐", "᪑", "᪒", "᪓", "᪔", "᪕", "᪖", "᪗", "᪘", "᪙", "ᩒᩴ", "'", "᪨", "᪩", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "lepcha", {
    ScriptType::Brahmi,
    { "ᰣ", "ᰣᰦ", "ᰣᰧ", "ᰣᰧᰶ", "ᰣᰪ", "ᰣᰫ", "ᰛᰪʽ", "ᰛᰫʽ", "ᰜᰪʽ", "ᰜᰫʽ", "ᰣᰬʽ", "ᰣᰬ", "ᰣᰬʽ", "ᰣᰨʽ", "ᰣᰨ", "ᰣᰩ", "ᰣᰬʽ", "ᰣᰬʽ", "ᰣᰦʽ" },
    { "ʾ", "ᰦ", "ᰧ", "ᰧᰶ", "ᰪ", "ᰫ", "ʾᰛᰪʽ", "ʾᰛᰫʽ", "ʾᰜᰪʽ", "ʾᰜᰫʽ", "ᰬʽ", "ᰬ", "ᰬʽ", "ᰨʽ", "ᰨ", "ᰩ", "ᰬʽ", "ᰬʽ", "ᰦʽ" },
    { "ᰀ", "ᰂ", "ᰃ", "ᰃʽ", "ᰅ", "ᰆ", "ᰇ", "ᰈ", "ᰈʽ", "ᰉ", "ᱍ", "ᱎ", "ᱏ", "ᱏʽ", "ᰍʽ", "ᰊ", "ᰋ", "ᰌ", "ᰌʽ", "ᰍ", "ᰎ", "ᰐ", "ᰓ", "ᰓʽ", "ᰕ", "ᰚ", "ᰛ", "ᰜ", "ᰟ", "ᰡ", "ᰡ᰷", "ᰠ", "ᰝ", "ᰜ᰷", "ᰜ᰷ʽ", "ᰛ᰷", "ᰍ᰷", "ᰀ᰷", "ᰂ᰷", "ᰃ᰷", "ᰈ᰷", "ᱏ᰷", "ᱏ᰷ʽ", "ᰑ", "ᰚ᰷", "ᰵᰃʽ", "ᰰᰈʽ", "ᰰᰌʽ", "ᰰᰌʽ", "ᰮᰓʽ" },
    { "ᰴʽ", "ᰴ", "ᰝʽ", "ᰝʽʼ", "᰷" },
    { "᱀", "᱁", "᱂", "᱃", "᱄", "᱅", "᱆", "᱇", "᱈", "᱉", "ᰣᰨᰴ", "'", "᰻", "᰼", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "limbu", {
    ScriptType::Brahmi,
    { "ᤀ", "ᤀᤠ", "ᤀᤡ", "ᤀᤡ᤺", "ᤀᤢ", "ᤀᤢ᤺", "ᤖᤢʽ", "ᤖᤢ᤺ʽ", "ᤗᤢʽ", "ᤗᤢ᤺ʽ", "ᤀᤧ", "ᤀᤣ", "ᤀᤤ", "ᤀᤨ", "ᤀᤥ", "ᤀᤦ", "ᤀᤧʽ", "ᤀᤣʽ", "ᤀᤨʽ" },
    { "᤻", "ᤠ", "ᤡ", "ᤡ᤺", "ᤢ", "ᤢ᤺", "᤻ᤖᤢʽ", "᤻ᤖᤢ᤺ʽ", "᤻ᤗᤢʽ", "᤻ᤗᤢ᤺ʽ", "ᤧ", "ᤣ", "ᤤ", "ᤨ", "ᤥ", "ᤦ", "ᤧʽ", "ᤣʽ", "ᤨʽ" },
    { "ᤁ", "ᤂ", "ᤃ", "ᤄ", "ᤅ", "ᤆ", "ᤇ", "ᤈ", "ᤉ", "ᤊ", "ᤋʽ", "ᤌʽ", "ᤍʽ", "ᤎʽ", "ᤏʽ", "ᤋ", "ᤌ", "ᤍ", "ᤎ", "ᤏ", "ᤐ", "ᤑ", "ᤒ", "ᤓ", "ᤔ", "ᤕ", "ᤖ", "ᤗ", "ᤘ", "ᤙ", "ᤚ", "ᤛ", "ᤜ", "ᤗʽ", "ᤗʽ", "ᤖʽ", "ᤏʽ", "ᤁʽ", "ᤂʽ", "ᤃʽ", "ᤈʽ", "ᤍʽ", "ᤎʽ", "ᤑʽ", "ᤕʽ", "ᤲᤃʽ", "ᤲᤈʽ", "ᤲᤍʽ", "ᤲᤍʽ", "ᤲᤒʽ" },
    { "ᤲʽ", "ᤲ", "ᤜ᤻ʽ", "ᤜ᤻ʽʼ", "ʽ" },
    { "᥆", "᥇", "᥈", "᥉", "᥊", "᥋", "᥌", "᥍", "᥎", "᥏", "ᤀᤥᤲ", "'", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "luetham", {
    ScriptType::Brahmi,
    { "ᩋ", "ᩋᩣ", "ᩍ", "ᩎ", "ᩏ", "ᩐ", "ᩂ", "ᩂᩣ", "ᩄ", "ᩄᩣ", "ᩑʽ", "ᩑ", "ᩋᩱ", "ᩒʽ", "ᩒ", "ᩏᩫᩣ", "ᩑʽ", "ᩑʽ", "ᩋᩣʽ" },
    { "᩺", "ᩣ", "ᩥ", "ᩦ", "ᩩ", "ᩪ", "᩺ᩂ", "᩺ᩂᩣ", "᩺ᩄ", "᩺ᩄᩣ", "ᩮʽ", "ᩮ", "ᩱ", "ᩮᩣʽ", "ᩮᩣ", "ᩮᩫᩣ", "ᩮʽ", "ᩮʽ", "ᩣʽ" },
    { "ᨠ", "ᨡ", "ᨣ", "ᨥ", "ᨦ", "ᨧ", "ᨨ", "ᨩ", "ᨫ", "ᨬ", "ᨭ", "ᨮ", "ᨯ", "ᨰ", "ᨱ", "ᨲ", "ᨳ", "ᨴ", "ᨵ", "ᨶ", "ᨸ", "ᨹ", "ᨻ", "ᨽ", "ᨾ", "ᨿ", "ᩁ", "ᩃ", "ᩅ", "ᩆ", "ᩇ", "ᩈ", "ᩉ", "ᩊ", "ᩊʽ", "ᩁʽ", "ᨶʽ", "ᨠʽ", "ᨡʽ", "ᨣʽ", "ᨩʽ", "ᨯʽ", "ᨰʽ", "ᨹʽ", "ᨿʽ", "ᩴᨣʽ", "ᩴᨩʽ", "ᩴᨯʽ", "ᩴᨴʽ", "ᩴᨽʽ" },
    { "ᩴʽ", "ᩴ", "ᩡ", "ᩡʽ", "ʽ" },
    { "᪐", "᪑", "᪒", "᪓", "᪔", "᪕", "᪖", "᪗", "᪘", "᪙", "ᩒᩴ", "'", "᪨", "᪩", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "mahajani", {
    ScriptType::Brahmi,
    { "𑅐", "𑅐ʽ", "𑅑", "𑅑ʽ", "𑅒", "𑅒ʽ", "𑅭𑅒ʽ", "𑅭𑅒ʽ", "𑅮𑅒ʽ", "𑅮𑅒ʽ", "𑅓ʽ", "𑅓", "𑅑ʽ", "𑅔ʽ", "𑅔", "𑅒ʽ", "𑅓ʽ", "𑅓ʽ", "𑅐ʽ" },
    { "ʾ", "𑅐ʽ", "𑅑ʽ", "ʿ𑅑", "𑅒ʽ", "𑅒ʽ", "𑅭𑅒ʽ", "𑅭𑅒ʽ", "𑅮𑅒ʽ", "𑅮𑅒ʽ", "𑅓ʽ", "𑅓ʽ", "𑅑ʽ", "𑅔ʽ", "𑅔ʽ", "𑅒ʽ", "𑅓ʽ", "𑅓ʽ", "𑅐ʽ" },
    { "𑅕", "𑅖", "𑅗", "𑅘", "𑅧ʽ", "𑅙", "𑅚", "𑅛", "𑅜", "𑅝", "𑅞", "𑅟", "𑅠", "𑅡", "𑅢", "𑅣", "𑅤", "𑅥", "𑅦", "𑅧", "𑅨", "𑅩", "𑅪", "𑅫", "𑅬", "𑅛ʽ", "𑅭", "𑅮", "𑅯", "𑅰𑅳", "𑅖𑅳ʽ", "𑅰", "𑅱", "𑅮𑅳", "𑅮𑅳ʽ", "𑅭𑅳", "𑅧𑅳", "𑅕𑅳", "𑅖𑅳", "𑅗𑅳", "𑅛𑅳", "𑅲", "𑅡𑅳", "𑅩𑅳", "𑅛ʽ", "𑅧𑅗ʽ", "𑅧𑅛ʽ", "𑅧𑅠ʽ", "𑅧𑅥ʽ", "𑅧𑅪ʽ" },
    { "𑅧ʽ", "𑅧ʽ", "𑅱ʽ", "𑅱ʽʽ", "𑅳" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "𑅔𑅬", "ʽʽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "makasar", {
    ScriptType::Brahmi,
    { "𑻱", "𑻱ʽ", "𑻱𑻳", "𑻱𑻳ʽ", "𑻱𑻴", "𑻱𑻴ʽ", "𑻭𑻴ʽ", "𑻭𑻴ʽ", "𑻮𑻴ʽ", "𑻮𑻴ʽ", "𑻱𑻵", "𑻱𑻵ʽ", "𑻱𑻱𑻳ʽ", "𑻱𑻶", "𑻱𑻶ʽ", "𑻱𑻱𑻴ʽ", "𑻱𑻵ʽ", "𑻱ʽ", "𑻱ʽ" },
    { "ʾ", "ʽ", "𑻳", "𑻳ʽ", "𑻴", "𑻴ʽ", "𑻭𑻴ʽ", "𑻭𑻴ʽ", "𑻮𑻴ʽ", "𑻮𑻴ʽ", "𑻵ʽ", "𑻵ʽ", "𑻱𑻳ʽ", "𑻶ʽ", "𑻶ʽ", "𑻱𑻴ʽ", "𑻵ʽ", "𑻵ʽ", "ʽʽʽ" },
    { "𑻠", "𑻠ʽ", "𑻡", "𑻡ʽ", "𑻢", "𑻩", "𑻩ʽ", "𑻪", "𑻪ʽ", "𑻫", "𑻦ʽ", "𑻦ʽ", "𑻧ʽ", "𑻧ʽ", "𑻨ʽ", "𑻦", "𑻦ʽ", "𑻧", "𑻧ʽ", "𑻨", "𑻣", "𑻣ʽ", "𑻤", "𑻤ʽ", "𑻥", "𑻬", "𑻭", "𑻮", "𑻯", "𑻰ʽ", "𑻰ʽ", "𑻰", "𑻠ʽ", "𑻮ʽ", "𑻮ʽ", "𑻭ʽ", "𑻨ʽ", "𑻠ʽ", "𑻠ʽ", "𑻡ʽ", "𑻪ʽ", "𑻧ʽ", "𑻧ʽ", "𑻣ʽ", "𑻬ʽ", "𑻥𑻡ʽ", "𑻥𑻪ʽ", "𑻥𑻧ʽ", "𑻥𑻧ʽ", "𑻥𑻤ʽ" },
    { "𑻥ʽ", "𑻥ʽ", "ʽʽʽ", "ʽʽʽʼ", "ʽ" },
    { "۰", "۱", "۲", "۳", "۴", "۵", "۶", "۷", "۸", "۹", "𑻱𑻶𑻥ʽ", "ʽʽ", "𑻷", "𑻷𑻷", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "marchen", {
    ScriptType::Brahmi,
    { "𑲏", "𑲏𑲰", "𑲏𑲱", "𑲏𑲱𑲰", "𑲏𑲲", "𑲏𑲲𑲰", "𑲊𑲱ʽ", "𑲊𑲱𑲰ʽ", "𑲋𑲱ʽ", "𑲋𑲱𑲰ʽ", "𑲏𑲳ʽ", "𑲏𑲳", "𑲏𑲳𑲰", "𑲏𑲴ʽ", "𑲏𑲴", "𑲏𑲰𑲴", "𑲏𑲳ʽ", "𑲏𑲳ʽ", "𑲏𑲰ʽ" },
    { "ʾ", "𑲰", "𑲱", "𑲱𑲰", "𑲲", "𑲲𑲰", "𑲪𑲱ʽ", "𑲪𑲱𑲰ʽ", "𑲫𑲱ʽ", "𑲫𑲱𑲰ʽ", "𑲳ʽ", "𑲳", "𑲳𑲰", "𑲴ʽ", "𑲴", "𑲰𑲴", "𑲳ʽ", "𑲳ʽ", "𑲰ʽ" },
    { "𑱲", "𑱳", "𑱴", "𑱴ʿ𑲮", "𑱵", "𑲂", "𑲃", "𑲄", "𑲄ʿ𑲮", "𑱹", "𑱺ʽ", "𑱻ʽ", "𑱼ʽ", "𑱼𑲮ʽ", "𑱽ʽ", "𑱺", "𑱻", "𑱼", "𑱼ʿ𑲮", "𑱽", "𑱾", "𑱿", "𑲀", "𑲀ʿ𑲮", "𑲁", "𑲉", "𑲊", "𑲋", "𑲅", "𑲌", "𑲌ʽ", "𑲍", "𑲎", "𑲋ʽ", "𑲋ʽ", "𑲊ʽ", "𑱽ʽ", "𑱲ʽ", "𑱳ʽ", "𑱴ʽ", "𑲇", "𑱼ʽ", "𑱼𑲮ʽ", "𑱿ʽ", "𑲉ʽ", "𑲶𑱴ʽ", "𑲶𑲄ʽ", "𑲶𑱼ʽ", "𑲶𑱼ʽ", "𑲶𑲀ʽ" },
    { "𑲶", "𑲵", "𑲎ʽ", "𑲎ʽʽ", "ʽʽ" },
    { "༠", "༡", "༢", "༣", "༤", "༥", "༦", "༧", "༨", "༩", "𑲏𑲴𑲶", "ʽʽʽ", "𑱱", "𑱱𑱱", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "masaramgondi", {
    ScriptType::Brahmi,
    { "𑴀", "𑴁", "𑴂", "𑴃", "𑴄", "𑴅", "𑴦𑴶", "𑴦𑴵ʽ", "𑴧𑴴ʽ", "𑴧𑴵ʽ", "𑴆ʽ", "𑴆", "𑴈", "𑴉ʽ", "𑴉", "𑴋", "𑴆𑵃", "𑴆𑵃ʽ", "𑴁𑵃" },
    { "𑵅", "𑴱", "𑴲", "𑴳", "𑴴", "𑴵", "𑴶", "𑵅𑴦𑴵ʽ", "𑵅𑴧𑴴ʽ", "𑵅𑴧𑴵ʽ", "𑴺ʽ", "𑴺", "𑴼", "𑴽ʽ", "𑴽", "𑴿", "𑴺𑵃", "𑴺𑵃ʽ", "𑴱𑵃" },
    { "𑴌", "𑴍", "𑴎", "𑴏", "𑴐", "𑴑", "𑴒", "𑴓", "𑴔", "𑴕", "𑴖", "𑴗", "𑴘", "𑴙", "𑴚", "𑴛", "𑴜", "𑴝", "𑴞", "𑴟", "𑴠", "𑴡", "𑴢", "𑴣", "𑴤", "𑴥", "𑴦", "𑴧", "𑴨", "𑴩", "𑴪", "𑴫", "𑴬", "𑴭", "𑴭𑵂", "𑴦𑵂", "𑴟𑵂", "𑴌𑵂", "𑴍𑵂", "𑴎𑵂", "𑴓𑵂", "𑴘𑵂", "𑴙𑵂", "𑴡𑵂", "𑴥𑵂", "𑵀𑴎ʽ", "𑵀𑴓ʽ", "𑵀𑴘ʽ", "𑵀𑴝ʽ", "𑵀𑴢ʽ" },
    { "𑵀ʽ", "𑵀", "𑵁", "𑵁ʽ", "ʽʽ" },
    { "𑵐", "𑵑", "𑵒", "𑵓", "𑵔", "𑵕", "𑵖", "𑵗", "𑵘", "𑵙", "𑴉𑵀", "ʽʽʽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "meeteimayek", {
    ScriptType::Brahmi,
    { "ꯑ", "ꯑꯥ", "ꯏ", "ꯑꫫ", "ꯎ", "ꯑꫬ", "ꯔꯨʽ", "ꯔꫬʽ", "ꯂꯨʽ", "ꯂꫬʽ", "ꯑꯦʽ", "ꯑꯦ", "ꯑꯩ", "ꯑꯣʽ", "ꯑꯣ", "ꯑꯧ", "ꯑꯦʽ", "ꯑꯦʽ", "ꯑꯥʽ" },
    { "꯭", "ꯥ", "ꯤ", "ꫫ", "ꯨ", "ꫬ", "꯭ꯔꯨʽ", "꯭ꯔꫬʽ", "꯭ꯂꯨʽ", "꯭ꯂꫬʽ", "ꯦʽ", "ꯦ", "ꯩ", "ꯣʽ", "ꯣ", "ꯧ", "ꯦʽ", "ꯦʽ", "ꯥʽ" },
    { "ꯀ", "ꯈ", "ꯒ", "ꯘ", "ꯉ", "ꯆ", "ꫢ", "ꯖ", "ꯓ", "ꫣ", "ꫤ", "ꫥ", "ꫦ", "ꫧ", "ꫨ", "ꯇ", "ꯊ", "ꯗ", "ꯙ", "ꯅ", "ꯄ", "ꯐ", "ꯕ", "ꯚ", "ꯃ", "ꯌ", "ꯔ", "ꯂ", "ꯋ", "ꫩ", "ꫪ", "ꯁ", "ꯍ", "ꯂʽ", "ꯂʽ", "ꯔʽ", "ꯅʽ", "ꯀʽ", "ꯈʽ", "ꯒʽ", "ꯖʽ", "ꯗʽ", "ꯙʽ", "ꯐʽ", "ꯌʽ", "ꯪꯒʽ", "ꯪꯖʽ", "ꯪꯗʽ", "ꯪꯗʽ", "ꯪꯕʽ" },
    { "ꯪʽ", "ꯪ", "ꫵ", "ꫵʼ", "ʽ" },
    { "꯰", "꯱", "꯲", "꯳", "꯴", "꯵", "꯶", "꯷", "꯸", "꯹", "ꯑꯣꯪ", "'", "꯫", "꯫꯫", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "modi", {
    ScriptType::Brahmi,
    { "𑘀", "𑘁", "𑘂", "𑘃", "𑘄", "𑘅", "𑘆", "𑘇", "𑘈", "𑘉", "𑘊ʽ", "𑘊", "𑘋", "𑘌ʽ", "𑘌", "𑘍", "𑘀𑙀", "𑘊ʽ", "𑘁ʽ" },
    { "𑘿", "𑘰", "𑘱", "𑘲", "𑘳", "𑘴", "𑘵", "𑘶", "𑘷", "𑘸", "𑘹ʽ", "𑘹", "𑘺", "𑘻ʽ", "𑘻", "𑘼", "𑙀", "𑘹ʽ", "𑘰ʽ" },
    { "𑘎", "𑘏", "𑘐", "𑘑", "𑘒", "𑘓", "𑘔", "𑘕", "𑘖", "𑘗", "𑘘", "𑘙", "𑘚", "𑘛", "𑘜", "𑘝", "𑘞", "𑘟", "𑘠", "𑘡", "𑘢", "𑘣", "𑘤", "𑘥", "𑘦", "𑘧", "𑘨", "𑘩", "𑘪", "𑘫", "𑘬", "𑘭", "𑘮", "𑘯", "𑘯ʽ", "𑘬ʽ", "𑘡ʽ", "𑘎ʽ", "𑘏ʽ", "𑘐ʽ", "𑘕ʽ", "𑘚ʽ", "𑘛ʽ", "𑘣ʽ", "𑘧ʽ", "𑘽𑘐ʽ", "𑘽𑘕ʽ", "𑘽𑘚ʽ", "𑘽𑘟ʽ", "𑘽𑘤ʽ" },
    { "𑘽ʽ", "𑘽", "𑘾", "𑘾ʽ", "ʽ" },
    { "𑙐", "𑙑", "𑙒", "𑙓", "𑙔", "𑙕", "𑙖", "𑙗", "𑙘", "𑙙", "𑘌𑘽", "ऽ", "𑙁", "𑙂", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "mon", {
    ScriptType::Brahmi,
    { "အ", "အာ", "ဣ", "ဣဳ", "ဥ", "ဥူ", "ၒ", "ၓ", "ၔ", "ၕ", "ဨʽ", "ဨ", "အဲ", "ဩʽ", "ဩ", "ဪ", "ဨʽ", "ဨʽ", "အာʽ" },
    { "်", "ာ", "ိ", "ဳ", "ု", "ူ", "ၖ", "ၗ", "ၘ", "ၙ", "ေʽ", "ေ", "ဲ", "ောʽ", "ော", "ော်", "ေʽ", "ေʽ", "ာʽ" },
    { "က", "ခ", "ဂ", "ဃ", "ၚ", "စ", "ဆ", "ဇ", "ၛ", "ည", "ဋ", "ဌ", "ဍ", "ဎ", "ဏ", "တ", "ထ", "ဒ", "ဓ", "န", "ပ", "ဖ", "ဗ", "ဘ", "မ", "ယ", "ရ", "လ", "ဝ", "ၐ", "ၑ", "သ", "ဟ", "ဠ", "ဠʽ", "ရʽ", "နʽ", "ကʽ", "ခʽ", "ဂʽ", "ဇʽ", "ဍʽ", "ဎʽ", "ဖʽ", "ယʽ", "ံဂʽ", "ံဇʽ", "ံဍʽ", "ံဒʽ", "ံဗʽ" },
    { "ံʽ", "ံ", "း", "းʽ", "ʽ" },
    { "၀", "၁", "၂", "၃", "၄", "၅", "၆", "၇", "၈", "၉", "ဥုံ", "'", "၊", "။", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "mongolian", {
    ScriptType::Brahmi,
    { "ᠠ᠋", "ᠠ᠋᠎ᠠ", "ᢈ", "ᠢᠢ", "ᠦ", "ᠤᠦ", "ᠷᠢ", "ᠷᠢᠢ", "ᠯᠢ", "ᠯᠢᠢ", "ᠧʽ", "ᠧ", "ᠧʼᠧ", "ᠣᠸᠠʽ", "ᠣᠸᠠ", "ᠣᠸᠸᠠ", "ᠣᠸᠠʽ", "ᠣᠸᠠʽ", "ᠠʽ" },
    { "×", "ᠠ᠋᠎ᠠ", "ᢈ", "ᠢᠢ", "ᠦ", "ᠤᠦ", "ᠷᠢ", "ᠷᠢᠢ", "ᠯᠢ", "ᠯᠢᠢ", "ᠧʽ", "ᠧ", "ᠧʼᠧ", "ᠣᠸᠠʽ", "ᠣᠸᠠ", "ᠣᠸᠸᠠ", "ᠣᠸᠠʽ", "ᠣᠸᠠʽ", "ᠠʽ" },
    { "ᢉ", "ᠻ", "ᠺ", "ᠺᠾ", "ᢊ", "ᢋ", "ᠼ", "ᢖ", "ᢖᠾ", "ᡛ", "ᢌ", "ᢍ", "ᢎ", "ᢎᠾ", "ᢏ", "ᢐ", "ᠲ", "ᢑ", "ᢑᠾ", "ᠨ", "ᢒ", "ᠹ", "ᠪ", "ᠪᠾ", "ᠮ", "ᠶ", "ᠷ", "ᠯ", "ᠸ", "ᠱ", "ᢔ", "ᠰ", "ᡙ", "ᠯʽ", "ᠯʽ", "ᠷʽ", "ᠨʽ", "ᢉʽ", "ᠻʽ", "ᠺʽ", "ᢖ", "ᢎʽ", "ᢎᠾʽ", "ᠹʽ", "ᠶʽ", "ᢀᠺʽ", "ᢀᢖʽ", "ᢀᢎʽ", "ᢀᢑʽ", "ᢀᠪʽ" },
    { "ᢀʽ", "ᢀ", "ᢁ", "ᢁʽ", "ʽʽ" },
    { "᠐", "᠑", "᠒", "᠓", "᠔", "᠕", "᠖", "᠗", "᠘", "᠙", "ᢀᠣᠸᠠ", "ʽʽʽ", "᠂", "᠂᠂", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "mro", {
    ScriptType::Brahmi,
    { "𖩒", "𖩆", "𖩊", "𖩊ʽ", "𖩑ʽ", "𖩑ʽ", "𖩓𖩑ʽ", "𖩓𖩑ʽ", "𖩍𖩑ʽ", "𖩍𖩑ʽ", "𖩘ʽ", "𖩘", "𖩆𖩂ʽ", "𖩑ʽ", "𖩑", "𖩖", "𖩘ʽ", "𖩘ʽ", "𖩝" },
    { "×", "𖩆", "𖩊", "𖩊ʽ", "𖩑ʽ", "𖩑ʽ", "𖩓𖩑ʽ", "𖩓𖩑ʽ", "𖩍𖩑ʽ", "𖩍𖩑ʽ", "𖩘ʽ", "𖩘", "𖩆𖩂ʽ", "𖩑ʽ", "𖩑", "𖩖", "𖩘ʽ", "𖩘ʽ", "𖩝" },
    { "𖩌", "𖩈", "𖩌ʽ", "𖩈ʽ", "𖩁", "𖩋", "𖩋ʽ", "𖩋ʽ", "𖩋ʽ", "𖩏ʽ", "𖩀ʽ", "𖩕ʽ", "𖩅ʽ", "𖩅ʽ", "𖩏ʽ", "𖩀", "𖩕", "𖩅", "𖩅ʽ", "𖩏", "𖩐", "𖩇", "𖩄", "𖩄ʽ", "𖩃", "𖩂", "𖩓", "𖩍", "𖩗", "𖩔ʽ", "𖩔ʽ", "𖩔", "𖩉", "𖩍ʽ", "𖩍ʽ", "𖩓ʽ", "𖩏ʽ", "𖩌ʽ", "𖩈ʽ", "𖩌ʽ", "𖩋ʽ", "𖩅ʽ", "𖩅ʽ", "𖩇ʽ", "𖩂ʽ", "𖩁𖩌ʽ", "𖩏𖩋ʽ", "𖩏𖩅ʽ", "𖩏𖩅ʽ", "𖩃𖩄ʽ" },
    { "𖩃ʽ", "𖩃ʽ", "𖩉ʽ", "𖩌ʽ", "ʽʽ" },
    { "𖩠", "𖩡", "𖩢", "𖩣", "𖩤", "𖩥", "𖩦", "𖩧", "𖩨", "𖩩", "𖩑𖩃", "ʽʽ", "𖩮", "𖩯", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "multani", {
    ScriptType::Brahmi,
    { "𑊀", "𑊀ʽ", "𑊁", "𑊁ʽ", "𑊂", "𑊂ʽ", "𑊢𑊂ʽ", "𑊢𑊂ʽ", "𑊣𑊂ʽ", "𑊣𑊂ʽ", "𑊃ʽ", "𑊃", "𑊃ʽ", "𑊂ʽ", "𑊂ʽ", "𑊂ʽ", "𑊃ʽ", "𑊃ʽ", "𑊀ʽ" },
    { "ʾ", "𑊀ʿ", "𑊁ʿ", "𑊁ʿ", "𑊂ʿ", "𑊂ʿ", "𑊢𑊂ʿ", "𑊢𑊂ʿ", "𑊣𑊂ʿ", "𑊣𑊂ʿ", "𑊃ʿ", "𑊃ʿ", "𑊃ʿ", "𑊂ʿ", "𑊂ʿ", "𑊂ʿ", "𑊃ʿ", "𑊃ʿ", "𑊀ʿ" },
    { "𑊄", "𑊅", "𑊆", "𑊈", "𑊚ʽ", "𑊊", "𑊋", "𑊌", "𑊌ʽ", "𑊏", "𑊐", "𑊑", "𑊒", "𑊔", "𑊕", "𑊖", "𑊗", "𑊘", "𑊙", "𑊚", "𑊛", "𑊜", "𑊝", "𑊟", "𑊠", "𑊡", "𑊢", "𑊣", "𑊤", "𑊥ʽ", "𑊥ʽ", "𑊥", "𑊦", "𑊣ʽ", "𑊣ʽ", "𑊢ʽ", "𑊚ʽ", "𑊄ʽ", "𑊅ʽ", "𑊆ʽ", "𑊌ʽ", "𑊧", "𑊨", "𑊜ʽ", "𑊡ʽ", "𑊚𑊆ʽ", "𑊚𑊌ʽ", "𑊚𑊒ʽ", "𑊚𑊘ʽ", "𑊠𑊝ʽ" },
    { "𑊚ʽ", "𑊚ʽ", "𑊦ʽ", "𑊦ʽʽ", "ʽʽʽ" },
    { "੦", "੧", "੨", "੩", "੪", "੫", "੬", "੭", "੮", "੯", "𑊂𑊠ʽ", "ʽʽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "nandinagari", {
    ScriptType::Brahmi,
    { "𑦠", "𑦡", "𑦢", "𑦣", "𑦤", "𑦥", "𑦦", "𑦧", "𑧉𑧔ʽ", "𑧉𑧕ʽ", "𑦪ʽ", "𑦪", "𑦫", "𑦬ʽ", "𑦬", "𑦭", "𑦪ʽ", "𑦪ʽ", "𑦡ʽ" },
    { "𑧠", "𑧑", "𑧒", "𑧓", "𑧔", "𑧕", "𑧖", "𑧗", "𑧠𑧉𑧔ʽ", "𑧠𑧉𑧕ʽ", "𑧚ʽ", "𑧚", "𑧛", "𑧜ʽ", "𑧜", "𑧝", "𑧑ʽ", "𑧚ʽ", "𑧚ʽ" },
    { "𑦮", "𑦯", "𑦰", "𑦱", "𑦲", "𑦳", "𑦴", "𑦵", "𑦶", "𑦷", "𑦸", "𑦹", "𑦺", "𑦻", "𑦼", "𑦽", "𑦾", "𑦿", "𑧀", "𑧁", "𑧂", "𑧃", "𑧄", "𑧅", "𑧆", "𑧇", "𑧈", "𑧉", "𑧊", "𑧋", "𑧌", "𑧍", "𑧎", "𑧏ʽ", "𑧏", "𑧐", "𑧁ʽ", "𑦮ʽ", "𑦯ʽ", "𑦰ʽ", "𑦵ʽ", "𑦺ʽ", "𑦻ʽ", "𑧃ʽ", "𑧇ʽ", "𑧞ʽ𑦰", "𑧞ʽ𑦵", "𑧞ʽ𑦺", "𑧞ʽ𑦿", "𑧞ʽ𑧄" },
    { "𑧞ʽ", "𑧞", "𑧟", "𑧟ʽ", "ʽʽ" },
    { "೦", "೧", "೨", "೩", "೪", "೫", "೬", "೭", "೮", "೯", "𑦬𑧞", "𑧡", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "newa", {
    ScriptType::Brahmi,
    { "𑐀", "𑐁", "𑐂", "𑐃", "𑐄", "𑐅", "𑐆", "𑐇", "𑐈", "𑐉", "𑐊ʽ", "𑐊", "𑐋", "𑐌ʽ", "𑐌", "𑐍", "𑐊ʽ", "𑐊ʽ", "𑐁ʽ" },
    { "𑑂", "𑐵", "𑐶", "𑐷", "𑐸", "𑐹", "𑐺", "𑐻", "𑐼", "𑐽", "𑐾ʽ", "𑐾", "𑐿", "𑑀ʽ", "𑑀", "𑑁", "𑐾ʽ", "𑐾ʽ", "𑐶ʽ" },
    { "𑐎", "𑐏", "𑐐", "𑐑", "𑐒", "𑐔", "𑐕", "𑐖", "𑐗", "𑐘", "𑐚", "𑐛", "𑐜", "𑐝", "𑐞", "𑐟", "𑐠", "𑐡", "𑐢", "𑐣", "𑐥", "𑐦", "𑐧", "𑐨", "𑐩", "𑐫", "𑐬", "𑐮", "𑐰", "𑐱", "𑐲", "𑐳", "𑐴", "𑐮𑑆", "𑐲𑑆", "𑐬𑑆", "𑐣𑑆", "𑐎𑑆", "𑐏𑑆", "𑐐𑑆", "𑐖𑑆", "𑐜𑑆", "𑐝𑑆", "𑐦𑑆", "𑐫𑑆", "𑑃𑐐ʽ", "𑑃𑐖ʽ", "𑑃𑐜ʽ", "𑑃𑐡ʽ", "𑑃𑐧ʽ" },
    { "𑑃", "𑑄", "𑑅", "𑑅ʽ", "𑑆" },
    { "𑑐", "𑑑", "𑑒", "𑑓", "𑑔", "𑑕", "𑑖", "𑑗", "𑑘", "𑑙", "𑑉", "𑑇", "𑑋", "𑑌", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "oldpersian", {
    ScriptType::Brahmi,
    { "𐎠", "𐎠ʽ", "𐎡", "𐎡ʽ", "𐎢", "𐎢ʽ", "𐎽𐎢ʽ", "𐎽𐎢ʽ", "𐎾𐎢ʽ", "𐎾𐎢ʽ", "𐎡ʽ", "𐎡ʽ", "𐎠𐎡", "𐎢ʽ", "𐎢ʽ", "𐎠𐎢", "𐎡ʽ", "𐎡ʽ", "𐎠ʽ" },
    { "ʽ", "_𐎠", "_𐎡", "𐎡𐎹ʽ", "_𐎢", "𐎢𐎺ʽ", "𐎽𐎢ʽ", "𐎽𐎢ʽ", "𐎾𐎢ʽ", "𐎾𐎢ʽ", "𐎡ʽ", "𐎡ʽ", "<𐎠𐎡", "𐎢ʽ", "𐎢ʽ", "<𐎠𐎢", "𐎡ʽ", "𐎡ʽ", "𐎠ʽ" },
    { "𐎣", "𐎧ʽ", "𐎥", "𐎥ʽ", "𐎴ʽ", "𐎨", "𐎨ʽ", "𐎩", "𐎩ʽ", "𐎴ʽ", "𐎫ʽ", "𐎫ʽ", "𐎭ʽ", "𐎭ʽ", "𐎴ʽ", "𐎫", "𐎰", "𐎭", "𐎭ʽ", "𐎴", "𐎱", "𐎱ʽ", "𐎲", "𐎲", "𐎶", "𐎹", "𐎼", "𐎾", "𐎺", "𐏁", "𐏂", "𐎿", "𐏃", "𐎾ʽ", "𐎾ʽ", "𐎼ʽ", "𐎴ʽ", "𐎣ʽ", "𐎧", "𐎥ʽ", "𐏀", "𐎭ʽ", "𐎭ʽ", "𐎳", "𐎹ʽ", "𐎴𐎥ʽ", "𐎴𐎩ʽ", "𐎴𐎭ʽ", "𐎴𐎭ʽ", "𐎶𐎲ʽ" },
    { "𐎶ʽ", "𐎶ʽ", "𐏃ʽ", "𐎧ʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𐎢𐎶ʽ", "ʽ", "𐏐𐏐", "𐏐𐏐ʽ", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "pallava", {
    ScriptType::Brahmi,
    { "ꦄ", "ꦄꦴ", "ꦆ", "ꦇ", "ꦈ", "ꦈꦴ", "ꦫꦶʽ", "ꦫꦷʽ", "ꦭꦶʽ", "ꦭꦷʽ", "ꦌʽ", "ꦌ", "ꦍ", "ꦎʽ", "ꦎ", "ꦎꦴ", "ꦌʽ", "ꦌʽ", "ꦄꦴʽ" },
    { "꧀", "ꦴ", "ꦶ", "ꦷ", "ꦸ", "ꦹ", "꧀ꦫꦶʽ", "꧀ꦫꦷʽ", "꧀ꦭꦶʽ", "꧀ꦭꦷʽ", "ꦺʽ", "ꦺ", "ꦻ", "ꦺꦴʽ", "ꦺꦴ", "ꦻꦴ", "ꦺʽ", "ꦺʽ", "ꦴʽ" },
    { "ꦏ", "ꦑ", "ꦒ", "ꦓ", "ꦔ", "ꦕ", "ꦖ", "ꦗ", "ꦙ", "ꦚ", "ꦛ", "ꦜ", "ꦝ", "ꦞ", "ꦟ", "ꦠ", "ꦡ", "ꦢ", "ꦣ", "ꦤ", "ꦥ", "ꦦ", "ꦧ", "ꦨ", "ꦩ", "ꦪ", "ꦫ", "ꦭ", "ꦮ", "ꦯ", "ꦰ", "ꦱ", "ꦲ", "ꦭʽ", "ꦰʽ", "ꦫʽ", "ꦤʽ", "ꦏʽ", "ꦑʽ", "ꦒʽ", "ꦗʽ", "ꦝʽ", "ꦞʽ", "ꦦʽ", "ꦪʽ", "ꦁꦒʽ", "ꦁꦗʽ", "ꦁꦝʽ", "ꦁꦢʽ", "ꦁꦧʽ" },
    { "ꦁʽ", "ꦁ", "ꦃ", "ꦃʽ", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ꦎꦁ", "'", "|", "||", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "phagspa", {
    ScriptType::Brahmi,
    { "ṿꡝ", "ṿꡝꡖ", "ṿꡞ", "ṿꡞꡖ", "ṿꡟ", "ṿꡟꡖ", "ṿꡘꡞʽ", "ṿꡘꡖꡞʽ", "ṿꡙꡞʽ", "ṿꡙꡖꡞʽ", "ꡠʽ", "ṿꡠ", "ṿꡠꡖ", "ꡡʽ", "ṿꡡ", "ṿꡡꡖ", "ꡠʽ", "ꡠʽ", "ꡝꡖʽ" },
    { "ʾ", "ꡖ", "ꡞ", "ꡖꡞ", "ꡟ", "ꡖꡟ", "ꡱꡞ", "ꡖꡱꡞʽ", "ʾꡙꡞʽ", "ʾꡙꡖꡞʽ", "ꡠʽ", "ꡠ", "ꡖꡠ", "ꡡʽ", "ꡡ", "ꡖꡡ", "ꡠʽ", "ꡠʽ", "ꡖʽ" },
    { "ꡀ", "ꡁ", "ꡂ", "ṾꡂṾꡜṾ", "ꡃ", "ꡐ", "ꡑ", "ꡒ", "ṾꡒṾꡜṾ", "ꡇ", "ꡩ", "ꡪ", "ꡫ", "ṾꡫṾꡜṾ", "ꡬ", "ꡈ", "ꡉ", "ꡊ", "ṾꡊṾꡜṾ", "ꡋ", "ꡌ", "ꡍ", "ꡎ", "ṾꡎṾꡜṾ", "ꡏ", "ꡗ", "ꡘ", "ꡙ", "ꡓ", "ꡚ", "ꡚʽ", "ꡛ", "ꡜ", "ꡙʽ", "ꡙʽ", "ꡘʽ", "ꡋʽ", "ꡢ", "ꡣ", "ꡥ", "ꡕ", "ꡫʽ", "ꡫṾꡜʽ", "ꡤ", "ꡭ", "ꡳꡂʽ", "ꡳꡒʽ", "ꡳꡨʽ", "ꡳꡊʽ", "ꡳꡎʽ" },
    { "ꡳ", "ꡳʽ", "ꡜʾʽ", "ꡜʽ", "ʽʽʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ṿꡡꡳ", "ʽ", "꡶", "꡷", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "ranjana", {
    ScriptType::Brahmi,
    { "अ", "आ", "इ", "ई", "उ", "ऊ", "ऋ", "ॠ", "ऌ", "ॡ", "एʽ", "ए", "ऐ", "ओʽ", "ओ", "औ", "एʽ", "एʽ", "आʽ" },
    { "्", "ा", "ि", "ी", "ु", "ू", "ृ", "ॄ", "ॢ", "ॣ", "ेʽ", "े", "ै", "ोʽ", "ो", "ौ", "ेʽ", "ेʽ", "ाʽ" },
    { "क", "ख", "ग", "घ", "ङ", "च", "छ", "ज", "झ", "ञ", "ट", "ठ", "ड", "ढ", "ण", "त", "थ", "द", "ध", "न", "प", "फ", "ब", "भ", "म", "य", "र", "ल", "व", "श", "ष", "स", "ह", "लʽ", "लʽ", "रʽ", "नʽ", "कʽ", "खʽ", "गʽ", "जʽ", "डʽ", "ढʽ", "फʽ", "यʽ", "ँʽग", "ँʽज", "ँʽड", "ँʽद", "ँʽब" },
    { "ँ", "ं", "ः", "ःʽ", "़" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "ॐ", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "rejang", {
    ScriptType::Brahmi,
    { "ꥆ", "ꥆʽ", "ꥆꥇ", "ꥆꥇʽ", "ꥆꥈ", "ꥆꥈʽ", "ꤽꥈʽ", "ꤽꥈʽ", "ꤾꥈʽ", "ꤾꥈʽ", "ꥆꥉ", "ꥆꥉʽ", "ꥆꥊ", "ꥆꥋ", "ꥆꥋʽ", "ꥆꥌ", "ꥆꥎ", "ꥆꥎʽ", "ꥆꥍ" },
    { "꥓", "ʽ", "ꥇ", "ꥇʽ", "ꥈ", "ꥈʽ", "꥓ꤽꥈʽ", "꥓ꤽꥈʽ", "꥓ꤾꥈʽ", "꥓ꤾꥈʽ", "ꥉ", "ꥉʽ", "ꥊ", "ꥋ", "ꥋʽ", "ꥌ", "ꥎ", "ꥎʽ", "ꥍ" },
    { "ꤰ", "ꤰʽ", "ꤱ", "ꤱʽ", "ꤲ", "ꤹ", "ꤹʽ", "ꤺ", "ꤺʽ", "ꤻ", "ꤳʽ", "ꤳʽ", "ꤴʽ", "ꤴʽ", "ꤵʽ", "ꤳ", "ꤳʽ", "ꤴ", "ꤴʽ", "ꤵ", "ꤶ", "ꤶʽ", "ꤷ", "ꤷʽ", "ꤸ", "ꤿ", "ꤽ", "ꤾ", "ꥀ", "ꤼʽ", "ꤼʽ", "ꤼ", "ꥁ", "ꤾʽ", "ꤾʽ", "ꤽʽ", "ꤵʽ", "ꤰʽ", "ꤰʽ", "ꤱʽ", "ꤺʽ", "ꤴʽ", "ꤴʽ", "ꤶʽ", "ꤿʽ", "ꥃ", "ꥅ", "ꥄʽ", "ꥄ", "ꥂ" },
    { "ꥏʽ", "ꥏ", "ꥒ", "ꥒʽ", "ʽʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ꥆꥋꥏʽ", "'", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "romancolloquial", {
    ScriptType::Roman,
    { "a", "a", "i", "i", "u", "u", "ri", "ri", "li", "li", "e", "e", "ai", "o", "o", "au", "a", "e", "o" },
    { "×", "a", "i", "i", "u", "u", "ri", "ri", "li", "li", "e", "e", "ai", "o", "o", "au", "a", "e", "o" },
    { "k", "kh", "g", "gh", "ng", "ch", "chh", "j", "jh", "nj", "t'", "th", "d'", "dh", "n", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "sh", "sh", "s", "h", "l", "zh", "r", "n", "q", "kh", "g", "z", "r'", "r'h", "f", "y", "ng", "nj", "nd", "nd", "mb" },
    { "m'", "m'", "h", "g", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "Om", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "romankana", {
    ScriptType::Roman,
    { "a", "aa", "i", "ii", "u", "uu", "ri", "rii", "r゚i", "r゚ii", "e", "ee", "ai", "o", "oo", "au", "a", "e", "o" },
    { "×", "aa", "i", "ii", "u", "uu", "ri", "rii", "r゚i", "r゚ii", "e", "ee", "ai", "o", "oo", "au", "a", "e", "o" },
    { "k", "k", "g", "g", "k゚", "c", "c", "j", "j", "J", "t", "t", "d", "d", "n", "t", "t", "d", "d", "n", "p", "p", "b", "b", "m", "y", "r", "r゚", "v", "sh", "sh", "s", "h", "r゚", "r゚", "r", "n", "k", "k", "g", "z", "r", "r", "f", "y", "ng", "nj", "nd", "nd", "nb" },
    { "n", "n", "H", "gu", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oon", "'", "。", "。。", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "romanreadable", {
    ScriptType::Roman,
    { "a", "aa", "i", "ee", "u", "oo", "ri'", "ree'", "li'", "lee'", "e'", "e", "ai", "o'", "o", "au", "a", "e", "o" },
    { "×", "aa", "i", "ee", "u", "oo", "ri'", "ree'", "li'", "lee'", "e'", "e", "ai", "o'", "o", "au", "a", "e", "o" },
    { "k", "kh", "g", "gh", "ng", "ch", "chh", "j", "jh", "nj", "t'", "t'h", "d'", "d'h", "n", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "sh", "sh", "s", "h", "l'", "zh", "r'", "n", "q", "kh", "g", "z", "r", "rh", "f", "y", "ng", "nj", "nd'", "nd", "mb" },
    { "m'", "M", "h'", "g", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "om", "'", ".", "..", "gum", "ggum", "​", "‌", "‍" }
  }},
  { "russiancyrillic", {
    ScriptType::Brahmi,
    { "а", "а̄", "и", "ӣ", "у", "ӯ", "р̣", "р̣̄", "л̣", "л̣̄", "э̆", "э", "аи", "о̆", "о", "ау", "ӕ", "ӕ̄", "о̂" },
    { "×", "а̄", "и", "ӣ", "у", "ӯ", "р̣", "р̣̄", "л̣", "л̣̄", "э̆", "э", "аи", "о̆", "о", "ау", "ӕ", "ӕ̄", "о̂" },
    { "к", "кх", "г", "гх", "н̇", "ч", "чх", "дж", "джх", "н̃", "т̣", "т̣х", "д̣", "д̣х", "н̣", "т", "тх", "д", "дх", "н", "п", "пх", "б", "бх", "м", "й", "р", "л", "в", "ш́", "ш", "с", "х", "л̤", "л̱", "р̱", "н̱", "ԛ", "к͟х", "г̇", "з", "р̤", "р̤х", "ф", "й̣", "н̆г", "н̆дж", "н̆д̣", "н̆д", "м̆б" },
    { "м̐", "м̣", "х̣", "к̱", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ом̣", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "santali", {
    ScriptType::Brahmi,
    { "ᱚ", "ᱟ", "ᱤ", "ᱤᱻ", "ᱩ", "ᱩᱻ", "ᱨᱩʽ", "ᱨᱩᱻʽ", "ᱞᱩʽ", "ᱞᱩᱻʽ", "ᱮᱹ", "ᱮ", "ᱚᱤ", "ᱳʽ", "ᱳ", "ᱚᱩ", "ᱚᱹ", "ᱚᱹʽ", "ᱟᱹ" },
    { "×", "ᱟ", "ᱤ", "ᱤᱻ", "ᱩ", "ᱩᱻ", "ᱨᱩʽ", "ᱨᱩᱻʽ", "ᱞᱩʽ", "ᱞᱩᱻʽ", "ᱮᱹ", "ᱮ", "ᱚᱤ", "ᱳʽ", "ᱳ", "ᱚᱩ", "ᱚᱹ", "ᱚᱹʽ", "ᱟᱹ" },
    { "ᱠ", "ᱠᱷ", "ᱜ", "ᱜᱷ", "ᱶ", "ᱪ", "ᱪᱷ", "ᱡ", "ᱡᱷ", "ᱧ", "ᱴ", "ᱴᱷ", "ᱰ", "ᱰᱷ", "ᱬ", "ᱛ", "ᱛᱷ", "ᱫ", "ᱫᱷ", "ᱱ", "ᱯ", "ᱯᱷ", "ᱵ", "ᱵᱷ", "ᱢ", "ᱭ", "ᱨ", "ᱞ", "ᱣ", "ᱥʽ", "ᱥʽ", "ᱥ", "ᱦ", "ᱞʽ", "ᱞʽ", "ᱨʽ", "ᱱʽ", "ᱠʽ", "ᱠᱷʽ", "ᱜʽ", "ᱡʽ", "ᱲ", "ᱲᱷ", "ᱯʽ", "ᱭʽ", "ᱸᱜʽ", "ᱸᱡʽ", "ᱸᱰʽ", "ᱸᱫʽ", "ᱸᱵʽ" },
    { "ᱸ", "ᱝ", "ᱷ", "ᱷʽ", "ʽ" },
    { "᱐", "᱑", "᱒", "᱓", "᱔", "᱕", "᱖", "᱗", "᱘", "᱙", "ᱳᱸ", "'", "᱾", "᱿", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "saurashtra", {
    ScriptType::Brahmi,
    { "ꢂ", "ꢃ", "ꢄ", "ꢅ", "ꢆ", "ꢇ", "ꢈ", "ꢉ", "ꢊ", "ꢋ", "ꢌ", "ꢍ", "ꢎ", "ꢏ", "ꢐ", "ꢑ", "ꢌʽ", "ꢌʽ", "ꢃʽ" },
    { "꣄", "ꢵ", "ꢶ", "ꢷ", "ꢸ", "ꢹ", "ꢺ", "ꢻ", "ꢼ", "ꢽ", "ꢾ", "ꢿ", "ꣀ", "ꣁ", "ꣂ", "ꣃ", "ꢾʽ", "ꢿʽ", "ꢵʽ" },
    { "ꢒ", "ꢓ", "ꢔ", "ꢕ", "ꢖ", "ꢗ", "ꢘ", "ꢙ", "ꢚ", "ꢛ", "ꢜ", "ꢝ", "ꢞ", "ꢟ", "ꢠ", "ꢡ", "ꢢ", "ꢣ", "ꢤ", "ꢥ", "ꢦ", "ꢧ", "ꢨ", "ꢩ", "ꢪ", "ꢫ", "ꢬ", "ꢭ", "ꢮ", "ꢯ", "ꢰ", "ꢱ", "ꢲ", "ꢳ", "ꢳʽ", "ꢬʽ", "ꢥʽ", "ꢒʽ", "ꢓʽ", "ꢔʽ", "ꢙʽ", "ꢞʽ", "ꢟʽ", "ꢧʽ", "ꢫʽ", "ꢀʽꢔ", "ꢀʽꢙ", "ꢀʽꢞ", "ꢀʽꢣ", "ꢀʽꢨ" },
    { "ꣅ", "ꢀ", "ꢁ", "ꢁʼ", "ʽ" },
    { "꣐", "꣑", "꣒", "꣓", "꣔", "꣕", "꣖", "꣗", "꣘", "꣙", "ꢐꢀ", "ఽ", "꣎", "꣏", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "shahmukhi", {
    ScriptType::Brahmi,
    { "اَ", "آ", "اِ", "اِی", "اُ", "اُو", "رِʽ", "رِیʽ", "لِʽ", "لِیʽ", "ایʽ", "ای", "اََی", "اوʽ", "او", "اََو", "ایʽ", "اےʽ", "آʽ" },
    { "ْ", "ا", "ِ", "ِی", "ُ", "ُو", "ْرِʽ", "ْرِیʽ", "ْلِʽ", "ْلِیʽ", "یʽ", "ی", "ََی", "وʽ", "و", "ََو", "یʽ", "یʽ", "اʽ" },
    { "کَ", "کھَ", "گَ", "گھَ", "نʽَ", "چَ", "چھَ", "جَ", "جھَ", "نʽَ", "ٹَ", "ٹھَ", "ڈَ", "ڈھَ", "ݨَ", "تَ", "تھَ", "دَ", "دھَ", "نَ", "پَ", "پھَ", "بَ", "بھَ", "مَ", "یَ", "رَ", "لَ", "وَ", "شَ", "شَʽ", "سَ", "ہَ", "ࣇَ", "لʽَ", "رʽَ", "نʽَ", "قَ", "خَ", "غَ", "زَ", "ڑَ", "ڑھَ", "فَ", "یَʽ", "ںگʽَ", "ںجʽَ", "ںڈʽَ", "ںدʽَ", "ںبʽَ" },
    { "ںʽ", "ں", "ہ", "ہʽ", "ʽ" },
    { "۰", "۱", "۲", "۳", "۴", "۵", "۶", "۷", "۸", "۹", "اومْ", "ʽ", "۔", "۔۔", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "shan", {
    ScriptType::Brahmi,
    { "ဢ", "ဢႃ", "ဢိ", "ဢီ", "ဢု", "ဢူ", "ရိʽ", "ရီʽ", "လိʽ", "လီʽ", "ဢေʽ", "ဢေ", "ဢႆ", "ဢေႃʽ", "ဢေႃ", "ဢဝ်ʽ", "ဢႄ", "ဢႄʽ", "ဢႃʽ" },
    { "်", "ႃ", "ိ", "ီ", "ု", "ူ", "်ရိʽ", "်ရီʽ", "်လိʽ", "်လီʽ", "ေʽ", "ေ", "ႆ", "ေႃʽ", "ေႃ", "ဝ်ʽ", "ႄ", "ႄʽ", "ႃʽ" },
    { "ၵ", "ၶ", "ၷ", "ꧠ", "င", "ၸ", "ꧡ", "ꩡ", "ꧢ", "ၺ", "ꩦ", "ꩧ", "ꩨ", "ꩩ", "ꧣ", "တ", "ထ", "ၻ", "ꩪ", "ၼ", "ပ", "ၽ", "ၿ", "ꧤ", "မ", "ယ", "ရ", "လ", "ဝ", "သ်ယ", "သျʽ", "သ", "ႁ", "ꩮ", "ꩮʽ", "ရʽ", "ၼʽ", "ၵʽ", "ၶʽ", "ၷʽ", "ၹ", "ꩨʽ", "ꩩʽ", "ၾ", "ယʽ", "ံၷʽ", "ံꩡʽ", "ံꩨʽ", "ံၻʽ", "ံၿʽ" },
    { "ံʽ", "ံ", "း", "းʽ", "ʽʽ" },
    { "႐", "႑", "႒", "႓", "႔", "႕", "႖", "႗", "႘", "႙", "ဢေႃံ", "'", "၊", "။", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "sharada", {
    ScriptType::Brahmi,
    { "𑆃", "𑆄", "𑆅", "𑆆", "𑆇", "𑆈", "𑆉", "𑆊", "𑆋", "𑆌", "𑆍ᳮ", "𑆍", "𑆎", "𑆃ᳯ", "𑆏", "𑆐", "𑆃᳐", "𑆃᳐ʽ", "𑆄᳐" },
    { "𑇀", "𑆳", "𑆴", "𑆵", "𑆶", "𑆷", "𑆸", "𑆹", "𑆺", "𑆻", "ᳮ", "𑆼", "𑆽", "ᳯ", "𑆾", "𑆿", "᳐", "᳐ʽ", "𑆳᳐" },
    { "𑆑", "𑆒", "𑆓", "𑆔", "𑆕", "𑆖", "𑆗", "𑆘", "𑆙", "𑆚", "𑆛", "𑆜", "𑆝", "𑆞", "𑆟", "𑆠", "𑆡", "𑆢", "𑆣", "𑆤", "𑆥", "𑆦", "𑆧", "𑆨", "𑆩", "𑆪", "𑆫", "𑆬", "𑆮", "𑆯", "𑆰", "𑆱", "𑆲", "𑆭", "𑆭𑇊", "𑆫𑇊", "𑆤𑇊", "𑆑𑇊", "𑆒𑇊", "𑆓𑇊", "𑆘𑇊", "𑆝𑇊", "𑆞𑇊", "𑆦𑇊", "𑆪𑇊", "𑆀ʽ𑆓", "𑆀ʽ𑆘", "𑆀ʽ𑆝", "𑆀ʽ𑆢", "𑆀ʽ𑆧" },
    { "𑆀", "𑆁", "𑆂", "𑆂ʽ", "𑇊" },
    { "𑇐", "𑇑", "𑇒", "𑇓", "𑇔", "𑇕", "𑇖", "𑇗", "𑇘", "𑇙", "𑆏𑆀", "𑇁", "𑇅", "𑇆", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "siddham", {
    ScriptType::Brahmi,
    { "𑖀", "𑖁", "𑖂", "𑖃", "𑖄", "𑖅", "𑖆", "𑖇", "𑖈", "𑖉", "𑖊ʽ", "𑖊", "𑖋", "𑖌ʽ", "𑖌", "𑖍", "𑖊ʽ", "𑖊ʽ", "𑖁ʽ" },
    { "𑖿", "𑖯", "𑖰", "𑖱", "𑖲", "𑖳", "𑖴", "𑖵", "𑖿𑖩𑖰ʽ", "𑖿𑖩𑖱ʽ", "𑖸ʽ", "𑖸", "𑖹", "𑖺ʽ", "𑖺", "𑖻", "𑖸ʽ", "𑖸ʽ", "𑖯ʽ" },
    { "𑖎", "𑖏", "𑖐", "𑖑", "𑖒", "𑖓", "𑖔", "𑖕", "𑖖", "𑖗", "𑖘", "𑖙", "𑖚", "𑖛", "𑖜", "𑖝", "𑖞", "𑖟", "𑖠", "𑖡", "𑖢", "𑖣", "𑖤", "𑖥", "𑖦", "𑖧", "𑖨", "𑖩", "𑖪", "𑖫", "𑖬", "𑖭", "𑖮", "𑖩𑗀", "𑖬𑗀", "𑖨𑗀", "𑖡𑗀", "𑖎𑗀", "𑖏𑗀", "𑖐𑗀", "𑖕𑗀", "𑖚𑗀", "𑖛𑗀", "𑖣𑗀", "𑖧𑗀", "𑖼ʽ𑖐", "𑖼ʽ𑖕", "𑖼ʽ𑖚", "𑖼ʽ𑖟", "𑖼ʽ𑖤" },
    { "𑖼", "𑖽", "𑖾", "𑖾ʽ", "𑗀" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𑖌𑖼", "ʽʽ", "𑗂", "𑗃", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "siddhamdevanagari", {
    ScriptType::Brahmi,
    { "अ", "आ", "इ", "ई", "उ", "ऊ", "ऋ", "ॠ", "ऌ", "ॡ", "एʽ", "ए", "ऐ", "ओʽ", "ओ", "औ", "एʽ", "एʽ", "आʽ" },
    { "्", "ा", "ि", "ी", "ु", "ू", "ृ", "ॄ", "ॢ", "ॣ", "ेʽ", "े", "ै", "ोʽ", "ो", "ौ", "ेʽ", "ेʽ", "ाʽ" },
    { "क", "ख", "ग", "घ", "ङ", "च", "छ", "ज", "झ", "ञ", "ट", "ठ", "ड", "ढ", "ण", "त", "थ", "द", "ध", "न", "प", "फ", "ब", "भ", "म", "य", "र", "ल", "व", "श", "ष", "स", "ह", "ल़", "ष़", "ऱ", "ऩ", "क़", "ख़", "ग़", "ज़", "ड़", "ढ़", "फ़", "य़", "ँʽग", "ँʽज", "ँʽड", "ँʽद", "ँʽब" },
    { "ँ", "ं", "ः", "ःʽ", "़" },
    { "०", "१", "२", "३", "४", "५", "६", "७", "८", "९", "ॐ", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "sinhala", {
    ScriptType::Brahmi,
    { "අ", "ආ", "ඉ", "ඊ", "උ", "ඌ", "ඍ", "ඎ", "ඏ", "ඐ", "එ", "ඒ", "ඓ", "ඔ", "ඕ", "ඖ", "ඇ", "ඈ", "ආʼ" },
    { "්", "ා", "ි", "ී", "ු", "ූ", "ෘ", "ෲ", "ෟ", "ෳ", "ෙ", "ේ", "ෛ", "ො", "ෝ", "ෞ", "ැ", "ෑ", "ාʼ" },
    { "ක", "ඛ", "ග", "ඝ", "ඞ", "ච", "ඡ", "ජ", "ඣ", "ඤ", "ට", "ඨ", "ඩ", "ඪ", "ණ", "ත", "ථ", "ද", "ධ", "න", "ප", "ඵ", "බ", "භ", "ම", "ය", "ර", "ල", "ව", "ශ", "ෂ", "ස", "හ", "ළ", "ළ·", "ර·", "න·", "ක·", "ඛ·", "ග·", "ජ·", "ඩ·", "ඪ·", "ෆ", "ය·", "ඟ", "ඦ", "ඬ", "ඳ", "ඹ" },
    { "ංʼ", "ං", "ඃ", "ඃʼ", "·" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ඕං", "(අ)", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "slp1", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "f", "F", "x", "X", "e1", "e", "E", "o1", "o", "O", "e2", "e4", "o2" },
    { "×", "A", "i", "I", "u", "U", "f", "F", "x", "X", "e1", "e", "E", "o1", "o", "O", "e2", "e4", "o2" },
    { "k", "K", "g", "G", "N", "c", "C", "j", "J", "Y", "w", "W", "q", "Q", "R", "t", "T", "d", "D", "n", "p", "P", "b", "B", "m", "y", "r", "l", "v", "S", "z", "s", "h", "L", "L0", "r2", "n2", "k0", "K0", "g0", "j0", "q0", "Q0", "P0", "Y0", "n*g", "n*j", "n*q", "n*d", "m*b" },
    { "~", "M", "H", "K", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oM", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "sorasompeng", {
    ScriptType::Brahmi,
    { "ə", "𑃢", "𑃤", "𑃤ʽ", "𑃥", "𑃥ʽ", "𑃝𑃤ʽ", "𑃝𑃤ʽ", "𑃘𑃤ʽ", "𑃘𑃤ʽ", "𑃣ʽ", "𑃣", "𑃧", "𑃦ʽ", "𑃦", "𑃦𑃥", "𑃣ʽ", "𑃣ʽ", "𑃢ʽ" },
    { "×", "𑃢", "𑃤", "𑃤ʽ", "𑃥", "𑃥ʽ", "𑃝𑃤ʽ", "𑃝𑃤ʽ", "𑃘𑃤ʽ", "𑃘𑃤ʽ", "𑃣ʽ", "𑃣", "𑃧", "𑃦ʽ", "𑃦", "𑃦𑃥", "𑃣ʽ", "𑃣ʽ", "𑃢ʽ" },
    { "𑃟", "𑃟𑃠", "𑃕", "𑃕𑃠", "𑃗", "𑃓", "𑃓𑃠", "𑃠", "𑃠𑃠", "𑃡", "𑃑𑃨", "𑃑𑃨𑃠", "𑃔", "𑃔𑃠", "𑃙𑃨", "𑃑", "𑃑𑃠", "𑃔𑃨", "𑃔𑃨𑃠ʽ", "𑃙", "𑃛", "𑃛𑃠", "𑃒", "𑃒𑃠", "𑃖", "𑃜", "𑃝", "𑃘", "𑃚", "𑃐𑃠ʽ", "𑃐𑃨", "𑃐", "𑃞", "𑃘𑃨", "𑃘𑃨ʽ", "𑃘ʽ", "𑃙ʽ", "𑃟ʽ", "𑃟𑃠ʽ", "𑃕ʽ", "𑃠ʽ", "𑃝𑃔", "𑃝𑃔𑃠", "𑃛𑃠ʽ", "𑃜ʽ", "𑃗𑃕ʽ", "𑃡𑃓ʽ", "𑃙𑃨𑃔ʽ", "𑃙𑃔ʽ", "𑃖𑃛ʽ" },
    { "𑃖ʽ", "𑃖ʽ", "𑃞ʽ", "𑃞ʽ", "𑃨ʽ" },
    { "𑃰", "𑃱", "𑃲", "𑃳", "𑃴", "𑃵", "𑃶", "𑃷", "𑃸", "𑃹", "𑃦𑃖ʽ", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "soyombo", {
    ScriptType::Brahmi,
    { "𑩐", "𑩐𑩛", "𑩐𑩑", "𑩐𑩑𑩛", "𑩐𑩒", "𑩐𑩒𑩛", "𑩐𑩙", "𑩐𑩙𑩛", "𑩐𑩚", "𑩐𑩚𑩛", "𑩐𑩔ʽ", "𑩐𑩔", "𑩐𑩗", "𑩐𑩖ʽ", "𑩐𑩖", "𑩐𑩘", "𑩐𑩔ʽ", "𑩐𑩔ʽ", "𑩐𑩕" },
    { "𑪙", "𑩛", "𑩑", "𑩑𑩛", "𑩒", "𑩒𑩛", "𑩙", "𑩙𑩛", "𑩚", "𑩚𑩛", "𑩔ʽ", "𑩔", "𑩗", "𑩖ʽ", "𑩖", "𑩘", "𑩔ʽ", "𑩔ʽ", "𑩕" },
    { "𑩜", "𑩝", "𑩞", "𑩟", "𑩠", "𑩵", "𑩶", "𑩷", "𑩤", "𑩥", "𑩦", "𑩧", "𑩨", "𑩩", "𑩪", "𑩫", "𑩬", "𑩭", "𑩮", "𑩯", "𑩰", "𑩱", "𑩲", "𑩳", "𑩴", "𑩻", "𑩼", "𑩽", "𑩾", "𑩿", "𑪀", "𑪁", "𑪂", "𑩽ʽ", "𑩽ʽ", "𑩼ʽ", "𑩯ʽ", "𑩜ʽ", "𑩝ʽ", "𑩞ʽ", "𑩹", "𑨖ʽ", "𑩨ʽ", "𑩩ʽ", "𑩱ʽ", "𑪖𑩞ʽ", "𑪖𑩷ʽ", "𑪖𑩨ʽ", "𑪖𑩭ʽ", "𑪖𑩲ʽ" },
    { "𑪖ʽ", "𑪖", "𑪗", "𑪗ʽ", "ʽʽʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𑩐𑩖𑪖", "ʽʽʽ", "𑪛", "𑪜", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "sundanese", {
    ScriptType::Brahmi,
    { "ᮃ", "ᮃʽ", "ᮄ", "ᮄʽ", "ᮅ", "ᮅʽ", "ᮻ", "ᮻʽ", "ᮼ", "ᮼʽ", "ᮈ", "ᮈʽ", "ᮃᮄʽ", "ᮇ", "ᮇʽ", "ᮃᮅʽ", "ᮆ", "ᮆʽ", "ᮉ" },
    { "᮪", "ʽ", "ᮤ", "ᮤʽ", "ᮥ", "ᮥʽ", "᮪ᮻ", "᮪ᮻʽ", "᮪ᮼ", "᮪ᮼʽ", "ᮨ", "ᮨʽ", "ᮄʽ", "ᮧ", "ᮧʽ", "ᮅʽ", "ᮦ", "ᮦʽ", "ᮩ" },
    { "ᮊ", "ᮊʽ", "ᮌ", "ᮌʽ", "ᮍ", "ᮎ", "ᮎʽ", "ᮏ", "ᮏʽ", "ᮑ", "ᮒʽ", "ᮒʽ", "ᮓʽ", "ᮓʽ", "ᮔʽ", "ᮒ", "ᮒʽ", "ᮓ", "ᮓʽ", "ᮔ", "ᮕ", "ᮕʽ", "ᮘ", "ᮽ", "ᮙ", "ᮚ", "ᮛ", "ᮜ", "ᮝ", "ᮯ", "ᮯʽ", "ᮞ", "ᮠ", "ᮜʽ", "ᮜʽ", "ᮛʽ", "ᮔʽ", "ᮋ", "ᮮ", "ᮌʽ", "ᮐ", "ᮓʽ", "ᮓʽ", "ᮖ", "ᮚʽ", "ᮀᮌʽ", "ᮀᮏʽ", "ᮀᮓʽ", "ᮀᮓʽ", "ᮀᮘʽ" },
    { "ᮀʽ", "ᮀ", "ᮂ", "ᮂʽ", "ʽʽʽ" },
    { "᮰", "᮱", "᮲", "᮳", "᮴", "᮵", "᮶", "᮷", "᮸", "᮹", "ᮇᮀʽ", "ᮺ", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "sylotinagri", {
    ScriptType::Brahmi,
    { "ꠅ", "ꠀ", "ꠁ", "ꠁʽ", "ꠃ", "ꠃʽ", "ꠞꠤʽ", "ꠞꠤʽ", "ꠟꠤʽ", "ꠟꠤʽ", "ꠄʽ", "ꠄ", "ꠅꠂ", "ꠅʽ", "ꠅʽ", "ꠅꠃ", "ꠄʽ", "ꠄʽ", "ꠀʽ" },
    { "꠆", "ꠣ", "ꠤ", "ꠤʽ", "ꠥ", "ꠥʽ", "꠆ꠞꠤʽ", "꠆ꠞꠤʽ", "꠆ꠟꠤʽ", "꠆ꠟꠤʽ", "ꠦʽ", "ꠦ", "ꠂ", "ꠧʽ", "ꠧ", "ꠃʽʽ", "ꠦʽ", "ꠦʽ", "ꠣʽ" },
    { "ꠇ", "ꠈ", "ꠉ", "ꠊ", "ꠘʽ", "ꠌ", "ꠍ", "ꠎ", "ꠏ", "ꠘʽ", "ꠐ", "ꠑ", "ꠒ", "ꠓ", "ꠘʽ", "ꠔ", "ꠕ", "ꠖ", "ꠗ", "ꠘ", "ꠙ", "ꠚ", "ꠛ", "ꠜ", "ꠝ", "ꠎʽ", "ꠞ", "ꠟ", "ꠛʽ", "ꠡʽ", "ꠡʽ", "ꠡ", "ꠢ", "ꠟʽ", "ꠟʽ", "ꠞʽ", "ꠘʽ", "ꠇʽ", "ꠈʽ", "ꠉʽ", "ꠎʽ", "ꠠ", "ꠓʽ", "ꠚʽ", "ꠎʽ", "ꠋꠉʽ", "ꠋꠎʽ", "ꠋꠒʽ", "ꠋꠖʽ", "ꠋꠛʽ" },
    { "ꠋʽ", "ꠋ", "ꠢ꠆ʽ", "ꠢ꠆ʽʽ", "ʽʽʽ" },
    { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯", "ꠅꠋ", "ঽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tagalog", {
    ScriptType::Brahmi,
    { "ᜀ", "ᜀʽ", "ᜁ", "ᜁʽ", "ᜂ", "ᜂʽ", "ᜎᜓʽ", "ᜎᜓʽ", "ᜎᜓʽ", "ᜎᜓʽ", "ᜁʽ", "ᜁʽ", "ᜀᜁʽ", "ᜂʽ", "ᜂʽ", "ᜀᜂʽ", "ᜁʽ", "ᜁʽ", "ᜀʽ" },
    { "᜔", "ʽ", "ᜒ", "ᜒʽ", "ᜓ", "ᜓʽ", "᜔ᜎᜓʽ", "᜔ᜎᜓʽ", "᜔ᜎᜓʽ", "᜔ᜎᜓʽ", "ᜒʽ", "ᜒʽ", "ᜁʽ", "ᜓʽ", "ᜓʽ", "ᜂʽ", "ᜒʽ", "ᜒʽ", "ʽ" },
    { "ᜃ", "ᜃʽ", "ᜄ", "ᜄʽ", "ᜅ", "ᜐʽ", "ᜐʽ", "ᜇʽ", "ᜇʽ", "ᜈʽ", "ᜆʽ", "ᜆʽ", "ᜇʽ", "ᜇʽ", "ᜈʽ", "ᜆ", "ᜆʽ", "ᜇ", "ᜇʽ", "ᜈ", "ᜉ", "ᜉʽ", "ᜊ", "ᜊʽ", "ᜋ", "ᜌ", "ᜎʽ", "ᜎ", "ᜏ", "ᜐʽ", "ᜐʽ", "ᜐ", "ᜑ", "ᜎʽ", "ᜎʽ", "ᜎʽ", "ᜈʽ", "ᜃʽ", "ᜃʽ", "ᜄʽ", "ᜇʽ", "ᜇʽ", "ᜇʽ", "ᜉʽ", "ᜌʽ", "ᜅ᜔ᜄʽ", "ᜈᜇᜄʽ", "ᜈᜇᜄʽ", "ᜈᜇᜄʽ", "ᜋᜊᜄʽ" },
    { "ᜋ᜔ʽ", "ᜋ᜔ʽ", "ᜑ᜔ʽ", "ᜑ᜔ʽʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᜂᜋ᜔ʽ", "ʽʽ", "᜵", "᜶", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tagbanwa", {
    ScriptType::Brahmi,
    { "ᝠ", "ᝠʽ", "ᝡ", "ᝡʽ", "ᝢ", "ᝢʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝡʽ", "ᝡʽ", "ᝠᝡʽ", "ᝢʽ", "ᝢʽ", "ᝠᝢʽ", "ᝡʽ", "ᝡʽ", "ᝠʽ" },
    { "ʽ", "ʽ", "ᝲ", "ᝲʽ", "ᝳ", "ᝳʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝮᝳʽ", "ᝲʽ", "ᝲʽ", "ᝡʽ", "ᝳʽ", "ᝳʽ", "ᝢʽ", "ᝲʽ", "ᝲʽ", "ʽ" },
    { "ᝣ", "ᝣʽ", "ᝤ", "ᝤʽ", "ᝥ", "ᝰʽ", "ᝰʽ", "ᝧʽ", "ᝧʽ", "ᝨʽ", "ᝦʽ", "ᝦʽ", "ᝧʽ", "ᝧʽ", "ᝨʽ", "ᝦ", "ᝦʽ", "ᝧ", "ᝧʽ", "ᝨ", "ᝩ", "ᝩʽ", "ᝪ", "ᝪʽ", "ᝫ", "ᝬ", "ᝮʽ", "ᝮ", "ᝯ", "ᝰʽ", "ᝰʽ", "ᝰ", "ᝣʽ", "ᝮʽ", "ᝮʽ", "ᝮʽ", "ᝨʽ", "ᝣʽ", "ᝣʽ", "ᝤʽ", "ᝧʽ", "ᝧʽ", "ᝧʽ", "ᝩʽ", "ᝬʽ", "ᝥᝤʽ", "ᝨᝧʽ", "ᝨᝧʽ", "ᝨᝧʽ", "ᝫᝪʽ" },
    { "ᝫʽ", "ᝫʽ", "ᝣʽ", "ᝣʽʽ", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ᝢᝫʽ", "ʽʽ", "᜵", "᜶", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tailaing", {
    ScriptType::Brahmi,
    { "အ", "အႃ", "အိ", "အီ", "အု", "အူ", "ꩺိʽ", "ꩺီʽ", "လိʽ", "လီʽ", "အေʽ", "အေ", "အႆ", "အေႃʽ", "အေႃ", "အဝ်ʽ", "အေʽ", "အေʽ", "အႃʽ" },
    { "်", "ႃ", "ိ", "ီ", "ု", "ူ", "်ꩺိʽ", "်ꩺီʽ", "်လိʽ", "်လီʽ", "ေʽ", "ေ", "ႆ", "ေႃʽ", "ေႃ", "ဝ်ʽ", "ႄ", "ႄʽ", "ႃʽ" },
    { "က", "ၵ", "ꧩ", "ꧪ", "င", "ၸ", "ꩬ", "ꧫ", "ꧬ", "ꧧ", "ꩦ", "ꩧ", "ꧭ", "ꧮ", "ꧯ", "တ", "ထ", "ꧻ", "ꧼ", "ꩫ", "ပ", "ꧤ", "ꧽ", "ꧾ", "မ", "ယ", "ꩺ", "လ", "ဝ", "ꧬʽ", "ꧬʽ", "ꧬ", "ၯ", "ꧺ", "ꧺʽ", "ꩺʽ", "ꩫʽ", "ကʽ", "ၵʽ", "ꧩʽ", "ꧫʽ", "ꧭʽ", "ꧮʽ", "ꧨ", "ယʽ", "ံၵʽ", "ံꧫʽ", "ံꧭʽ", "ံꧻʽ", "ံꧽʽ" },
    { "ံʽ", "ံ", "း", "းʽ", "ʽʽʽ" },
    { "꧰", "꧱", "꧲", "꧳", "꧴", "꧵", "꧶", "꧷", "꧸", "꧹", "အေႃံ", "'", "၊", "။", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "taitham", {
    ScriptType::Brahmi,
    { "ᩋ", "ᩋᩣ", "ᩍ", "ᩎ", "ᩏ", "ᩐ", "ᩂ", "ᩂᩣ", "ᩄ", "ᩄᩣ", "ᩑʽ", "ᩑ", "ᩋᩱ", "ᩒʽ", "ᩒ", "ᩏᩫᩣ", "ᩑʽ", "ᩑʽ", "ᩋᩣʽ" },
    { "᩺", "ᩣ", "ᩥ", "ᩦ", "ᩩ", "ᩪ", "᩺ᩂ", "᩺ᩂᩣ", "᩺ᩄ", "᩺ᩄᩣ", "ᩮʽ", "ᩮ", "ᩱ", "ᩮᩣʽ", "ᩮᩣ", "ᩮᩫᩣ", "ᩮʽ", "ᩮʽ", "ᩣʽ" },
    { "ᨠ", "ᨡ", "ᨣ", "ᨥ", "ᨦ", "ᨧ", "ᨨ", "ᨩ", "ᨫ", "ᨬ", "ᨭ", "ᨮ", "ᨯ", "ᨰ", "ᨱ", "ᨲ", "ᨳ", "ᨴ", "ᨵ", "ᨶ", "ᨸ", "ᨹ", "ᨻ", "ᨽ", "ᨾ", "ᨿ", "ᩁ", "ᩃ", "ᩅ", "ᩆ", "ᩇ", "ᩈ", "ᩉ", "ᩊ", "ᩊʽ", "ᩁʽ", "ᨶʽ", "ᨠʽ", "ᨡʽ", "ᨣʽ", "ᨩʽ", "ᨯʽ", "ᨰʽ", "ᨹʽ", "ᨿʽ", "ᩴᨣʽ", "ᩴᨩʽ", "ᩴᨯʽ", "ᩴᨴʽ", "ᩴᨽʽ" },
    { "ᩴʽ", "ᩴ", "ᩡ", "ᩡʽ", "ʽ" },
    { "᪐", "᪑", "᪒", "᪓", "᪔", "᪕", "᪖", "᪗", "᪘", "᪙", "ᩒᩴ", "'", "᪨", "᪩", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "takri", {
    ScriptType::Brahmi,
    { "𑚀", "𑚁", "𑚂", "𑚃", "𑚄", "𑚅", "𑚤𑚮ʽ", "𑚤𑚯ʽ", "𑚥𑚮ʽ", "𑚥𑚯ʽ", "𑚆", "𑚆", "𑚇", "𑚈", "𑚈", "𑚉", "𑚆ʽ", "𑚆ʽ", "𑚁ʽ" },
    { "𑚶", "𑚭", "𑚮", "𑚯", "𑚰", "𑚱", "𑚶𑚤𑚮ʽ", "𑚶𑚤𑚯ʽ", "𑚶𑚥𑚮ʽ", "𑚶𑚥𑚯ʽ", "𑚳ʽ", "𑚲", "𑚳", "𑚴ʽ", "𑚴", "𑚵", "𑚳ʽ", "𑚳ʽ", "𑚭ʽ" },
    { "𑚊", "𑚸", "𑚌", "𑚍", "𑚎", "𑚏", "𑚐", "𑚑", "𑚒", "𑚓", "𑚔", "𑚕", "𑚖", "𑚗", "𑚘", "𑚙", "𑚚", "𑚛", "𑚜", "𑚝", "𑚞", "𑚟", "𑚠", "𑚡", "𑚢", "𑚣", "𑚤", "𑚥", "𑚦", "𑚧", "𑚋", "𑚨", "𑚩", "𑚥𑚷", "𑚥𑚷ʽ", "𑚤𑚷", "𑚝𑚷", "𑚊𑚷", "𑚋𑚷", "𑚌𑚷", "𑚑𑚷", "𑚪", "𑚗𑚷", "𑚟𑚷", "𑚣𑚷", "𑚫𑚌ʽ", "𑚫𑚑ʽ", "𑚫𑚖ʽ", "𑚫𑚛ʽ", "𑚫𑚠ʽ" },
    { "𑚫ʽ", "𑚫", "𑚬", "𑚬ʽ", "𑚷" },
    { "𑛀", "𑛁", "𑛂", "𑛃", "𑛄", "𑛅", "𑛆", "𑛇", "𑛈", "𑛉", "𑚈𑚫", "ऽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tamilbrahmi", {
    ScriptType::Brahmi,
    { "𑀅", "𑀆", "𑀇", "𑀈", "𑀉", "𑀊", "𑀭𑀼ʽ", "𑀭𑀽ʽ", "𑀮𑀼ʽ", "𑀮𑀽ʽ", "𑀏𑁆", "𑀏", "𑀐", "𑀑𑁆", "𑀑", "𑀒", "𑀏𑁆ʽ", "𑀏ʽ", "𑀆ʽ" },
    { "𑁆", "𑀸", "𑀺", "𑀻", "𑀼", "𑀽", "𑁆𑀭𑀼ʽ", "𑁆𑀭𑀽ʽ", "𑁆𑀮𑀼ʽ", "𑁆𑀮𑀽ʽ", "𑁂𑁆", "𑁂", "𑁃", "𑁄𑁆", "𑁄", "𑁅", "𑁂𑁆ʽ", "𑁂ʽ", "𑀸ʽ" },
    { "𑀓", "𑀓ʽ", "𑀓ʽ", "𑀓ʽ", "𑀗", "𑀘", "𑀘ʽ", "𑀚", "𑀚ʽ", "𑀜", "𑀝", "𑀝ʽ", "𑀝ʽ", "𑀝ʽ", "𑀡", "𑀢", "𑀢ʽ", "𑀢ʽ", "𑀥", "𑀦", "𑀧", "𑀧ʽ", "𑀧ʽ", "𑀧ʽ", "𑀫", "𑀬", "𑀭", "𑀮", "𑀯", "𑀰", "𑀱", "𑀲", "𑀳", "𑀴", "𑀵", "𑀶", "𑀷", "𑀓ʽ", "𑀓ʽ", "𑀓ʽ", "𑀚ʽ", "𑀝ʽ", "𑀝ʽ", "𑀧ʽ", "𑀬ʽ", "𑀗𑁆𑀓ʽ", "𑀜𑁆𑀚ʽ", "𑀡𑁆𑀝ʽ", "𑀦𑁆𑀢ʽ", "𑀫𑁆𑀧ʽ" },
    { "𑀫𑁆ʽ", "𑀫𑁆ʽ", "𑀂ʽ", "𑀂", "ʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𑀑𑀫𑁆", "'", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tamilextended", {
    ScriptType::Tamil,
    { "അ", "ആ", "ഇ", "ഈ", "ഉ", "ഊ", "ഋ", "ൠ", "ഌ", "ൡ", "എ", "ഏ", "ഐ", "ഒ", "ഓ", "ഔ", "എʼ", "ഏˇ", "ആʼ" },
    { "്‌", "ാ", "ി", "ീ", "ു", "ൂ", "ൃ", "ൄ", "ൢ", "ൣ", "െ", "േ", "ൈ", "ൊ", "ോ", "ൗ", "െʼ", "േˇ", "ാʼ" },
    { "ക", "ഖ", "ഗ", "ഘ", "ങ", "ച", "ഛ", "ജ", "ഝ", "ഞ", "ട", "ഠ", "ഡ", "ഢ", "ണ", "ത", "ഥ", "ദ", "ധ", "ന", "പ", "ഫ", "ബ", "ഭ", "മ", "യ", "ര", "ല", "വ", "ശ", "ഷ", "സ", "ഹ", "ള", "ഴ", "റ", "ഩ", "ക·", "ഖ·", "ഗ·", "ജ·", "ഡ·", "ഢ·", "ഫ·", "യ·", "ംˆഗ", "ംˆജ", "ംˆഡ", "ംˆദ", "ംˆബ" },
    { "ഁ", "ം", "ഃ", "ஃ", "·" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ௐ", "ഽ", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tamilgrantha", {
    ScriptType::Tamil,
    { "அ", "ஆ", "இ", "ஈ", "உ", "ஊ", "ঋ", "ৠ", "ঌ", "ৡ", "எ", "ஏ", "ஐ", "ஒ", "ஓ", "ஔ", "எʼ", "ஏˇ", "ஆʼ" },
    { "்", "ா", "ி", "ீ", "ு", "ூ", "ৃ", "ৄ", "ৢ", "ৣ", "ெ", "ே", "ை", "ொ", "ோ", "ௌ", "ெʼ", "ேˇ", "ாʼ" },
    { "க", "খ", "গ", "ঘ", "ங", "ச", "ছ", "ஜ", "ঝ", "ஞ", "ட", "ঠ", "ড", "ঢ", "ண", "த", "থ", "দ", "ধ", "ந", "ப", "ফ", "ব", "ভ", "ம", "ய", "ர", "ல", "வ", "ஶ", "ஷ", "ஸ", "ஹ", "ள", "ழ", "ற", "ன", "க়", "খ়", "গ়", "ஜ়", "ড়", "ঢ়", "ফ়", "ய়", "ங்ˆগ", "ஞ்ˆஜ", "ண்ˆড", "ந்ˆদ", "ம்ˆব" },
    { "ঁ", "ং", "ঃ", "ঃʼ", "়" },
    { "০", "১", "২", "৩", "৪", "৫", "৬", "৭", "৮", "৯", "ௐ", "ঽ", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "thaana", {
    ScriptType::Brahmi,
    { "އަ", "އާ", "އި", "އީ", "އު", "އޫ", "ރު", "ރޫ", "ލު", "ލޫ", "އެ", "އޭ", "އައިʽ", "އޮ", "އޯ", "އައުʽ", "އެʽ", "އޭʽ", "އާʽ" },
    { "ް", "ާ", "ި", "ީ", "ު", "ޫ", "ްރު", "ްރޫ", "ްލު", "ްލޫ", "ެ", "ޭ", "ައިʽ", "ޮ", "ޯ", "ައުʽ", "ެʽ", "ޭʽ", "ާʽ" },
    { "ކަ", "ކʽަ", "ގަ", "ގʽަ", "ނʽަ", "ޗަ", "ޗʽަ", "ޖަ", "ޖʽަ", "ޏަ", "ޓަ", "ޓʽަ", "ޑަ", "ޑʽަ", "ޱަ", "ތަ", "ތʽަ", "ދަ", "ދʽަ", "ނަ", "ޕަ", "ޕʽަ", "ބަ", "ބʽަ", "މަ", "ޔަ", "ރަ", "ލަ", "ވަ", "ޝަ", "ށަ", "ސަ", "ހަ", "ޅަ", "ޅʽަ", "ރʽަ", "ނʽަ", "ޤަ", "ޚަ", "ޣަ", "ޒަ", "ޑʽަ", "ޑʽަ", "ފަ", "ޔʽަ", "ނގަ", "ނޖަ", "ނޑަ", "ނދަ", "ނބަ" },
    { "މްʽ", "މްʽ", "ހަްʽ", "ހަްʽʽ", "ʽʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "އޯމަް", "ʽʽ", "۔", "۔۔", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "thai", {
    ScriptType::Brahmi,
    { "อ", "อา", "อิ", "อี", "อุ", "อู", "ฤ", "ฤๅ", "ฦ", "ฦๅ", "อเะ", "อเ", "อไ", "อโะ", "อโ", "อเา", "อแะ", "อแ", "อเาะ" },
    { "ฺ", "า", "ิ", "ี", "ุ", "ู", "ฺฤ", "ฺฤๅ", "ฺฦ", "ฺฦๅ", "เะ", "เ", "ไ", "โะ", "โ", "เา", "แะ", "แ", "เาะ" },
    { "ก", "ข", "ค", "ฆ", "ง", "จ", "ฉ", "ช", "ฌ", "ญ", "ฏ", "ฐ", "ฑ", "ฒ", "ณ", "ต", "ถ", "ท", "ธ", "น", "ป", "ผ", "พ", "ภ", "ม", "ย", "ร", "ล", "ว", "ศ", "ษ", "ส", "ห", "ฬ", "ฬʽ", "รʽ", "นʽ", "กʽ", "ฃ", "ฅ", "ซ", "รʽ", "รฺหʽ", "ฟ", "ยʽ", "ํคʽ", "ํชʽ", "ํฑʽ", "ํทʽ", "ํพʽ" },
    { "ํʽ", "ํ", "ห์", "ห์ʽ", "ʽ" },
    { "๐", "๑", "๒", "๓", "๔", "๕", "๖", "๗", "๘", "๙", "โอํ", "'", "ฯ", "๚", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tibetan", {
    ScriptType::Brahmi,
    { "ཨ", "ཨཱ", "ཨི", "ཨཱི", "ཨུ", "ཨཱུ", "རྀ", "རཱྀ", "ལྀ", "ལཱྀ", "ཨེʽ", "ཨེ", "ཨཻ", "ཨོʽ", "ཨོ", "ཨཽ", "ཨེʽ", "ཨེʽ", "ཨཱʽ" },
    { "྄", "ཱ", "ི", "ཱི", "ུ", "ཱུ", "ྲྀ", "ྲཱྀ", "ླྀ", "ླཱྀ", "ེʽ", "ེ", "ཻ", "ོʽ", "ོ", "ཽ", "ེʽ", "ེʽ", "ཱʽ" },
    { "ཀ", "ཁ", "ག", "གྷ", "ང", "ཙ", "ཚ", "ཛ", "ཛྷ", "ཉ", "ཊ", "ཋ", "ཌ", "ཌྷ", "ཎ", "ཏ", "ཐ", "ད", "དྷ", "ན", "པ", "ཕ", "བ", "བྷ", "མ", "ཡ", "ར", "ལ", "ཝ", "ཤ", "ཥ", "ས", "ཧ", "ལ༹", "ཥ༹", "ར༹", "ན༹", "ཀ༹", "ཁ༹", "ག༹", "ཟ", "ཌ༹", "ཌྷ༹", "ཕ༹", "ཡ༹", "ྃཀʽ", "ྃཛʽ", "ྃཌʽ", "ྃདʽ", "ྃབʽ" },
    { "ྃ", "ཾ", "ཿ", "ཿʽ", "༹" },
    { "༠", "༡", "༢", "༣", "༤", "༥", "༦", "༧", "༨", "༩", "ༀ", "྅", "།", "༎", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "tirhuta", {
    ScriptType::Brahmi,
    { "𑒁", "𑒂", "𑒃", "𑒄", "𑒅", "𑒆", "𑒇", "𑒈", "𑒉", "𑒊", "𑒁𑒺", "𑒋", "𑒌", "𑒁𑒽", "𑒍", "𑒎", "𑒋ʽ", "𑒋ʽ", "𑒂ʽ" },
    { "𑓂", "𑒰", "𑒱", "𑒲", "𑒳", "𑒴", "𑒵", "𑒶", "𑒷", "𑒸", "𑒺", "𑒹", "𑒻", "𑒽", "𑒼", "𑒾", "𑒹ʽ", "𑒹ʽ", "𑒰ʽ" },
    { "𑒏", "𑒐", "𑒑", "𑒒", "𑒓", "𑒔", "𑒕", "𑒖", "𑒗", "𑒘", "𑒙", "𑒚", "𑒛", "𑒜", "𑒝", "𑒞", "𑒟", "𑒠", "𑒡", "𑒢", "𑒣", "𑒤", "𑒥", "𑒦", "𑒧", "𑒨", "𑒩", "𑒪", "𑒫", "𑒬", "𑒭", "𑒮", "𑒯", "𑒝𑓃", "𑒭𑓃", "𑒩ʽ", "𑒪𑓃", "𑒏𑓃", "𑒐𑓃", "𑒑𑓃", "𑒖𑓃", "𑒛𑓃", "𑒜𑓃", "𑒤𑓃", "𑒨𑓃", "𑒿𑒑ʽ", "𑒿𑒖ʽ", "𑒿𑒛ʽ", "𑒿𑒠ʽ", "𑒿𑒥ʽ" },
    { "𑒿", "𑓀", "𑓁", "𑓁ʽ", "𑓃" },
    { "𑓐", "𑓑", "𑓒", "𑓓", "𑓔", "𑓕", "𑓖", "𑓗", "𑓘", "𑓙", "𑓇", "𑓄", "।", "॥", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "titus", {
    ScriptType::Roman,
    { "a", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "×", "ā", "i", "ī", "u", "ū", "r̥", "r̥̄", "l̥", "l̥̄", "ĕ", "e", "ai", "ŏ", "o", "au", "æ", "ǣ", "ô" },
    { "k", "kʰ", "g", "gʰ", "ṅ", "c", "cʰ", "j", "jʰ", "ñ", "ṭ", "ṭʰ", "ḍ", "ḍʰ", "ṇ", "t", "tʰ", "d", "dʰ", "n", "p", "pʰ", "b", "bʰ", "m", "y", "r", "l", "v", "ś", "ṣ", "s", "h", "ḷ", "ḻ", "ṟ", "ṉ", "q", "k͟ʰ", "ġ", "z", "ṛ", "ṛʰ", "f", "ẏ", "n̆g", "n̆j", "n̆ḍ", "n̆d", "m̆b" },
    { "m̐", "ṃ", "ḥ", "ḵ", "̈" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oṃ", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "tolongsiki", {
    ScriptType::Roman,
    { "a", "A", "i", "iʽ", "u", "uʽ", "ruʽ", "ruʽ", "luʽ", "luʽ", "eʽ", "e", "ai", "aʽ", "o", "au", "eʽ", "Aʽ", "Aʽ" },
    { "×", "A", "i", "iʽ", "u", "uʽ", "ruʽ", "ruʽ", "luʽ", "luʽ", "eʽ", "e", "ai", "aʽ", "o", "au", "eʽ", "Aʽ", "Aʽ" },
    { "k", "K", "g", "G", "W", "c", "C", "j", "J", "Y", "t", "T", "d", "D", "N", "q", "Q", "v", "V", "n", "p", "P", "b", "B", "m", "y", "r", "l", "w", "sʽ", "sʽ", "s", "h", "lʽ", "lʽ", "rʽ", "nʽ", "kʽ", "x", "gʽ", "jʽ", "z", "Z", "Pʽ", "yʽ", "Mg", "Mj", "Md", "Mv", "Mb" },
    { "Mʽ", "M", "hʽ", "hʽ", "ʽ" },
    { "0", "¡", "¢", "£", "¤", "¥", "¦", "§", "¨", "©", "oM", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "urdu", {
    ScriptType::Brahmi,
    { "اَ", "آ", "اِ", "اِی", "اُ", "اُو", "رِʽ", "رِیʽ", "لِʽ", "لِیʽ", "ایʽ", "ای", "اََی", "اوʽ", "او", "اََو", "ایʽ", "اےʽ", "آʽ" },
    { "ْ", "ا", "ِ", "ِی", "ُ", "ُو", "ْرِʽ", "ْرِیʽ", "ْلِʽ", "ْلِیʽ", "یʽ", "ی", "ََی", "وʽ", "و", "ََو", "یʽ", "یʽ", "اʽ" },
    { "کَ", "کھَ", "گَ", "گھَ", "نʽَ", "چَ", "چھَ", "جَ", "جھَ", "نʽَ", "ٹَ", "ٹھَ", "ڈَ", "ڈھَ", "نʽَ", "تَ", "تھَ", "دَ", "دھَ", "نَ", "پَ", "پھَ", "بَ", "بھَ", "مَ", "یَ", "رَ", "لَ", "وَ", "شَ", "شَʽ", "سَ", "ہَ", "لʽَ", "لʽَ", "رʽَ", "نʽَ", "قَ", "خَ", "غَ", "زَ", "ڑَ", "ڑھَ", "فَ", "یَʽ", "ںگʽَ", "ںجʽَ", "ںڈʽَ", "ںدʽَ", "ںبʽَ" },
    { "ںʽ", "ں", "ہ", "ہʽ", "ʽ" },
    { "۰", "۱", "۲", "۳", "۴", "۵", "۶", "۷", "۸", "۹", "اومْ", "ʽ", "۔", "۔۔", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "vatteluttu", {
    ScriptType::Tamil,
    { "அ", "ஆ", "இ", "ஈ", "உ", "ஊ", "ருʽ", "ரூʽ", "லுʽ", "லூʽ", "எ", "ஏ", "ஐ", "ஒ", "ஓ", "ஔ", "எʽ", "ஏʽ", "ஆʽ" },
    { "்", "ா", "ி", "ீ", "ு", "ூ", "்ருʽ", "்ரூʽ", "்லுʽ", "்லூʽ", "ெ", "ே", "ை", "ொ", "ோ", "ௌ", "ெʽ", "ேʽ", "ாʽ" },
    { "க", "கʽ", "கʽ", "கʽ", "ங", "ச", "சʽ", "சʽ", "சʽ", "ஞ", "ட", "டʽ", "டʽ", "டʽ", "ண", "த", "தʽ", "தʽ", "தʽ", "ந", "ப", "பʽ", "பʽ", "பʽ", "ம", "ய", "ர", "ல", "வ", "சʽ", "சʽ", "சʽ", "கʽ", "ள", "ழ", "ற", "ன", "ʽக", "ʽக", "ʽக", "ʽச", "ʽட", "ʽட", "ʽப", "ʽய", "ங்ʽக", "ஞ்ʽச", "ண்ʽட", "ந்ʽத", "ம்ʽப" },
    { "ம்ʽ", "ம்ʽ", "꞉", "ஃ", "ʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "ஓம்", "ʽ", ".", "..", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }},
  { "velthuis", {
    ScriptType::Roman,
    { "a", "aa", "i", "ii", "u", "uu", ".r", ".R", ".l", ".L", "E", "e", "ai", "O", "o", "au", "aE", "AE", "aO" },
    { "×", "aa", "i", "ii", "u", "uu", ".r", ".R", ".l", ".L", "E", "e", "ai", "O", "o", "au", "aE", "AE", "aO" },
    { "k", "kh", "g", "gh", "\"n", "c", "ch", "j", "jh", "~n", ".t", ".th", ".d", ".dh", ".n", "t", "th", "d", "dh", "n", "p", "ph", "b", "bh", "m", "y", "r", "l", "v", "\"s", ".s", "s", "h", "..l", "_l", "_r", "_n", "q", "_kh", ".g", "z", "..r", "..rh", "f", ".y", "n*g", "n*j", "n*.d", "n*d", "m*b" },
    { "~m", ".m", ".h", "_k", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "o.m", ".a", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "wancho", {
    ScriptType::Brahmi,
    { "𞋁", "𞋀", "𞋜", "𞋜ʽ", "𞋞", "𞋞ʽ", "𞋗𞋞ʽ", "𞋗𞋞ʽ", "𞋈𞋞ʽ", "𞋈𞋞ʽ", "𞋛ʽ", "𞋛", "𞋀𞋜", "𞋕ʽ", "𞋕", "𞋖", "𞋛ʽ", "𞋛ʽ", "𞋀ʽ" },
    { "×", "𞋀", "𞋜", "𞋜ʽ", "𞋞", "𞋞ʽ", "𞋗𞋞ʽ", "𞋗𞋞ʽ", "𞋈𞋞ʽ", "𞋈𞋞ʽ", "𞋛ʽ", "𞋛", "𞋀𞋜", "𞋕ʽ", "𞋕", "𞋖", "𞋛ʽ", "𞋛ʽ", "𞋀ʽ" },
    { "𞋔", "𞋙", "𞋅", "𞋅ʽ", "𞋝", "𞋃", "𞋃ʽ", "𞋐", "𞋐ʽ", "𞋩", "𞋋ʽ", "𞋌ʽ", "𞋄ʽ", "𞋄ʽ", "𞋉ʽ", "𞋋", "𞋌", "𞋄", "𞋄ʽ", "𞋉", "𞋊", "𞋇", "𞋂", "𞋂ʽ", "𞋘", "𞋆", "𞋗", "𞋈", "𞋓", "𞋏", "𞋏ʽ", "𞋎", "𞋚", "𞋟", "𞋟ʽ", "𞋗ʽ", "𞋉ʽ", "𞋔ʽ", "𞋙ʽ", "𞋅ʽ", "𞋑", "𞋄ʽ", "𞋄ʽ", "𞋍", "𞋆ʽ", "𞋝𞋅ʽ", "𞋩𞋐ʽ", "𞋉𞋄ʽ", "𞋉𞋄ʽ", "𞋘𞋂ʽ" },
    { "ʿ", "ʾ", "𞋫", "𞋔ʽ", "Ø" },
    { "𞋰", "𞋱", "𞋲", "𞋳", "𞋴", "𞋵", "𞋶", "𞋷", "𞋸", "𞋹", "𞋦ʽ", "ʽʽ", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "warangciti", {
    ScriptType::Brahmi,
    { "𑣁", "𑣁𑣙ʾ", "𑣂", "𑣆", "𑣃", "𑣇", "𑣜𑣃ʽ", "𑣜𑣇ʽ", "𑣚𑣃ʽ", "𑣚𑣇ʽ", "𑣈ʽ", "𑣈", "𑣆ʽ", "𑣉ʽ", "𑣉", "𑣇ʽ", "𑣈ʽ", "𑣈ʽ", "𑣁𑣙ʽ" },
    { "×", "𑣁𑣙ʾ", "𑣂", "𑣆", "𑣃", "𑣇", "𑣜𑣃ʽ", "𑣜𑣇ʽ", "𑣚𑣃ʽ", "𑣚𑣇ʽ", "𑣈ʽ", "𑣈", "𑣆ʽ", "𑣉ʽ", "𑣉", "𑣇ʽ", "𑣈ʽ", "𑣈ʽ", "𑣁𑣙ʽ" },
    { "𑣌", "𑣌‍𑣙", "𑣋", "𑣋‍𑣙", "𑣊", "𑣏", "𑣏‍𑣙", "𑣎", "𑣎‍𑣙", "𑣍", "𑣒", "𑣒‍𑣙", "𑣑", "𑣑‍𑣙", "𑣐", "𑣕", "𑣕‍𑣙", "𑣔", "𑣔‍𑣙", "𑣓", "𑣘", "𑣘‍𑣙", "𑣗", "𑣗‍𑣙", "𑣖", "𑣅", "𑣜", "𑣚", "𑣟", "𑣝ʽ", "𑣝", "𑣞", "𑣙", "𑣚ʽ", "𑣚ʽ", "𑣜ʽ", "𑣓ʽ", "𑣌ʽ", "𑣌‍𑣙ʽ", "𑣋ʽ", "𑣎ʽ", "𑣛", "𑣛‍𑣙", "𑣘ʽ", "𑣅ʽ", "𑣀𑣋ʽ", "𑣀𑣎ʽ", "𑣀𑣑ʽ", "𑣀𑣔ʽ", "𑣀𑣗ʽ" },
    { "𑣀ʽ", "𑣀", "𑣄", "𑣄ʽ", "ʿ" },
    { "𑣠", "𑣡", "𑣢", "𑣣", "𑣤", "𑣥", "𑣦", "𑣧", "𑣨", "𑣩", "𑣿ʽ", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "wx", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "q", "qV", "L", "LV", "eV", "e", "E", "oV", "o", "O", "aEV", "AEV", "aOV" },
    { "×", "A", "i", "I", "u", "U", "q", "qV", "L", "LV", "eV", "e", "E", "oV", "o", "O", "aEV", "AEV", "aOV" },
    { "k", "K", "g", "G", "f", "c", "C", "j", "J", "F", "t", "T", "d", "D", "N", "w", "W", "x", "X", "n", "p", "P", "b", "B", "m", "y", "r", "l", "v", "S", "R", "s", "h", "lY", "lYY", "rY", "nY", "kY", "KY", "GY", "zY", "dY", "DY", "PY", "yY", "nYYg", "nYYj", "nYYd", "nYYx", "mYYb" },
    { "z", "M", "H", "kYY", "Q" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oM", "'", ".", "..", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "wx-kok", {
    ScriptType::Roman,
    { "a", "A", "i", "I", "u", "U", "q", "qVY", "LY", "LVY", "e", "E", "Y", "o", "O", "Q", "Z", "AEVY", "V" },
    { "×", "A", "i", "I", "u", "U", "q", "qVY", "LY", "LVY", "e", "E", "Y", "o", "O", "Q", "Z", "AEVY", "V" },
    { "k", "K", "g", "G", "f", "c", "C", "j", "J", "F", "t", "T", "d", "D", "N", "w", "W", "x", "X", "n", "p", "P", "b", "B", "m", "y", "r", "l", "v", "z", "S", "s", "h", "L", "lYYY", "R", "nYY", "kYY", "KYY", "GYY", "zYY", "dYY", "DYY", "PYY", "yYY", "nYYgY", "nYYjY", "nYYdY", "nYYxY", "mYYbY" },
    { "~", "M", "H", "kYYY", "QY" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "oMY", "'Y", ".Y", "..Y", "gͫ", "gͫ̄", "​", "‌", "‍" }
  }},
  { "zanabazarsquare", {
    ScriptType::Brahmi,
    { "𑨀", "𑨀𑨊", "𑨀𑨁", "𑨀𑨁𑨊", "𑨀𑨂", "𑨀𑨂𑨊", "𑨫𑨉", "𑨫𑨉𑨊", "𑨬𑨉", "𑨬𑨉𑨊", "𑨀𑨄ʽ", "𑨀𑨄", "𑨀𑨄𑨊", "𑨀𑨆ʽ", "𑨀𑨆", "𑨀𑨆𑨊", "𑨀𑨄ʽ", "𑨀𑨄ʽ", "𑨀𑨅" },
    { "𑨴", "𑨊", "𑨁", "𑨁𑨊", "𑨂", "𑨂𑨊", "𑨴𑨫𑨉", "𑨴𑨫𑨉𑨊", "𑨴𑨬𑨉", "𑨴𑨬𑨉𑨊", "𑨄ʽ", "𑨄", "𑨄𑨊", "𑨆ʽ", "𑨆", "𑨆𑨊", "𑨄ʽ", "𑨄ʽ", "𑨅" },
    { "𑨋", "𑨌", "𑨍", "𑨎", "𑨏", "𑨣", "𑨤", "𑨥", "𑨦", "𑨓", "𑨔", "𑨕", "𑨖", "𑨗", "𑨘", "𑨙", "𑨚", "𑨛", "𑨜", "𑨝", "𑨞", "𑨟", "𑨠", "𑨡", "𑨢", "𑨪", "𑨫", "𑨬", "𑨭", "𑨮", "𑨯", "𑨰", "𑨱", "𑨬ʽ", "𑨬ʽ", "𑨫ʽ", "𑨝ʽ", "𑨋ʽ", "𑨌ʽ", "𑨍ʽ", "𑨨", "𑨖ʽ", "𑨗ʽ", "𑨟ʽ", "𑨪ʽ", "𑨵𑨍ʽ", "𑨵𑨥ʽ", "𑨵𑨖ʽ", "𑨵𑨛ʽ", "𑨵𑨠ʽ" },
    { "𑨵", "𑨸", "𑨹", "𑨹ʽ", "ʽʽʽʽ" },
    { "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "𑨀𑨆𑨵", "ʽʽʽ", "𑩂", "𑩃", "ꣳ", "ꣴ", "​", "‌", "‍" }
  }}
#endif
}};
// clang-format on
